-- sql
-- $Source: atc_script.sql
-- $Revision: Oct 5, 2011
-- $Author: Jim Busser, GNUmed project
-- ---------------------------
-- Description:
-- script for filling missing ATC codes (based on consumable substance names)
-- … into GNUmed ref.consumable_substance
-- … deployed as 'install-data-pack.sql' within GNUmed data packs
-- Caveats:
-- 1. a drug can be known by more than one ATC code
-- 2. accordingly it will not mean that usage of the consumable substance will match the code
-- ---------------------------
-- References / links:
-- GNUmed git repository, data packs and project
--   git://gitorious.org/gnumed/gnumed.git
--   http://wiki.gnumed.de/bin/view/Gnumed/GmManualReferenceData
--   http://www.gnumed.de/downloads/data/data-packs.conf
--   http://wiki.gnumed.de
-- Health Canada DPD
--   contributes (source of):
--     ATC codes for branded drugs, from which is derived ATC for ingredient where # ingred = 1
--   file listing:
--     http://www.hc-sc.gc.ca/dhp-mps/prodpharma/databasdon/dpd_bdpp_data_extract-eng.php
--   data specifications:
--     http://www.hc-sc.gc.ca/dhp-mps/alt_formats/hpfb-dgpsa/txt/prodpharma/dpdreadme_bdpplisezmoi-eng.txt
-- FreeDiams
--   contributes (source of):
--     ATC codes for one language INN
--   download URL:
--     http://freemedforms.googlecode.com/files/freediamsfullsources-0.5.4.tgz
-- ----------------------

-- uncomment the following to run from psql (instead of from GNUmed GUI)
-- set default_transaction_read_only to off;

-----------------------------------------------------------------------------
-- ************************************************************
-- set ON_ERROR_STOP 1
-- ************************************************************
-- ---------------------------------------------------------------------------
\set ON_ERROR_STOP 1


-----------------------------------------------------------------------------
-- ************************************************************
-- create staging table
-- ************************************************************
-- -----------------------------------------------------------------------------
-- ---------------------------------------------
\unset ON_ERROR_STOP
DROP TABLE staging.atc CASCADE;
\set ON_ERROR_STOP 1

begin;

CREATE TABLE staging.atc (
    description varchar,
    atc_code varchar
);


-- -----------------------------------------------------------------------------
-- *********************
-- import staging data
-- *********************
-- -----------------------------------------------------------------------------
--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = staging, pg_catalog;

--
-- Data for Name: atc; Type: TABLE DATA; Schema: staging; Owner: gm-dbo
--

INSERT INTO staging.atc (description, atc_code) VALUES ('(2-benzhydryloxyethyl)diethyl-methylammonium iodide', 'A03AB16');
INSERT INTO staging.atc (description, atc_code) VALUES ('(morpholinothio)benzothiazole', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('2-(4-chlorphenoxy)-ethanol', 'D01AE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('2-amino-1-phenylethanol derivatives', 'C04AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('3-(trimethoxysilyl)propyl dimethyl octadecyl ammonium chloride', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('3-oxoandrosten (4) derivatives', 'G03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('4-dimethylaminophenol', 'V03AB27');
INSERT INTO staging.atc (description, atc_code) VALUES ('5-androstanon (3) derivatives', 'G03BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('abacavir', 'J05AF06');
INSERT INTO staging.atc (description, atc_code) VALUES ('abacavir (abacavir sulfate)', 'J05AF06');
INSERT INTO staging.atc (description, atc_code) VALUES ('abarelix', 'L02BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('abatacept', 'L04AA24');
INSERT INTO staging.atc (description, atc_code) VALUES ('abciximab', 'B01AC13');
INSERT INTO staging.atc (description, atc_code) VALUES ('abetimus', 'L04AA22');
INSERT INTO staging.atc (description, atc_code) VALUES ('abiraterone acetate', 'L02BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('absorbable gelatin sponge', 'B02BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acadesine', 'C01EB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('acamprosate', 'N07BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('acamprosate calcium', 'N07BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('acarbose', 'A10BF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ace inhibitors and calcium channel blockers', 'C09BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('ace inhibitors and diuretics', 'C09BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('ace inhibitors, combinations', 'C09B');
INSERT INTO staging.atc (description, atc_code) VALUES ('ace inhibitors, plain', 'C09AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('ace inhibitors, plain', 'C09A');
INSERT INTO staging.atc (description, atc_code) VALUES ('acebutolol', 'C07AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('acebutolol and thiazides', 'C07BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aceclidine', 'S01EB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('aceclidine, combinations', 'S01EB58');
INSERT INTO staging.atc (description, atc_code) VALUES ('aceclofenac', 'M01AB16');
INSERT INTO staging.atc (description, atc_code) VALUES ('acefylline piperazine', 'R03DA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('acemetacin', 'M01AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('acenocoumarol', 'B01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('acepromazine', 'N05AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aceprometazine', 'Z01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetaminophen', 'N02BE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetarsol', 'G01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetarsol', 'A07AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetarsol', 'P01CD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetazolamide', 'S01EC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetazolamide (acetazolamide sodium)', 'S01EC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetic acid', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetic acid', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetic acid', 'G01AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetic acid', 'S02AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetic acid derivatives and related substances', 'M01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetohexamide', 'A10BB31');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetohydroxamic acid', 'G04BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetophenazine', 'N05AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetorphan', 'A07XA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetoxolone', 'A02BX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetphenolisatin', 'A06AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetrizoic acid', 'V08AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylcarnitine', 'N06BX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylcholine', 'S01EB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylcholine chloride', 'S01EB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylcysteine', 'V03AB23');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylcysteine', 'R05CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylcysteine', 'S01XA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetyldigitoxin', 'C01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetyldigoxin', 'C01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetyldigoxin, combinations', 'C01AA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylglycinamide chloral hydrate', 'N05CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylleucine', 'N07CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylsalicylic acid', 'A01AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylsalicylic acid', 'B01AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylsalicylic acid', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylsalicylic acid', 'N02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylsalicylic acid and corticosteroids', 'M01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylsalicylic acid, comb. excl. psycholeptics', 'N02BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylsalicylic acid, comb. with psycholeptics', 'N02BA71');
INSERT INTO staging.atc (description, atc_code) VALUES ('aciclovir', 'D06BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aciclovir', 'J05AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aciclovir', 'S01AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aciclovir, combinations', 'D06BB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('acid preparations', 'A09AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('acidifiers', 'G04BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('acipimox', 'C10AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('acitretin', 'D05BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('aclarubicin', 'L01DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('acridine derivatives', 'D08AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('acriflavinium chloride', 'R02AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('acrivastine', 'R06AX18');
INSERT INTO staging.atc (description, atc_code) VALUES ('acth', 'H01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('actinomycines', 'L01DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('acyclovir', 'J05AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acyclovir', 'D06BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('acyclovir (acyclovir sodium)', 'J05AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('adalimumab', 'L04AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('adamantane derivatives', 'N04BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('adapalene', 'D10AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('adefovir dipivoxil', 'J05AF08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ademetionine', 'A16AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('adenine', 'V07AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('adenosine', 'C01EB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('adinazolam', 'N05BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('adipiodone', 'V08AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('adrafinil', 'N06BX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('adrenalone', 'B02BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('adrenalone', 'A01AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('adrenergic and dopaminergic agents', 'C01CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('adrenergics and other drugs for obstructive airway diseases', 'R03AK');
INSERT INTO staging.atc (description, atc_code) VALUES ('adrenergics and other drugs for obstructive airway diseases', 'R03CK');
INSERT INTO staging.atc (description, atc_code) VALUES ('adrenergics for systemic use', 'R03C');
INSERT INTO staging.atc (description, atc_code) VALUES ('adrenergics, inhalants', 'R03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('afelimomab', 'L04AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('agalsidase alfa', 'A16AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('agalsidase beta', 'A16AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('agents acting on the renin-angiotensin system', 'C09');
INSERT INTO staging.atc (description, atc_code) VALUES ('agents against amoebiasis and other protozoal diseases', 'P01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('agents against leishmaniasis and trypanosomiasis', 'P01C');
INSERT INTO staging.atc (description, atc_code) VALUES ('agents for atopic dermatitis, excluding corticosteroids', 'D11AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('agents posing risk during smoking cessation', 'ZXX0118');
INSERT INTO staging.atc (description, atc_code) VALUES ('agents predisposing to torsades de pointes', 'ZXX0115');
INSERT INTO staging.atc (description, atc_code) VALUES ('agents used by vaginal route', 'ZXX0117');
INSERT INTO staging.atc (description, atc_code) VALUES ('agents used in photodynamic therapy', 'L01XD');
INSERT INTO staging.atc (description, atc_code) VALUES ('agents which lower seizure thresholds', 'ZXX0111');
INSERT INTO staging.atc (description, atc_code) VALUES ('agomelatine', 'N06AX22');
INSERT INTO staging.atc (description, atc_code) VALUES ('air', 'V03AN05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ajmaline', 'C01BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('alanine', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('alanyl glutamine', 'B05XB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('alaproclate', 'N06AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('albendazole', 'P02CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('albumin', 'B05AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('albumin (human)', 'B05AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('albumin (human)', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('albumin tannate', 'A07XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('albumin tannate, combinations', 'A07XA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('alclofenac', 'M01AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('alclometasone', 'D07AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('alclometasone', 'S01BA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('alcohol anhydrous', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('alcohol anhydrous', 'V03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('alcohol anhydrous', 'V03AZ01');
INSERT INTO staging.atc (description, atc_code) VALUES ('alcohol anhydrous', 'B05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('alcohol anhydrous', 'D08AJ51');
INSERT INTO staging.atc (description, atc_code) VALUES ('alcohol consumption', 'ZXX0054');
INSERT INTO staging.atc (description, atc_code) VALUES ('alcohol denatured', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('alcuronium', 'M03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aldehydes and derivatives', 'N05CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('aldesleukin', 'L03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aldesulfone sodium', 'J04BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aldose reductase inhibitors', 'A10XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('aldosterone', 'H02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aldosterone antagonists', 'C03DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('alefacept', 'L04AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('alemtuzumab', 'L01XC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('alendronic acid', 'M05BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('alendronic acid (alendronate sodium trihydrate)', 'M05BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('alfa1 antitrypsin', 'B02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('alfacalcidol', 'A11CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('alfaxalone', 'N01AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('alfentanil', 'N01AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('alfentanil (alfentanil hydrochloride)', 'N01AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('alfuzosin', 'G04CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('alfuzosin and finasteride', 'G04CA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('alfuzosin hydrochloride', 'G04CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('algeldrate', 'A02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('alginic acid', 'A02BX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('alglucerase', 'A16AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('alglucosidase alfa', 'A16AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('alimemazine', 'R06AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('alimentary tract and metabolism', 'A');
INSERT INTO staging.atc (description, atc_code) VALUES ('aliskiren', 'C09XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('aliskiren (aliskiren fumarate)', 'C09XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('aliskiren and hydrochlorothiazide', 'C09XA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('alitretinoin', 'L01XX22');
INSERT INTO staging.atc (description, atc_code) VALUES ('alitretinoin', 'D11AX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('alizapride', 'A03FA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('alkaloids, excl. rauwolfia', 'C02KA');
INSERT INTO staging.atc (description, atc_code) VALUES ('alkaloids, excl. rauwolfia, in combination with diuretics', 'C02LK');
INSERT INTO staging.atc (description, atc_code) VALUES ('alkyl dimethyl benzyl ammonium saccharinate', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'D08AJ51');
INSERT INTO staging.atc (description, atc_code) VALUES ('alkyl sulfonates', 'L01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('alkylating agents', 'L01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('all other non-therapeutic products', 'V07');
INSERT INTO staging.atc (description, atc_code) VALUES ('all other non-therapeutic products', 'V07A');
INSERT INTO staging.atc (description, atc_code) VALUES ('all other therapeutic products', 'V03');
INSERT INTO staging.atc (description, atc_code) VALUES ('all other therapeutic products', 'V03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('allantoin', 'D04AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('allergen extract - alum precipitated', 'V01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('allergen extract - diagnostic', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('allergen extracts', 'V01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('allergenic extract non-pollen', 'V01AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('allergenic extracts', 'V01AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('allergenic extracts pollens', 'V01AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('allergens', 'V01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('allergens', 'V01');
INSERT INTO staging.atc (description, atc_code) VALUES ('allobarbital', 'N05CA21');
INSERT INTO staging.atc (description, atc_code) VALUES ('allopurinol', 'M04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('allopurinol, combinations', 'M04AA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('allylestrenol', 'G03DC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('almagate', 'A02AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('almasilate', 'A02AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('alminoprofen', 'M01AE16');
INSERT INTO staging.atc (description, atc_code) VALUES ('almitrine', 'R07AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('almotriptan', 'N02CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('almotriptan (almotriptan malate)', 'N02CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('alogliptin', 'A10BH04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aloglutamol', 'A02AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('alosetron', 'A03AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aloxiprin', 'B01AC15');
INSERT INTO staging.atc (description, atc_code) VALUES ('aloxiprin', 'N02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha agonists (oral and nasal routes)', 'ZXX0140');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha and beta agonists (im and iv routes)', 'ZXX0141');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha and beta blocking agents', 'C07AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha and beta blocking agents and other diuretics', 'C07CG');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha and beta blocking agents and thiazides', 'C07BG');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha blockers for urologic use (except doxazosin)', 'ZXX0009');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha blocking antihypertensives', 'ZXX0034');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha glucosidase inhibitors', 'A10BF');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha- and beta-adrenoreceptor agonists', 'R03CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha- and beta-adrenoreceptor agonists', 'R03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha-adrenoreceptor antagonists', 'G04CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha-adrenoreceptor antagonists', 'C02CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha-adrenoreceptor antagonists and diuretics', 'C02LE');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha1-proteinase inhibitor (human)', 'B02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('alprazolam', 'N05BA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('alprenolol', 'C07AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('alprostadil', 'G04BX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('alprostadil', 'G04BE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('alprostadil', 'C01EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('alsactide', 'V04CH04');
INSERT INTO staging.atc (description, atc_code) VALUES ('alteplase', 'B01AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('alteplase', 'S01XA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('althea root', 'R05CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('altizide and potassium-sparing agents', 'C03EA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('altretamine', 'L01XX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('alum', 'S01XA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium (sels des topiques gastro-intestinaux)', 'Z01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium acetoacetate', 'A02AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium acetotartrate', 'S02AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium acetotartrate', 'C05AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium agents', 'D08AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium chloride', 'D10AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium chlorohydrate', 'D09AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium chlorohydrate', 'M05BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium clofibrate', 'C10AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium compounds', 'A02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium glycinate', 'A02AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium hydroxide', 'A02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium nicotinate', 'C10AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium oxide', 'D10AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium phosphate', 'A02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('alverine', 'A03AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('alverine, combinations', 'A03AX58');
INSERT INTO staging.atc (description, atc_code) VALUES ('alvimopan', 'A06AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('amantadine', 'N04BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amantadine hydrochloride', 'N04BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ambazone', 'R02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ambenonium', 'N07AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('ambrisentan', 'C02KX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ambroxol', 'R05CB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ambutonium and psycholeptics', 'A03CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('amcinonide', 'D07AC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('amfepramone', 'A08AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('amfetamine', 'N06BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amides', 'N01BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('amifampridine', 'N07XX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('amifostine', 'V03AF05');
INSERT INTO staging.atc (description, atc_code) VALUES ('amikacin', 'J01GB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('amikacin', 'S01AA21');
INSERT INTO staging.atc (description, atc_code) VALUES ('amikacin', 'D06AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('amikacin (amikacin sulfate)', 'J01GB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('amiloride', 'C03DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amineptine', 'N06AA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('amino acids', 'B05XB');
INSERT INTO staging.atc (description, atc_code) VALUES ('amino acids', 'B05BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amino acids', 'B02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('amino acids and derivatives', 'A16AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('amino acids, incl. combinations with polypeptides', 'V06DD');
INSERT INTO staging.atc (description, atc_code) VALUES ('amino acids/carbohydrates/minerals/vitamins, combinations', 'V06DE');
INSERT INTO staging.atc (description, atc_code) VALUES ('amino(diphenylhydantoin) valeric acid', 'N03AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminoacridine', 'D08AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminoalkyl ethers', 'R06AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminobenzoic acid', 'D02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminobutyric acid', 'N03AG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminocaproic acid', 'B02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminoglutethimide', 'L02BG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminoglycoside antibacterials', 'J01G');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminoglycosides', 'ZXX0010');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminohippuric acid', 'V04CH30');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminolevulinic acid', 'L01XD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminolevulinic acid hydrochloride', 'L01XD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminomethylbenzoic acid', 'B02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminophenazone', 'N02BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminophenazone, combinations excl. psycholeptics', 'N02BB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminophenazone, combinations with psycholeptics', 'N02BB73');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminophylline', 'R03DA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminophylline and adrenergics', 'R03DB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminophylline, combinations', 'R03DA55');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminoquinolines', 'P01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminosalicylic acid', 'J04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminosalicylic acid (asa) derivatives', 'ZXX0070');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminosalicylic acid and derivatives', 'J04AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminosalicylic acid and similar agents', 'A07EC');
INSERT INTO staging.atc (description, atc_code) VALUES ('amiodarone', 'C01BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amiodarone hydrochloride', 'C01BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amisulpride', 'N05AL05');
INSERT INTO staging.atc (description, atc_code) VALUES ('amitriptyline', 'N06AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('amitriptyline and psycholeptics', 'N06CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amitriptyline hydrochloride', 'N06AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('amlexanox', 'R03DX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amlexanox', 'A01AD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('amlodipine', 'C08CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ammonium chloride', 'G04BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ammonium chloride', 'B05XA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ammonium hydroxide', 'M02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('amobarbital', 'N05CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('amodiaquine', 'P01BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('amorolfine', 'D01AE16');
INSERT INTO staging.atc (description, atc_code) VALUES ('amoxapine', 'N06AA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('amoxicillin', 'J01CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('amoxicillin (amoxicillin)', 'J01CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('amoxicillin and enzyme inhibitor', 'J01CR02');
INSERT INTO staging.atc (description, atc_code) VALUES ('amphenicols', 'J01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('amphenicols', 'J01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('amphotericin', 'A01AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('amphotericin b', 'G01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('amphotericin b', 'J02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amphotericin b', 'A07AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ampicillin', 'J01CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ampicillin', 'S01AA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('ampicillin (ampicillin sodium)', 'J01CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ampicillin and enzyme inhibitor', 'J01CR01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ampicillin, combinations', 'J01CA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('amprenavir', 'J05AE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('amprenavir (and, by extrapolation, fosamprenavir)', 'ZXX0011');
INSERT INTO staging.atc (description, atc_code) VALUES ('amrinone', 'C01CE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amsacrine', 'L01XX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amyl cinnamal', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('amyl nitrite', 'V03AB22');
INSERT INTO staging.atc (description, atc_code) VALUES ('amylase', 'A09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('anabolic agents for systemic use', 'A14');
INSERT INTO staging.atc (description, atc_code) VALUES ('anabolic steroids', 'A14A');
INSERT INTO staging.atc (description, atc_code) VALUES ('anagrelide', 'L01XX35');
INSERT INTO staging.atc (description, atc_code) VALUES ('anagrelide (anagrelide hydrochloride monohydrate)', 'L01XX35');
INSERT INTO staging.atc (description, atc_code) VALUES ('anagrelide (anagrelide hydrochloride)', 'L01XX35');
INSERT INTO staging.atc (description, atc_code) VALUES ('anakinra', 'L04AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('analgesics', 'N02');
INSERT INTO staging.atc (description, atc_code) VALUES ('analgesics and anesthetics', 'S02DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('analgesics opiod agonists', 'ZXX0012');
INSERT INTO staging.atc (description, atc_code) VALUES ('anastrozole', 'L02BG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ancestim', 'L03AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('ancrod', 'B01AD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('androgen, progestogen and estrogen in combination', 'G03EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('androgens', 'ZXX0016');
INSERT INTO staging.atc (description, atc_code) VALUES ('androgens', 'G03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('androgens and estrogens', 'G03EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('androgens and female sex hormones in combination', 'G03E');
INSERT INTO staging.atc (description, atc_code) VALUES ('androgens and female sex hormones in combination with other drugs', 'G03EK');
INSERT INTO staging.atc (description, atc_code) VALUES ('androgens for topical use', 'D11AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('androstan derivatives', 'A14AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('androstanolone', 'G03BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('androstanolone', 'A14AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('anecortave', 'S01LA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('anesthetics', 'N01');
INSERT INTO staging.atc (description, atc_code) VALUES ('anesthetics for topical use', 'D04AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('anesthetics, general', 'N01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('anesthetics, local', 'R02AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('anesthetics, local', 'N01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('anethole trithione', 'A16AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('angiotensin ii antagonists and diuretics', 'C09DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('angiotensin ii antagonists, combinations', 'C09D');
INSERT INTO staging.atc (description, atc_code) VALUES ('angiotensin ii antagonists, other combinations', 'C09DX');
INSERT INTO staging.atc (description, atc_code) VALUES ('angiotensin ii antagonists, plain', 'C09CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('angiotensin ii antagonists, plain', 'C09C');
INSERT INTO staging.atc (description, atc_code) VALUES ('angiotensin ii receptor antagonists', 'ZXX0020');
INSERT INTO staging.atc (description, atc_code) VALUES ('angiotensinamide', 'C01CX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('anidulafungin', 'J02AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('anileridine', 'N01AH05');
INSERT INTO staging.atc (description, atc_code) VALUES ('anilides', 'N02BE');
INSERT INTO staging.atc (description, atc_code) VALUES ('animals', 'V01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('aniracetam', 'N06BX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('anistreplase', 'B01AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('antabuse (reaction)', 'ZXX0018');
INSERT INTO staging.atc (description, atc_code) VALUES ('antacids', 'A02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antacids with antiflatulents', 'A02AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('antacids with antispasmodics', 'A02AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('antacids with sodium bicarbonate', 'A02AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('antacids, other combinations', 'A02AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('antazoline', 'R06AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('antazoline', 'R01AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('anterior pituitary lobe hormones and analogues', 'H01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('anthelmintics', 'P02');
INSERT INTO staging.atc (description, atc_code) VALUES ('anthracyclines and related substances', 'L01DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('anthrax antigen', 'J07AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('anthrax vaccines', 'J07AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('anti-acne preparations', 'D10');
INSERT INTO staging.atc (description, atc_code) VALUES ('anti-acne preparations for systemic use', 'D10B');
INSERT INTO staging.atc (description, atc_code) VALUES ('anti-acne preparations for topical use', 'D10A');
INSERT INTO staging.atc (description, atc_code) VALUES ('anti-androgens', 'L02BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('anti-d (rh) immunoglobulin', 'J06BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('anti-dementia drugs', 'N06D');
INSERT INTO staging.atc (description, atc_code) VALUES ('anti-estrogens', 'L02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('anti-gonadotropin-releasing hormones', 'H01CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('anti-parathyroid hormones', 'H05B');
INSERT INTO staging.atc (description, atc_code) VALUES ('anti-parkinson drugs', 'N04');
INSERT INTO staging.atc (description, atc_code) VALUES ('anti-thymocyte globulin (rabbit)', 'L04AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiadrenal preparations', 'H02C');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiadrenergic agents, centrally acting', 'C02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiadrenergic agents, ganglion-blocking', 'C02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiadrenergic agents, peripherally acting', 'C02C');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiallergic agents, excl. corticosteroids', 'R03BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiallergic agents, excl. corticosteroids', 'A07EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiallergic agents, excl. corticosteroids', 'R01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiandrogens', 'G03H');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiandrogens and estrogens', 'G03HB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiandrogens, plain', 'G03HA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antianemic preparations', 'B03');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiarrhythmics', 'ZXX0023');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiarrhythmics, class i and iii', 'C01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiarrhythmics, class ia', 'C01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiarrhythmics, class ib', 'C01BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiarrhythmics, class ic', 'C01BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiarrhythmics, class iii', 'C01BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibacterials for systemic use', 'J01');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotics', 'A07AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotics', 'R02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotics', 'S01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotics', 'G01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotics', 'J04AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotics', 'J02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotics', 'D01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotics and chemotherapeutics for dermatological use', 'D06');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotics and chemotherapeutics, combinations', 'D06C');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotics and corticosteroids', 'G01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotics for topical use', 'D06A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotics in combination with other drugs', 'S01AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('anticestodals', 'P02D');
INSERT INTO staging.atc (description, atc_code) VALUES ('anticholinergic agents', 'N04A');
INSERT INTO staging.atc (description, atc_code) VALUES ('anticholinergic anti-parkinson drugs', 'ZXX0038');
INSERT INTO staging.atc (description, atc_code) VALUES ('anticholinergics', 'S01FA');
INSERT INTO staging.atc (description, atc_code) VALUES ('anticholinergics', 'R03BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('anticholinesterases', 'N07AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('anticholinesterases', 'ZXX0026');
INSERT INTO staging.atc (description, atc_code) VALUES ('anticholinesterases', 'N06DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('anticorticosteroids', 'H02CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antidepressants', 'N06A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antidepressants in combination with psycholeptics', 'N06CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antidiarrheal microorganisms', 'A07F');
INSERT INTO staging.atc (description, atc_code) VALUES ('antidiarrheal microorganisms', 'A07FA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antidiarrheals, intestinal antiinflammatory/antiinfective agents', 'A07');
INSERT INTO staging.atc (description, atc_code) VALUES ('antidotes', 'V03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiemetic neuroleptics', 'ZXX0121');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiemetics and antinauseants', 'A04A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiemetics and antinauseants', 'A04');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiepileptics', 'N03');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiepileptics', 'N03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antifibrinolytics', 'B02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antifungals for dermatological use', 'D01');
INSERT INTO staging.atc (description, atc_code) VALUES ('antifungals for systemic use', 'D01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antifungals for systemic use', 'D01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antifungals for topical use', 'D01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiglaucoma preparations and miotics#', 'S01E');
INSERT INTO staging.atc (description, atc_code) VALUES ('antigonadotropins and similar agents', 'G03XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antigout preparations', 'M04');
INSERT INTO staging.atc (description, atc_code) VALUES ('antigout preparations', 'M04A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antigrowth hormone', 'H01CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihemophilic factor (recombinant)', 'B02BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihemorrhagics', 'B02');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihemorrhoidals for topical use', 'C05A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihidrotics', 'D11AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihistamines for systemic use', 'R06A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihistamines for systemic use', 'R06');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihistamines for topical use', 'D04AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihistaminic h2-receptor antagonists', 'ZXX0041');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihypertensive drugs', 'ZXX0033');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihypertensives', 'C02');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihypertensives and diuretics in combination', 'C02L');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihypertensives except alpha-blockers', 'ZXX0036');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfectives', 'S03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfectives', 'S02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfectives', 'S01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfectives', 'B05CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfectives', 'S03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfectives', 'S02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfectives and antiseptics for local oral treatment', 'A01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfectives and antiseptics, excl. combinations with corticosteroids', 'G01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfectives for systemic use', 'J');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfectives for treatment of acne', 'D10AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfectives, combinations', 'S03AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfectives, combinations', 'S02AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfectives/antiseptics in combination with corticosteroids', 'G01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinflammatory agents', 'V10A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinflammatory agents', 'S01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinflammatory agents and antiinfectives in combination', 'S01C');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinflammatory agents, non-steroids', 'S01BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinflammatory agents, non-steroids and antiinfectives in combination', 'S01CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinflammatory and antirheumatic products', 'M01');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinflammatory and antirheumatic products, non-steroids', 'M01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinflammatory preparations, non-steroids for topical use', 'M02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinflammatory products for vaginal administration', 'G02CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinflammatory/antirheumatic agents in combination', 'M01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinflammatory/antirheumatic agents in combination with corticosteroids', 'M01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antilymphocyte globulins', 'ZXX0080');
INSERT INTO staging.atc (description, atc_code) VALUES ('antilymphocyte immunoglobulin (horse)', 'L04AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimalarials', 'P01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimetabolites', 'L01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimigraine preparations', 'N02C');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimony compounds', 'P01CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimony pentasulfide', 'R05CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimycobacterials', 'J04');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimycotics for systemic use', 'J02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimycotics for systemic use', 'J02');
INSERT INTO staging.atc (description, atc_code) VALUES ('antineavascularisation agents', 'S01LA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antinematodal agents', 'P02C');
INSERT INTO staging.atc (description, atc_code) VALUES ('antineoplastic agents', 'L01');
INSERT INTO staging.atc (description, atc_code) VALUES ('antineoplastic and immunomodulating agents', 'L');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiobesity preparations, excl. diet products', 'A08');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiobesity preparations, excl. diet products', 'A08A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiparasitic agents predisposing to torsades de pointes', 'ZXX0037');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiparasitic products, insecticides and repellents', 'P');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiprogestogens', 'G03XB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antipropulsives', 'A07D');
INSERT INTO staging.atc (description, atc_code) VALUES ('antipropulsives', 'A07DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiprotozoals', 'P01');
INSERT INTO staging.atc (description, atc_code) VALUES ('antipruritics, incl. antihistamines, anesthetics, etc.', 'D04A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antipruritics, incl. antihistamines, anesthetics, etc.', 'D04');
INSERT INTO staging.atc (description, atc_code) VALUES ('antipsoriatics', 'D05');
INSERT INTO staging.atc (description, atc_code) VALUES ('antipsoriatics for systemic use', 'D05B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antipsoriatics for topical use', 'D05A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antipsychotic neuroleptics (except clozapine)', 'ZXX0120');
INSERT INTO staging.atc (description, atc_code) VALUES ('antipsychotics', 'N05A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiseptics', 'R02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiseptics and corticosteroids', 'G01BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiseptics and disinfectants', 'D08');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiseptics and disinfectants', 'D08A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antispasmodics and anticholinergics in combination with other drugs', 'A03E');
INSERT INTO staging.atc (description, atc_code) VALUES ('antispasmodics in combination with analgesics', 'A03D');
INSERT INTO staging.atc (description, atc_code) VALUES ('antispasmodics in combination with other drugs', 'A03ED');
INSERT INTO staging.atc (description, atc_code) VALUES ('antispasmodics in combination with psycholeptics', 'A03C');
INSERT INTO staging.atc (description, atc_code) VALUES ('antispasmodics, psycholeptics and analgesics in combination', 'A03EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antithrombin iii', 'B01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('antithrombin iii (human)', 'B01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('antithrombotic agents', 'B01');
INSERT INTO staging.atc (description, atc_code) VALUES ('antithrombotic agents', 'B01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antithymocyte immunoglobulin (rabbit)', 'L04AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('antithyroid preparations', 'H03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antitrematodals', 'P02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antivaricose therapy', 'C05B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antivertigo preparations', 'N07CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antivertigo preparations', 'N07C');
INSERT INTO staging.atc (description, atc_code) VALUES ('antivirals', 'S01AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('antivirals', 'D06BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antivirals for systemic use', 'J05');
INSERT INTO staging.atc (description, atc_code) VALUES ('antracen derivatives', 'D05AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('anxiolytics', 'N05B');
INSERT INTO staging.atc (description, atc_code) VALUES ('apis mellifera venom protein extract', 'V01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('apomorphine', 'G04BE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('apomorphine', 'N04BC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('appetite stimulants', 'A15');
INSERT INTO staging.atc (description, atc_code) VALUES ('apraclonidine', 'S01EA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('apraclonidine (apraclonidine hydrochloride)', 'S01EA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aprepitant', 'A04AD12');
INSERT INTO staging.atc (description, atc_code) VALUES ('aprindine', 'C01BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aprobarbital', 'N05CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('apronal', 'N05CM12');
INSERT INTO staging.atc (description, atc_code) VALUES ('aprotinin', 'B02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aprotinin (bovine)', 'B02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('arbutamine', 'C01CA22');
INSERT INTO staging.atc (description, atc_code) VALUES ('argatroban', 'B01AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('arginine', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('arginine glutamate', 'A05BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('arginine hydrochloride', 'B05XB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('arginine hydrochloride', 'V04CD');
INSERT INTO staging.atc (description, atc_code) VALUES ('argipressin', 'H01BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('aripiprazole', 'N05AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('arsenic compounds', 'G01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('arsenic compounds', 'P01AR');
INSERT INTO staging.atc (description, atc_code) VALUES ('arsenic compounds', 'P01CD');
INSERT INTO staging.atc (description, atc_code) VALUES ('arsenic trioxide', 'L01XX27');
INSERT INTO staging.atc (description, atc_code) VALUES ('arsthinol', 'P01AR01');
INSERT INTO staging.atc (description, atc_code) VALUES ('artemether', 'P01BE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('artemether, combinations', 'P01BE52');
INSERT INTO staging.atc (description, atc_code) VALUES ('artemisinin', 'P01BE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('artemisinin and derivatives', 'P01BE');
INSERT INTO staging.atc (description, atc_code) VALUES ('artemotil', 'P01BE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('artenimol', 'P01BE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('arteriolar smooth muscle, agents acting on', 'C02D');
INSERT INTO staging.atc (description, atc_code) VALUES ('artesunate', 'P01BE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('articaine', 'N01BB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('articaine, combinations', 'N01BB58');
INSERT INTO staging.atc (description, atc_code) VALUES ('artificial tears and other indifferent preparations', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('aryloxyacetic acid derivatives', 'C03CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('ascorbic acid', 'S01XA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('ascorbic acid', 'G01AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ascorbic acid (vit c)', 'A11GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ascorbic acid (vit c) and calcium', 'A11GB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ascorbic acid (vitamin c), combinations', 'A11GB');
INSERT INTO staging.atc (description, atc_code) VALUES ('ascorbic acid (vitamin c), incl. combinations', 'A11G');
INSERT INTO staging.atc (description, atc_code) VALUES ('ascorbic acid (vitamin c), plain', 'A11GA');
INSERT INTO staging.atc (description, atc_code) VALUES ('asenapine', 'N05AH05');
INSERT INTO staging.atc (description, atc_code) VALUES ('asparaginase', 'L01XX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('astemizole', 'R06AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('atazanavir', 'J05AE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('atazanavir (atazanavir sulfate)', 'J05AE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('atenolol', 'C07AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('atenolol and other antihypertensives', 'C07FB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('atenolol and other diuretics', 'C07CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('atenolol and other diuretics, combinations', 'C07CB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('atenolol and thiazides', 'C07BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('atenolol, thiazides and other diuretics', 'C07DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('atomoxetine', 'N06BA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('atorvastatin', 'C10AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('atorvastatin (atorvastatin calcium propylene glycol solvate)', 'C10AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('atorvastatin and amlodipine', 'C10BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('atosiban', 'G02CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('atovaquone', 'P01AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('atracurium', 'M03AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('atracurium besylate', 'M03AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('atropine', 'S01FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('atropine', 'A03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('atropine and psycholeptics', 'A03CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('atropine sulfate', 'A03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('atropine sulfate', 'S01FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('atropinic agents', 'ZXX0112');
INSERT INTO staging.atc (description, atc_code) VALUES ('attapulgite', 'A07BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('attapulgite, combinations', 'A07BC54');
INSERT INTO staging.atc (description, atc_code) VALUES ('auranofin', 'M01CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aurothioglucose', 'M01CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aurotioprol', 'M01CB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('avermectines', 'P02CF');
INSERT INTO staging.atc (description, atc_code) VALUES ('avizafone', 'Z01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('avizafone', 'Z01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('avobenzone', 'D11AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('avobenzone', 'D06BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('azacitidine', 'L01BC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('azanidazole', 'P01AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('azanidazole', 'G01AF13');
INSERT INTO staging.atc (description, atc_code) VALUES ('azapetine', 'C04AX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('azapropazone', 'M01AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('azaspirodecanedione derivatives', 'N05BE');
INSERT INTO staging.atc (description, atc_code) VALUES ('azatadine', 'R06AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('azathioprine', 'L04AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('azathioprine (azathioprine sodium)', 'L04AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('azelaic acid', 'D10AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('azelastine', 'R06AX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('azelastine', 'S01GX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('azelastine', 'R01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('azidamfenicol', 'S01AA25');
INSERT INTO staging.atc (description, atc_code) VALUES ('azidocillin', 'J01CE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('azithromycin', 'J01FA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('azithromycin', 'S01AA26');
INSERT INTO staging.atc (description, atc_code) VALUES ('azithromycin (azithromycin dihydrate)', 'J01FA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('azithromycin (azithromycin hydrogen citrate)', 'J01FA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('azithromycin (azithromycin isopropanolate monohydrate)', 'J01FA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('azithromycin (azithromycin monohydrate)', 'J01FA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('azlocillin', 'J01CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('azole antifungals', 'ZXX0032');
INSERT INTO staging.atc (description, atc_code) VALUES ('aztreonam', 'J01DF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bacampicillin', 'J01CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('bacillus calmette-guerin (bcg) strain tice', 'L03AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bacillus calmette-guerin (bcg) substrain connaught', 'J07AN01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bacillus calmette-guerin (bcg) substrain connaught', 'L03AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bacitracin', 'R02AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('bacitracin', 'J01XX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('bacitracin', 'D06AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('bacitracin (bacitracin zinc)', 'D06AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('bacitracin zinc', 'D06AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('baclofen', 'M03BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bacterial and viral vaccines, combined', 'J07C');
INSERT INTO staging.atc (description, atc_code) VALUES ('bacterial and viral vaccines, combined', 'J07CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('bacterial vaccines', 'J07A');
INSERT INTO staging.atc (description, atc_code) VALUES ('balsalazide', 'A07EC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('bambuterol', 'R03CC12');
INSERT INTO staging.atc (description, atc_code) VALUES ('bamethan', 'C04AA31');
INSERT INTO staging.atc (description, atc_code) VALUES ('bamifylline', 'R03DA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('bamipine', 'R06AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bamipine', 'D04AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbexaclone', 'N03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbital', 'N05CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbiturates', 'ZXX0046');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbiturates and derivatives', 'N03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbiturates in combination with other drugs', 'N05CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbiturates in combination with other drugs', 'N01AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbiturates, combinations', 'N05CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbiturates, plain', 'N05CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbiturates, plain', 'N01AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('barium sulfate containing x-ray contrast media', 'V08BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('barium sulfate with suspending agents', 'V08BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('barium sulfate without suspending agents', 'V08BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('barnidipine', 'C08CA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('basiliximab', 'L04AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('batroxobin', 'B02BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bazedoxifene', 'G03XC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bcg vaccine', 'L03AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('becaplermin', 'A01AD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('becaplermin', 'D03AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('beclamide', 'N03AX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('beclometasone', 'R01AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('beclometasone', 'R03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('beclometasone', 'D07AC15');
INSERT INTO staging.atc (description, atc_code) VALUES ('beclometasone', 'A07EA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('beclometasone and antibiotics', 'D07CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('beclomethasone dipropionate', 'R01AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('beclomethasone dipropionate', 'D07AC15');
INSERT INTO staging.atc (description, atc_code) VALUES ('beclomethasone dipropionate', 'R03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('befunolol', 'S01ED06');
INSERT INTO staging.atc (description, atc_code) VALUES ('belimumab', 'L04AA26');
INSERT INTO staging.atc (description, atc_code) VALUES ('belladonna alkaloids, semisynthetic, quaternary ammonium compounds', 'A03BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('belladonna alkaloids, tertiary amines', 'A03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('belladonna and derivatives in combination with analgesics', 'A03DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('belladonna and derivatives in combination with psycholeptics', 'A03CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('belladonna and derivatives, plain', 'A03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('belladonna total alkaloids', 'A03BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('belladonna total alkaloids and psycholeptics', 'A03CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bemegride', 'R07AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('bemiparin', 'B01AB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('benazepril', 'C09AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('benazepril and diuretics', 'C09BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('benazepril hydrochloride', 'C09AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bencyclane', 'C04AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('bendamustine', 'L01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('bendazac', 'M02AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('bendazac', 'S01BC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bendroflumethiazide', 'C03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bendroflumethiazide and potassium', 'C03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bendroflumethiazide and potassium-sparing agents', 'C03EA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('benethamine-penicilline', 'Z01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('benfluorex', 'A10BX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('benidipine', 'C08CA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('benorilate', 'N02BA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('benoxaprofen', 'M01AE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('benperidol', 'N05AD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('benproperine', 'R05DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bentiromide', 'V04CK03');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzalkonium', 'R02AA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzalkonium', 'D09AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzalkonium', 'D08AJ01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzalkonium chloride', 'D04AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzalkonium chloride', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzalkonium chloride', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzalkonium chloride', 'D08AJ01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzalkonium chloride', 'D08AJ51');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzamides', 'N05AL');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzathine benzylpenicillin', 'J01CE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzathine phenoxymethylpenicillin', 'J01CE10');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzatropine', 'N04AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzbromarone', 'M04AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzethonium', 'R02AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzethonium chloride', 'D08AJ08');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzethonium chloride', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzethonium chloride, combinations', 'D08AJ58');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzilone', 'A03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzimidazole derivatives', 'P02CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('benziodarone', 'C01DX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('benziodarone, combinations', 'C01DX54');
INSERT INTO staging.atc (description, atc_code) VALUES ('benznidazole', 'P01CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzocaine', 'C05AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzocaine', 'N01BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzocaine', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzocaine', 'R02AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzocaine', 'R02AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzocaine', 'D04AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzoctamine', 'N05BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzodiazepine derivatives', 'N05BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzodiazepine derivatives', 'N05CD');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzodiazepine derivatives', 'N03AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzodiazepine related drugs', 'N05CF');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzodiazepines and related', 'ZXX0047');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzododecinium', 'D09AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzoin', 'D08AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzomorphan derivatives', 'N02AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzonatate', 'R05DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzothiazepine derivatives', 'C08DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzoxonium chloride', 'A01AB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzoxonium chloride', 'D08AJ05');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzoyl peroxide', 'D10AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzoyl peroxide, combinations', 'D10AE51');
INSERT INTO staging.atc (description, atc_code) VALUES ('benztropine mesylate', 'N04AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzydamine', 'G02CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzydamine', 'M02AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzydamine', 'M01AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzydamine', 'A01AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzydamine hydrochloride', 'A01AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzyl benzoate', 'P03AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzyl di-hydroxyethyl-cocoalkyl-ammonium chl', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzyl paraben', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzylpenicillin', 'J01CE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzylpenicillin', 'S01AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzylthiouracil', 'H03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bephenium', 'P02CX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bepridil', 'C08EA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('beractant', 'R07AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('beraprost', 'B01AC19');
INSERT INTO staging.atc (description, atc_code) VALUES ('bergapten', 'D05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bermuda grass', 'V01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('besifloxacin', 'S01AX23');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents', 'C07');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents', 'S01ED');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents', 'C07A');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents (except esmolol and sotalol)', 'ZXX0051');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents (except esmolol)', 'ZXX0052');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents and other antihypertensives', 'C07F');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents and other diuretics', 'C07C');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents and thiazides', 'C07B');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents and vasodilators', 'C07E');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents in heart failure', 'ZXX0053');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents, non-selective', 'C07AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents, non-selective, and other antihypertensives', 'C07FA');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents, non-selective, and other diuretics', 'C07CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents, non-selective, and thiazides', 'C07BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents, non-selective, and vasodilators', 'C07EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents, non-selective, thiazides and other diuretics', 'C07DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents, selective', 'C07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents, selective, and other antihypertensives', 'C07FB');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents, selective, and other diuretics', 'C07CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents, selective, and thiazides', 'C07BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents, selective, and vasodilators', 'C07EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents, selective, thiazides and other diuretics', 'C07DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta blocking agents, thiazides and other diuretics', 'C07D');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-2 mimetics', 'ZXX0050');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-lactam antibacterials, penicillins', 'J01C');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-lactamase inhibitors', 'J01CG');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-lactamase resistant penicillins', 'J01CF');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-lactamase sensitive penicillins', 'J01CE');
INSERT INTO staging.atc (description, atc_code) VALUES ('betacarotene', 'A11CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('betacarotene', 'D02BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betahistine', 'N07CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betahistine hydrochloride', 'N07CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betaine', 'A16AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('betaine hydrochloride', 'A09AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone', 'S01CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone', 'S01BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone', 'R03BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone', 'H02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone', 'D07AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone', 'D07XC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone', 'S02BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone', 'C05AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone', 'S03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone', 'R01AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone', 'A07EA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone (betamethasone dipropionate)', 'D07AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone (betamethasone sodium phosphate)', 'A07EA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone (betamethasone valerate)', 'D07AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone and antibiotics', 'D07CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone and antiinfectives', 'S03CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone and antiinfectives', 'S01CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone and antiseptics', 'D07BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone and mydriatics', 'S01BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone dipropionate', 'D07AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethasone valerate', 'D07AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betanidine', 'C02CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betaxolol', 'S01ED02');
INSERT INTO staging.atc (description, atc_code) VALUES ('betaxolol', 'C07AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('betaxolol (betaxolol hydrochloride)', 'S01ED02');
INSERT INTO staging.atc (description, atc_code) VALUES ('betaxolol, combinations', 'S01ED52');
INSERT INTO staging.atc (description, atc_code) VALUES ('betazole', 'V04CG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bethanechol', 'N07AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bethanechol chloride', 'N07AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bevacizumab', 'L01XC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bevantolol', 'C07AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('bevantolol and thiazides', 'C07BB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('bevonium', 'A03AB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('bevonium and analgesics', 'A03DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bevonium and psycholeptics', 'A03CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('bexarotene', 'L01XX25');
INSERT INTO staging.atc (description, atc_code) VALUES ('bezafibrate', 'C10AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bezitramide', 'N02AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('biapenem', 'J01DH05');
INSERT INTO staging.atc (description, atc_code) VALUES ('bibenzonium bromide', 'R05DB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('bibrocathol', 'S01AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('bicalutamide', 'L02BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bietaserpine', 'C02AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bietaserpine and diuretics', 'C02LA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bietaserpine, combinations', 'C02AA57');
INSERT INTO staging.atc (description, atc_code) VALUES ('bifemelane', 'N06AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('bifonazole', 'D01AC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('bifonazole, combinations', 'D01AC60');
INSERT INTO staging.atc (description, atc_code) VALUES ('biguanides', 'P01BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('biguanides', 'A10BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('biguanides and amidines', 'D08AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('bile acid preparations', 'ZXX0004');
INSERT INTO staging.atc (description, atc_code) VALUES ('bile acid preparations', 'A05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('bile acid sequestrants', 'C10AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('bile and liver therapy', 'A05');
INSERT INTO staging.atc (description, atc_code) VALUES ('bile salts', 'A09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bile therapy', 'A05A');
INSERT INTO staging.atc (description, atc_code) VALUES ('bimatoprost', 'S01EE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bioallethrin', 'P03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bioallethrin, combinations', 'P03AC52');
INSERT INTO staging.atc (description, atc_code) VALUES ('bioflavonoids', 'C05CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('biotin', 'A11HA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('biperiden', 'N04AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bis(1-piperidylthiocarbonyl)disulfide', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisacodyl', 'A06AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisacodyl', 'A06AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisacodyl, combinations', 'A06AB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisantrene', 'Z01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bismuth dipropylacetate', 'R07AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('bismuth preparations', 'A07BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('bismuth preparations, combinations', 'C05AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bismuth subcitrate', 'A02BX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('bismuth subgallate', 'A07BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('bismuth subnitrate', 'A02BX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('bismuth subsalicylate', 'A07BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('bismuth tribromophenate', 'D09AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisoprolol', 'C07AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisoprolol and thiazides', 'C07BB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisoprolol fumarate', 'C07AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisoprolol, combinations', 'C07AB57');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisoxatin', 'A06AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisphosphonates', 'M05BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisphosphonates', 'ZXX0048');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisphosphonates and calcium, sequential preparations', 'M05BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisquaternary ammonium compounds', 'C02BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('bithionol', 'P02BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bithionol', 'D10AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bitolterol', 'R03AC17');
INSERT INTO staging.atc (description, atc_code) VALUES ('bivalirudin', 'B01AE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('bleomycin', 'L01DC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bleomycin (bleomycin sulfate)', 'L01DC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bleomycin sulfate', 'L01DC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('blood and blood forming organs', 'B');
INSERT INTO staging.atc (description, atc_code) VALUES ('blood and related products', 'B05A');
INSERT INTO staging.atc (description, atc_code) VALUES ('blood coagulation factors', 'B02BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('blood plasma', 'B05AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('blood substitutes and perfusion solutions', 'B05');
INSERT INTO staging.atc (description, atc_code) VALUES ('blood substitutes and plasma protein fractions', 'B05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('blood tests, auxiliary products', 'V07AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('blood transfusion, auxiliary products', 'V07AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('boldo', 'Z01AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('bone morphogenetic proteins', 'M05BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('bopindolol', 'C07AA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('bopindolol and other diuretics', 'C07CA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('boric acid', 'S02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('boric acid products', 'D08AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('bornaprine', 'N04AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('bortezomib', 'L01XX32');
INSERT INTO staging.atc (description, atc_code) VALUES ('bortezomib (bortezomib mannitol boronic ester)', 'L01XX32');
INSERT INTO staging.atc (description, atc_code) VALUES ('bosentan', 'C02KX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bosentan (bosentan monohydrate)', 'C02KX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('botulinum antitoxin', 'J06AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('botulinum toxin', 'M03AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('botulinum toxin type a', 'M03AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bourdaine', 'Z01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('bradycardic agents', 'ZXX0049');
INSERT INTO staging.atc (description, atc_code) VALUES ('bretylium tosilate', 'C01BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bretylium tosylate', 'C01BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('brimonidine', 'S01EA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('brimonidine tartrate', 'S01EA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('brinase', 'B01AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('brinzolamide', 'S01EC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('brodimoprim', 'J01EA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromazepam', 'N05BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromazine', 'R06AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromelains', 'B06AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromfenac', 'S01BC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromhexine', 'R05CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromides', 'N05CM11');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromine-phenol-benzethonium chloride complex', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromisoval', 'N05CM03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromochlorosalicylanilide', 'D01AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromocriptine', 'G02CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromocriptine', 'N04BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromocriptine (bromocriptine mesylate)', 'G02CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromocriptine mesylate', 'G02CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromopride', 'A03FA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromperidol', 'N05AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('brompheniramine', 'R06AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('brompheniramine, combinations', 'R06AB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('brotizolam', 'N05CD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('broxyquinoline', 'G01AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('broxyquinoline', 'P01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('broxyquinoline', 'A07AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('brucella antigen', 'J07AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('brucellosis vaccines', 'J07AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('bucetin', 'N02BE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('bucetin, combinations excl. psycholeptics', 'N02BE54');
INSERT INTO staging.atc (description, atc_code) VALUES ('bucetin, combinations with psycholeptics', 'N02BE74');
INSERT INTO staging.atc (description, atc_code) VALUES ('bucillamine', 'M01CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bucladesine', 'C01CE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('buclizine', 'R06AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('buclizine, combinations', 'R06AE51');
INSERT INTO staging.atc (description, atc_code) VALUES ('budesonide', 'R03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('budesonide', 'A07EA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('budesonide', 'D07AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('budesonide', 'R01AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('budipine', 'N04BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bufexamac', 'M01AB17');
INSERT INTO staging.atc (description, atc_code) VALUES ('bufexamac', 'M02AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('buffer solution', 'L01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('buflomedil', 'C04AX20');
INSERT INTO staging.atc (description, atc_code) VALUES ('buformin', 'A10BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bufylline', 'R03DA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('bulk producers', 'A06AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('bumadizone', 'M01AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bumetanide', 'C03CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bumetanide and potassium', 'C03CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bumetanide and potassium-sparing agents', 'C03EB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bunaftine', 'C01BD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('buphenine', 'G02CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('buphenine', 'C04AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bupivacaine', 'N01BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bupivacaine hydrochloride', 'N01BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bupivacaine, combinations', 'N01BB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('bupranolol', 'C07AA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('buprenorphin, combinations', 'N07BC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('buprenorphine', 'N02AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('buprenorphine', 'N07BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bupropion', 'N06AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('bupropion hydrochloride', 'N06AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('buserelin', 'L02AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('buserelin (buserelin acetate)', 'L02AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('buspirone', 'N05BE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('buspirone hydrochloride', 'N05BE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('busulfan', 'L01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('butalamine', 'C04AX23');
INSERT INTO staging.atc (description, atc_code) VALUES ('butalbital', 'Z01AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('butamirate', 'R05DB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('butanilicaine', 'N01BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('butaperazine', 'N05AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('butenafine', 'D01AE23');
INSERT INTO staging.atc (description, atc_code) VALUES ('butizide and potassium-sparing agents', 'C03EA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('butobarbital', 'N05CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('butoconazole', 'G01AF15');
INSERT INTO staging.atc (description, atc_code) VALUES ('butoconazole nitrate', 'G01AF15');
INSERT INTO staging.atc (description, atc_code) VALUES ('butorphanol', 'N02AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('butorphanol tartrate', 'N02AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('butoxy polyoxypropylene polyoxyethylene gly.iodine', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('butoxy polyoxypropylene polyoxyethylene gly.iodine', 'D08AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('butriptyline', 'N06AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('butylparaben', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('butylpyrazolidines', 'M01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('butylscopolamine', 'A03BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('butylscopolamine and analgesics', 'A03DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('butyrophenone derivatives', 'N05AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('c1-inhibitor', 'B02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cabazitaxel', 'L01CD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cabergoline', 'G02CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cabergoline', 'N04BC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cadexomer iodine', 'D03AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cadmium compounds', 'D11AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cadralazine', 'C02DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cafedrine', 'C01CA21');
INSERT INTO staging.atc (description, atc_code) VALUES ('caffeine', 'N06BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('caffeine and sodium benzoate', 'V04CG30');
INSERT INTO staging.atc (description, atc_code) VALUES ('calamine', 'D04AA32');
INSERT INTO staging.atc (description, atc_code) VALUES ('calamine', 'D04AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcifediol', 'A11CC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcineurin inhibitors', 'L04AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcipotriol', 'D05AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcipotriol, combinations', 'D05AX52');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcitonin (human synthetic)', 'H05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcitonin (pork natural)', 'H05BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcitonin (salmon synthetic)', 'H05BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcitonin preparations', 'H05BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcitriol', 'A11CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcitriol', 'D05AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium', 'A12AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium', 'A12A');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium (different salts in combination)', 'A12AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium acetate', 'V03AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium acetate anhydrous', 'A12AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium alginate', 'B02BC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium aminosalicylate', 'J04AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium carbimide', 'N07BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium carbonate', 'A02AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium carbonate', 'A12AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium channel antagonists', 'ZXX0019');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium channel blockers', 'C08');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium channel blockers and diuretics', 'C08G');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium channel blockers and diuretics', 'C08GA');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium chloride', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium chloride', 'B05XA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium chloride', 'A12AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium chloride', 'G04BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium chloride', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium chloride', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium citrate lysine complex', 'A12AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium compounds', 'A02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium compounds', 'A07XA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium dobesilate', 'C05BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium dobesilate, combinations', 'C05BX51');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium folinate', 'V03AF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium glubionate', 'A12AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium glucoheptonate', 'A12AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium gluconate', 'A12AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium gluconate', 'D11AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium glycerylphosphate', 'A12AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium hexamine thiocyanate', 'R01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium homeostasis', 'H05');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium iopodate', 'V08AC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium lactate', 'A12AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium lactate gluconate', 'A12AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium laevulate', 'A12AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium levofolinate', 'V03AF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium pangamate', 'A12AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium pantothenate', 'D03AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium pantothenate', 'A11HA31');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium phosphate', 'A12AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium polycarbophil', 'A06AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium polystyrene sulfonate', 'V03AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium silicate', 'A02AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium, combinations with other drugs', 'A12AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('camazepam', 'N05BA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('camostat', 'B02AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('camphor', 'D04AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('camphor', 'M02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('camphor', 'D02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('camphora', 'C01EB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('camylofin', 'A03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('camylofin and analgesics', 'A03DA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('canakinumab', 'L04AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('candesartan', 'C09CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('candesartan and diuretics', 'C09DA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('candesartan cilexetil', 'C09CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('candicidin', 'G01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('canrenone', 'C03DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('capecitabine', 'L01BC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('capillary stabilizing agents', 'C05C');
INSERT INTO staging.atc (description, atc_code) VALUES ('capreomycin', 'J04AB30');
INSERT INTO staging.atc (description, atc_code) VALUES ('capsaicin', 'M02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('capsaicin', 'N01BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('capsicum preparations and similar agents', 'M02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('captodiame', 'N05BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('captopril', 'C09AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('captopril and diuretics', 'C09BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbachol', 'N07AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbachol', 'S01EB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbamates', 'N05BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbamazepine', 'N03AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbamic acid esters', 'M03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbamide', 'D02AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbamide', 'B05BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbamide products', 'D02AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbamide, combinations', 'D02AE51');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbapenems', 'J01DH');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbasalate calcium', 'N02BA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbasalate calcium', 'B01AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbasalate calcium comb. excl. psycholeptics', 'N02BA65');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbazochrome', 'B02BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbenicillin', 'J01CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbenoxolone', 'A02BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbenoxolone, combinations excl. psycholeptics', 'A02BX51');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbenoxolone, combinations with psycholeptics', 'A02BX71');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbetocin', 'H01BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbimazole', 'H03BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbinoxamine', 'R06AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbocisteine', 'R05CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbocromen', 'C01DX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbohydrates', 'B05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbohydrates', 'V06DC');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbohydrates/proteins/minerals/vitamins, combinations', 'V06DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbolic oil', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbon dioxide', 'V03AN05');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbon dioxide', 'V03AN02');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbon dioxide producing drugs', 'A06AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbon monoxide', 'V03AN05');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbonic anhydrase inhibitors', 'S01EC');
INSERT INTO staging.atc (description, atc_code) VALUES ('carboplatin', 'L01XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('carboprost', 'G02AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('carboprost (carboprost tromethamine)', 'G02AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('carboquone', 'L01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('carboxamide derivatives', 'N03AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbromal', 'N05CM04');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbutamide', 'A10BB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbuterol', 'R03AC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbuterol', 'R03CC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('cardiac glycosides', 'C01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('cardiac stimulants excl. cardiac glycosides', 'C01C');
INSERT INTO staging.atc (description, atc_code) VALUES ('cardiac therapy', 'C01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cardioplegia solutions', 'B05XA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('cardiovascular system', 'C');
INSERT INTO staging.atc (description, atc_code) VALUES ('cardiovascular system', 'V09G');
INSERT INTO staging.atc (description, atc_code) VALUES ('carfecillin', 'G01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('carglutamic acid', 'A16AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('caries prophylactic agents', 'A01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('carindacillin', 'J01CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('carisbamate', 'N03AX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('carisoprodol', 'M03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('carisoprodol, combinations excl. psycholeptics', 'M03BA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('carisoprodol, combinations with psycholeptics', 'M03BA72');
INSERT INTO staging.atc (description, atc_code) VALUES ('carmofur', 'L01BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('carmustine', 'L01AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('caroverine', 'A03AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('carpipramine', 'Z01AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('carteolol', 'S01ED05');
INSERT INTO staging.atc (description, atc_code) VALUES ('carteolol', 'C07AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('carvacrol', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('carvedilol', 'C07AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cascara', 'A06AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cascara, combinations', 'A06AB57');
INSERT INTO staging.atc (description, atc_code) VALUES ('casopitant', 'A04AD13');
INSERT INTO staging.atc (description, atc_code) VALUES ('caspofungin', 'J02AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('caspofungin (caspofungin acetate)', 'J02AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('castor oil', 'A06AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('cat (felis domesticus) pelt and cat dander', 'V01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('cathine', 'A08AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cation exchange resins', 'V04CG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('catioresine sulfo sodique', 'Z01AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('catumaxomab', 'L01XC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefacetrile', 'J01DB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefaclor', 'J01DC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefadroxil', 'J01DB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefalexin', 'J01DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefaloridine', 'J01DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefalotin', 'J01DB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefamandole', 'J01DC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefapirin', 'J01DB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefatrizine', 'J01DB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefazedone', 'J01DB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefazolin', 'J01DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefcapene', 'J01DD17');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefdinir', 'J01DD15');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefditoren', 'J01DD16');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefepime', 'J01DE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefepime (cefepime hydrochloride)', 'J01DE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefetamet', 'J01DD10');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefixime', 'J01DD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefmenoxime', 'J01DD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefmetazole', 'J01DC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefodizime', 'J01DD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefonicid', 'J01DC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefoperazone', 'J01DD12');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefoperazone, combinations', 'J01DD62');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceforanide', 'J01DC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefotaxime', 'J01DD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefotaxime (cefotaxime sodium)', 'J01DD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefotaxime sodium', 'J01DD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefotetan', 'J01DC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefotiam', 'J01DC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefoxitin', 'J01DC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefoxitin (cefoxitin sodium)', 'J01DC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefozopran', 'J01DE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefpiramide', 'J01DD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefpirome', 'J01DE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefpodoxime', 'J01DD13');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefprozil', 'J01DC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefprozil (cefprozil monohydrate)', 'J01DC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefradine', 'J01DB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefroxadine', 'J01DB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefsulodin', 'J01DD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceftazidime', 'J01DD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceftazidime (ceftazidime pentahydrate)', 'J01DD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceftezole', 'J01DB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceftibuten', 'J01DD14');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceftizoxime', 'J01DD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceftobiprole medocaril', 'J01DI01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceftriaxone', 'J01DD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceftriaxone, combinations', 'J01DD54');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefuroxime', 'J01DC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefuroxime (cefuroxime axetil)', 'J01DC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefuroxime (cefuroxime sodium)', 'J01DC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefuroxime, comb. with other antibacterials', 'J01RA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('celecoxib', 'M01AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('celecoxib', 'L01XX33');
INSERT INTO staging.atc (description, atc_code) VALUES ('celiprolol', 'C07AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('cellulase', 'A09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('central antihypertensives', 'ZXX0035');
INSERT INTO staging.atc (description, atc_code) VALUES ('central nervous system', 'V09A');
INSERT INTO staging.atc (description, atc_code) VALUES ('centrally acting antiobesity products', 'A08AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('centrally acting sympathomimetics', 'N06BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('cephalexin', 'J01DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cephalothin (cephalothin sodium)', 'J01DB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceratonia', 'A07XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cerium oxalate', 'A04AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cerivastatin', 'C10AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('certolizumab pegol', 'L04AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceruletide', 'V04CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetalkonium', 'Z01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetiedil', 'C04AX26');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetirizine', 'R06AE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetirizine hydrochloride', 'R06AE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetrimide', 'D11AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetrimide', 'D08AJ04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetrimonium', 'R02AA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetrimonium', 'D08AJ02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetrimonium bromide', 'D08AJ02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetrorelix', 'H01CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetrorelix (cetrorelix acetate)', 'H01CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetuximab', 'L01XC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetylpyridinium', 'R02AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetylpyridinium', 'D09AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetylpyridinium', 'B05CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetylpyridinium', 'D08AJ03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetylpyridinium chloride', 'R02AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cevimeline', 'N07AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('charcoal activated', 'A07BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('charcoal preparations', 'A07BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('chemicals and reagents for analysis', 'V07AZ');
INSERT INTO staging.atc (description, atc_code) VALUES ('chemotherapeutics for topical use', 'D06B');
INSERT INTO staging.atc (description, atc_code) VALUES ('chenodeoxycholic acid', 'A05AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chiniofon', 'P01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloral hydrate', 'N05CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloralodol', 'N05CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorambucil', 'L01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloramphenicol', 'S01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloramphenicol', 'J01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloramphenicol', 'S03AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloramphenicol', 'S02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloramphenicol', 'D10AF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloramphenicol', 'D06AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloramphenicol', 'G01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloramphenicol (chloramphenicol sodium succinate)', 'J01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorbenzoxamine', 'A03AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorcyclizine', 'R06AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlordiazepoxide', 'N05BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlordiazepoxide hydrochloride', 'N05BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidine', 'S03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidine', 'B05CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidine', 'S01AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidine', 'A01AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidine', 'D08AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidine', 'S02AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidine', 'D09AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidine', 'R02AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidine acetate', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidine acetate', 'A01AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidine gluconate', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidine gluconate', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidine gluconate', 'D08AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidine gluconate', 'A01AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidine, combinations', 'D08AC52');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorine (sodium dichloro-s-triazinetrione)', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorine containing products', 'P03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorine peroxide', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlormadinone', 'G03DB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlormadinone and estrogen', 'G03AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlormadinone and estrogen', 'G03FB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlormethine', 'L01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlormezanone', 'M03BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlormezanone, combinations excl. psycholeptics', 'M03BB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlormezanone, combinations with psycholeptics', 'M03BB72');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorobutanol', 'A04AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorobutanol, combinations', 'A04AD54');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloroform', 'N01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloroprednisone and antiinfectives', 'S01CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloroprocaine', 'N01BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloroprocaine hydrochloride', 'N01BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloropyramine', 'D04AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloropyramine', 'R06AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloropyramine, combinations', 'R06AC53');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloroquinaldol', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloroquine', 'P01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloroquine diphosphate', 'P01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorothiazide', 'C03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorothiazide and potassium', 'C03AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorothiazide, combinations', 'C03AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorotrianisene', 'G03CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloroxylenol', 'D08AE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloroxylenol', 'D05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorphenamine', 'R06AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorphenamine, combinations', 'R06AB54');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorphenesin', 'D01AE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorpheniramine maleate', 'R06AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorphenoxamine', 'R06AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorphenoxamine', 'D04AA34');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorphenoxamine, combinations', 'R06AA56');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorproethazine', 'N05AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorpromazine', 'N05AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorpromazine (chlorpromazine hydrochloride)', 'N05AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorpromazine hydrochloride', 'N05AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorpropamide', 'A10BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorprothixene', 'N05AF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorquinaldol', 'R02AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorquinaldol', 'D08AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorquinaldol', 'P01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorquinaldol', 'G01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlortalidone', 'C03BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlortalidone and potassium', 'C03BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlortalidone and potassium-sparing agents', 'C03EA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlortetracycline', 'A01AB21');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlortetracycline', 'D06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlortetracycline', 'J01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlortetracycline', 'S01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorthalidone', 'C03BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorzoxazone', 'M03BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorzoxazone, combinations excl. psycholeptics', 'M03BB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorzoxazone, combinations with psycholeptics', 'M03BB73');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholera vaccines', 'J07AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholera, combinations with typhoid vaccine, inactivated, whole cell', 'J07AE51');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholera, inactivated, whole cell', 'J07AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholera, live attenuated', 'J07AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholesterol and triglyceride reducers', 'C10A');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholestyramine resin', 'C10AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholic acid', 'A05AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('choline alfoscerate', 'N07AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('choline derivatives', 'M03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('choline esters', 'N07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('choline salicylate', 'N02BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('choline theophyllinate', 'R03DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('choline theophyllinate and adrenergics', 'R03DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholinesterase', 'V03AB29');
INSERT INTO staging.atc (description, atc_code) VALUES ('chondroitin sulfate', 'M01AX25');
INSERT INTO staging.atc (description, atc_code) VALUES ('chondroitin sulfate-iron complex', 'B03AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('choriogonadotropin alfa', 'G03GA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('choriogonadotropin alpha', 'G03GA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('chorionic gonadotropin', 'G03GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chromium (51cr) chromate labelled cells', 'V09GX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chromium (51cr) edetate', 'V09CX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chromium (chromic chloride)', 'A12CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('chymopapain', 'M09AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chymotrypsin', 'B06AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chymotrypsin', 'S01KX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cibenzoline', 'C01BG07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cicatrizants', 'D03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclesonide', 'R03BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('cicletanine', 'C03BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclobendazole', 'P02CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclonicate', 'C04AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclonium and analgesics', 'A03DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclopirox', 'D01AE14');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclopirox', 'G01AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclopirox olamine', 'D01AE14');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclosporin', 'L04AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclosporin', 'S01XA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('cidofovir', 'J05AB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('cilazapril', 'C09AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('cilazapril and diuretics', 'C09BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('cilnipidine', 'C08CA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('cilostazol', 'Z01AA36');
INSERT INTO staging.atc (description, atc_code) VALUES ('cimetidine', 'A02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cimetidine (cimetidine hydrochloride)', 'A02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cimetidine, combinations', 'A02BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('cimetropium bromide', 'A03BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinacalcet', 'H05BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinacalcet (cinacalcet hydrochloride)', 'H05BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinchocaine', 'S01HA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinchocaine', 'D04AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinchocaine', 'C05AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinchocaine', 'N01BB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinchophen', 'M04AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinepazet', 'C01DX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinepazide', 'C04AX27');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinnamaldehyde', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinnamyl alcohol', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinnarizine', 'N07CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinnarizine, combinations', 'N07CA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinolazepam', 'N05CD13');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinoxacin', 'J01MB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciprofibrate', 'C10AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciprofloxacin', 'J01MA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciprofloxacin', 'S03AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciprofloxacin', 'S01AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride, ciprofloxacin)', 'J01MA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciprofloxacin (ciprofloxacin lactate)', 'J01MA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciprofloxacin hydrochloride', 'S01AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('cisapride', 'A03FA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cisatracurium', 'M03AC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('cisatracurium (cisatracurium besylate)', 'M03AC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('cisplatin', 'L01XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('citalopram', 'N06AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('citicoline', 'N06BX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('citiolone', 'A05BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('citrates', 'Z01AA32');
INSERT INTO staging.atc (description, atc_code) VALUES ('citric acid', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('citric acid', 'V07AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('citric acid', 'A09AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('citric acid', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('cladribine', 'L01BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('clarithromycin', 'J01FA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('class i antiarrhythmics (but lidocaine)', 'ZXX0024');
INSERT INTO staging.atc (description, atc_code) VALUES ('class ia antiarrhythmics', 'ZXX0025');
INSERT INTO staging.atc (description, atc_code) VALUES ('clebopride', 'A03FA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('clefamide', 'P01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clemastine', 'R06AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('clemastine', 'D04AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('clemastine (clemastine hydrogen fumarate)', 'R06AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('clemastine, combinations', 'R06AA54');
INSERT INTO staging.atc (description, atc_code) VALUES ('clenbuterol', 'R03CC13');
INSERT INTO staging.atc (description, atc_code) VALUES ('clenbuterol', 'R03AC14');
INSERT INTO staging.atc (description, atc_code) VALUES ('clevudine', 'J05AF12');
INSERT INTO staging.atc (description, atc_code) VALUES ('clidinium and psycholeptics', 'A03CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clindamycin', 'J01FF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clindamycin', 'D10AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clindamycin', 'G01AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('clindamycin (clindamycin 2-palmitate hydrochloride)', 'J01FF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clindamycin (clindamycin phosphate)', 'G01AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('clindamycin (clindamycin phosphate)', 'J01FF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clioquinol', 'D09AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('clioquinol', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('clioquinol', 'S02AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('clioquinol', 'P01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clioquinol', 'G01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clioquinol', 'D08AH30');
INSERT INTO staging.atc (description, atc_code) VALUES ('clioquinol, combinations', 'P01AA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobazam', 'N05BA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobenzorex', 'A08AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobetasol', 'D07AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobetasol and antibiotics', 'D07CD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobetasol propionate', 'D07AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobetasone', 'D07AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobetasone', 'S01BA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobetasone and antiinfectives', 'S01CA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobetasone butyrate', 'D07AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobutinol', 'R05DB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('clocinizine', 'Z01AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('clocortolone', 'D07AB21');
INSERT INTO staging.atc (description, atc_code) VALUES ('clodantoin', 'G01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clodronate disodium', 'M05BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clodronate disodium (clodronate disodium tetrahydrate)', 'M05BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clodronic acid', 'M05BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofarabine', 'L01BB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofazimine', 'J04BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofedanol', 'R05DB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofedanol hydrochloride', 'R05DB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofenamide', 'C03BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofenamide and potassium', 'C03BB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofenotane', 'P03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofenotane, combinations', 'P03AB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofezone', 'M01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofezone', 'M02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofibrate', 'C10AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofibride', 'C10AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofoctol', 'J01XX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('clomethiazole', 'N05CM02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clomethiazole, combinations', 'N05CX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('clometocillin', 'J01CE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('clomidazole', 'D01AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('clomifene', 'G03GB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clomiphene citrate', 'G03GB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clomipramine', 'N06AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('clomipramine hydrochloride', 'N06AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('clomocycline', 'J01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('clonazepam', 'N03AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clonidine', 'N02CX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clonidine', 'S01EA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('clonidine', 'C02AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clonidine and diuretics', 'C02LC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clonidine and diuretics, combinations with other drugs', 'C02LC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('clonidine hydrochloride', 'C02AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clopamide', 'C03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('clopamide and potassium', 'C03BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('clopenthixol', 'N05AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cloperastine', 'R05DB21');
INSERT INTO staging.atc (description, atc_code) VALUES ('clopidogrel', 'B01AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('clopidogrel (clopidogrel bisulfate)', 'B01AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cloprednol', 'H02AB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('cloranolol', 'C07AA27');
INSERT INTO staging.atc (description, atc_code) VALUES ('clorazepate dipotassium', 'N05BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('clorexolone', 'C03BA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('clorexolone, comb. with psycholeptics', 'C03BA82');
INSERT INTO staging.atc (description, atc_code) VALUES ('cloricromen', 'B01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cloridarol', 'C01DX15');
INSERT INTO staging.atc (description, atc_code) VALUES ('clorindione', 'B01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('clorophene', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('clorophene sodium', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('clostridiopeptidase', 'D03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clostridiopeptidase, combinations', 'D03BA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('clostridium botulinum neurotoxin type a (150kd), free from complexing proteins', 'M03AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clotiapine', 'N05AH06');
INSERT INTO staging.atc (description, atc_code) VALUES ('clotiazepam', 'N05BA21');
INSERT INTO staging.atc (description, atc_code) VALUES ('clotrimazole', 'A01AB18');
INSERT INTO staging.atc (description, atc_code) VALUES ('clotrimazole', 'G01AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clotrimazole', 'D01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cloxacillin', 'J01CF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cloxacillin (cloxacillin sodium)', 'J01CF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cloxacillin sodium', 'J01CF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cloxazolam', 'N05BA22');
INSERT INTO staging.atc (description, atc_code) VALUES ('clozapine', 'N05AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('coagulation factor ix', 'B02BD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('coagulation factor ix (human)', 'B02BD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('coagulation factor ix (recombinant)', 'B02BD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('coagulation factor ix, ii, vii and x in combination', 'B02BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('coagulation factor vii', 'B02BD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('coagulation factor viii', 'B02BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('coagulation factor xiii', 'B02BD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('coal tar', 'D05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('cobalt (57co) cyanocobalamine', 'V09XX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cobalt (58co) cyanocobalamine', 'V09XX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cobaltous chloride', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('cobamamide', 'B03BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cocaine', 'N01BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cocaine', 'S01HA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cocaine', 'S02DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cocaine', 'R02AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cocaine hydrochloride', 'R02AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cod-liver oil ointments', 'D03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('codeine', 'R05DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('codeine (codeine monohydrate)', 'R05DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('codeine (codeine sulfate)', 'R05DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('codeine phosphate', 'R05DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('codeine, combinations excl. psycholeptics', 'N02AA59');
INSERT INTO staging.atc (description, atc_code) VALUES ('codeine, combinations with psycholeptics', 'N02AA79');
INSERT INTO staging.atc (description, atc_code) VALUES ('colchicine', 'M04AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('colchicine derivatives', 'L01CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('colecalciferol', 'A11CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('colesevelam', 'C10AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('colestipol', 'C10AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('colestipol hydrochloride', 'C10AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('colestyramine', 'C10AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('colfosceril palmitate', 'R07AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('colistin', 'A07AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('colistin', 'J01XB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('colistin (colistimethate sodium)', 'J01XB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('collagen', 'G04BX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('collagen', 'B02BC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('collagen, combinations', 'D11AX57');
INSERT INTO staging.atc (description, atc_code) VALUES ('collagenase', 'D03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('collagenase', 'D03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('colony stimulating factors', 'L03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('colouring agents', 'S01JA');
INSERT INTO staging.atc (description, atc_code) VALUES ('comb. of rauwolfia alkaloids and diuretics incl. other combinations', 'C02LA50');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'J01CA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'B05BA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'S02DA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'D06AX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'A10AC30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'S01HA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'A06AG20');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'A11CC20');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'A10AE30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'R05CB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'B01AC30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'A10AD30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'N01BB20');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'C01CA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'B05CA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'R05DB20');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'D01AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'B05CX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'G04BE30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'A07BC30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'B02BC30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'A02AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'D01AC20');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'J01ED20');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'R01AX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'R05CA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'A02AC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'J06BB30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'A01AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'J01EB20');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'A12BA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'A10AB30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'J05AR');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'A02AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'J01EC20');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'R05DA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'J07BC20');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'R07AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'J01CE30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'D01AE20');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations', 'B05CB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations and complexes of aluminium, calcium and magnesium compounds', 'A02AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations for eradication of helicobacter pylori', 'A02BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of adrenergics', 'R03AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of antibacterials', 'J01R');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of antibacterials', 'J01RA');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of antihistamines', 'R06AK');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of antihypertensives in atc-gr. c02', 'C02N');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of antineoplastic agents', 'L01XY');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of barbiturates', 'N05CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of corticosteroids', 'D07AB30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of corticosteroids', 'D07XB30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of different antibiotics', 'S01AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of drugs for treatment of tuberculosis', 'J04AM');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of electrolytes', 'B05XA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of imidazole derivatives', 'G01AF20');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of levothyroxine and liothyronine', 'H03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of oral blood glucose lowering drugs', 'A10BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of penicillins', 'J01CR50');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of penicillins, incl. beta-lactamase inhibitors', 'J01CR');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of rauwolfia alkaloids', 'C02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of rauwolfia alkoloids, combinations', 'C02AA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of sulfonamides', 'G01AE10');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of sulfonamides and trimethoprim, incl. derivatives', 'J01EE');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of tetracyclines', 'J01AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of vitamins', 'A11JA');
INSERT INTO staging.atc (description, atc_code) VALUES ('combinations of xanthines', 'R03DA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('conjugated estrogens', 'G03CA57');
INSERT INTO staging.atc (description, atc_code) VALUES ('contact laxatives', 'A06AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('contact laxatives in combination', 'A06AB20');
INSERT INTO staging.atc (description, atc_code) VALUES ('contact laxatives in combination with belladonna alkaloids', 'A06AB30');
INSERT INTO staging.atc (description, atc_code) VALUES ('contraceptives for topical use', 'G02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('contrast media', 'V08');
INSERT INTO staging.atc (description, atc_code) VALUES ('copper (copper sulfate)', 'A12CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('copper oleinate', 'P03AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('copper sulfate', 'V03AB20');
INSERT INTO staging.atc (description, atc_code) VALUES ('copper usnate', 'G01AX15');
INSERT INTO staging.atc (description, atc_code) VALUES ('corifollitropin alfa', 'G03GA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticorelin', 'V04CD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroid derivatives', 'N02CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids', 'S02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids', 'R01AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids', 'S03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids', 'S03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids', 'S02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids acting locally', 'A07EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids and antiinfectives in combination', 'S02C');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids and antiinfectives in combination', 'S02CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids and antiinfectives in combination', 'S01CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids and antiinfectives in combination', 'S03CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids and antiinfectives in combination', 'S03C');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids and mydriatics in combination', 'S01BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids for local oral treatment', 'A01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids for systemic use', 'H02');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids for systemic use, combinations', 'H02BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids for systemic use, combinations', 'H02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids for systemic use, plain', 'H02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, combinations for treatment of acne', 'D10AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, combinations with antibiotics', 'D07C');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, combinations with antiseptics', 'D07B');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, dermatological preparations', 'D07');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, moderately potent (group ii)', 'D07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, moderately potent, combinations with antibiotics', 'D07CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, moderately potent, combinations with antiseptics', 'D07BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, moderately potent, other combinations', 'D07XB');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, other combinations', 'D07X');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, plain', 'S01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, plain', 'D07A');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, potent (group iii)', 'D07AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, potent, combinations with antibiotics', 'D07CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, potent, combinations with antiseptics', 'D07BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, potent, other combinations', 'D07XC');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, very potent (group iv)', 'D07AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, very potent, combinations with antibiotics', 'D07CD');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, very potent, combinations with antiseptics', 'D07BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, very potent, other combinations', 'D07XD');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, weak (group i)', 'D07AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, weak, combinations with antibiotics', 'D07CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, weak, combinations with antiseptics', 'D07BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids, weak, other combinations', 'D07XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroids/antiinfectives/mydriatics in combination', 'S01CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticotropin', 'H01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cortisone', 'H02AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('cortisone', 'S01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cortisone acetate', 'H02AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('cortivazol', 'H02AB17');
INSERT INTO staging.atc (description, atc_code) VALUES ('corynebacterium diphtheriae crm-197 protein', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cosmetics', 'V07AT');
INSERT INTO staging.atc (description, atc_code) VALUES ('cosyntropin', 'H01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cosyntropin (cosyntropin zinc hydroxide complex)', 'H01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cough and cold preparations', 'R05');
INSERT INTO staging.atc (description, atc_code) VALUES ('cough suppressants and expectorants', 'R05FB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cough suppressants and expectorants, combinations', 'R05F');
INSERT INTO staging.atc (description, atc_code) VALUES ('cough suppressants and mucolytics', 'R05FB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cough suppressants, excl. combinations with expectorants', 'R05D');
INSERT INTO staging.atc (description, atc_code) VALUES ('coxibs', 'M01AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('crataegus glycosides', 'C01EB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('creatinolfosfate', 'C01EB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('creosote', 'R05CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('crilanomer', 'D03AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromoglicic acid', 'R01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromoglicic acid', 'A07EB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromoglicic acid', 'D11AH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromoglicic acid', 'R03BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromoglicic acid', 'S01GX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromoglicic acid, combinations', 'S01GX51');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromoglicic acid, combinations', 'R01AC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromolyn sodium', 'R03BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromolyn sodium', 'S01GX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromolyn sodium', 'A07EB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromolyn sodium', 'R01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('crospovidone', 'A07BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('crotamiton', 'P03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('curare alkaloids', 'ZXX0056');
INSERT INTO staging.atc (description, atc_code) VALUES ('curare alkaloids', 'M03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyamemazine', 'N05AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyanocobalamin', 'B03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyanocobalamin tannin complex', 'B03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyanocobalamin, combinations', 'B03BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclandelate', 'C04AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclic amines', 'J05AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclines', 'ZXX0058');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclizine', 'R06AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclizine, combinations', 'R06AE53');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclobarbital', 'N05CA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclobenzaprine', 'M03BX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclobenzaprine hydrochloride', 'M03BX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclobutyrol', 'A05AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclofenil', 'G03GB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cycloguanil embonate', 'P01BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclopentamine', 'R01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclopentamine hydrochloride', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclopenthiazide', 'C03AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclopenthiazide and potassium', 'C03AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclopenthiazide and potassium-sparing agents', 'C03EA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclopentolate', 'S01FA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclopentolate hydrochloride', 'S01FA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclophosphamide', 'L01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cycloserine', 'J04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclothiazide', 'C03AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclothiazide and potassium', 'C03AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyfluthrin', 'P03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cymarin', 'C01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyp3a4 dependent substrates', 'ZXX0137');
INSERT INTO staging.atc (description, atc_code) VALUES ('cypermethrin', 'P03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyproheptadine', 'R06AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyproheptadine hydrochloride', 'R06AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyproterone', 'G03HA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyproterone acetate', 'G03HA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyproterone and estrogen', 'G03HB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytarabine', 'L01BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytochrome p450 1a2 inducers', 'ZXX0164');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytochrome p450 1a2 substrates', 'ZXX0163');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytochrome p450 2b6 inducers', 'ZXX0170');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytochrome p450 2b6 substrates', 'ZXX0169');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytochrome p450 2c19 inducers', 'ZXX0188');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytochrome p450 2c19 substrates', 'ZXX0187');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytochrome p450 2c8 inducers', 'ZXX0176');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytochrome p450 2c8 substrates', 'ZXX0175');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytochrome p450 2c9 inducers', 'ZXX0182');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytochrome p450 2c9 substrates', 'ZXX0181');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytochrome p450 2d6 inducers', 'ZXX0194');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytochrome p450 2d6 substrates', 'ZXX0193');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytochrome p450 2e1 inducers', 'ZXX0200');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytochrome p450 2e1 substrates', 'ZXX0199');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytochrome p450 3a4,5,7 inducers', 'ZXX0206');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytochrome p450 3a4,5,7 substrates', 'ZXX0205');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytokines and immunomodulators', 'L03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytomegalovirus immune globulin (human)', 'J06BB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytomegalovirus immunoglobulin', 'J06BB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytotoxic antibiotics and related substances', 'L01D');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytotoxics', 'ZXX0059');
INSERT INTO staging.atc (description, atc_code) VALUES ('d&c red no. 28', 'V04CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('d-penicillamine', 'M01CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dabigatran', 'B01AE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('dabigatran etexilate (dabigatran etexilate mesilate)', 'B01AE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('dacarbazine', 'L01AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('daclizumab', 'L04AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dactinomycin', 'L01DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dalbavancin', 'J01XA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dalteparin', 'B01AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dalteparin sodium', 'B01AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('danaparoid', 'B01AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('danaparoid sodium', 'B01AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('danazol', 'G03XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dantrolene', 'M03CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dantrolene and derivatives', 'M03CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('dantrolene sodium', 'M03CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dantron', 'A06AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dantron, combinations', 'A06AB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('dantron, incl. combinations', 'A06AG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dapiprazole', 'S01EX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dapoxetine', 'G04BX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('dapsone', 'D10AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('dapsone', 'J04BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('daptomycin', 'J01XX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('darbepoetin alfa', 'B03XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('darifenacin', 'G04BD10');
INSERT INTO staging.atc (description, atc_code) VALUES ('darifenacin (darifenacin hydrobromide)', 'G04BD10');
INSERT INTO staging.atc (description, atc_code) VALUES ('darunavir', 'J05AE10');
INSERT INTO staging.atc (description, atc_code) VALUES ('darunavir (darunavir ethanolate)', 'J05AE10');
INSERT INTO staging.atc (description, atc_code) VALUES ('dasatinib', 'L01XE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('dasatinib (dasatinib monohydrate)', 'L01XE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('daunorubicin', 'L01DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('daunorubicin (daunorubicin hydrochloride)', 'L01DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('deanol', 'N06BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('debrisoquine', 'C02CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('decamethrin', 'P03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('decongestants and antiallergics', 'S01G');
INSERT INTO staging.atc (description, atc_code) VALUES ('decongestants and other nasal preparations for topical use', 'R01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('deferasirox', 'V03AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('deferiprone', 'V03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('deferoxamine', 'V03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('deferoxamine mesylate', 'V03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('defibrotide', 'B01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('deflazacort', 'H02AB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('degarelix (degarelix acetate)', 'L02BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dehydrocholic acid', 'A05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('delapril', 'C09AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('delapril and calcium channel blockers', 'C09BB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('delapril and diuretics', 'C09BA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('delavirdine', 'J05AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('delavirdine mesylate', 'J05AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('demecarium', 'S01EB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('demeclocycline', 'D06AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('demeclocycline', 'J01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('demecolcine', 'L01CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('demegestone', 'G03DB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('demoxytocin', 'H01BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('denileukin diftitox', 'L01XX29');
INSERT INTO staging.atc (description, atc_code) VALUES ('denosumab', 'M05BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('deptropine', 'R06AX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('dequalinium', 'G01AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('dequalinium', 'R02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dequalinium', 'D08AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dequalinium chloride', 'R02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dermatan sulfate', 'B01AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dermatologicals', 'D');
INSERT INTO staging.atc (description, atc_code) VALUES ('dermatophagoides farinae', 'V01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dermatophagoides farinae', 'V01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('dermatophagoides pteronyssinus', 'V01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('desaspidin', 'P02DX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('deserpidine', 'C02AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('deserpidine and diuretics', 'C02LA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('desflurane', 'N01AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('desipramine', 'N06AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('desipramine (desipramine hydrochloride)', 'N06AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('desipramine hydrochloride', 'N06AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('desirudin', 'B01AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('deslanoside', 'C01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('desloratadine', 'R06AX27');
INSERT INTO staging.atc (description, atc_code) VALUES ('desmopressin', 'H01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('desmopressin (desmopressin acetate)', 'H01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('desmopressin acetate', 'H01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('desmopressin acetate trihydrate', 'H01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('desogestrel', 'G03AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('desogestrel and estrogen', 'G03AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('desogestrel and estrogen', 'G03FB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('desogestrel and estrogen', 'G03AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('desonide', 'S01BA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('desonide', 'D07AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('desonide and antiseptics', 'D07BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('desoximetasone', 'D07AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('desoximetasone', 'D07XC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('desoxycortone', 'H02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('desoxyribonuclease', 'B06AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('desvenlafaxine', 'N06AX23');
INSERT INTO staging.atc (description, atc_code) VALUES ('desvenlafaxine (desvenlafaxine succinate)', 'N06AX23');
INSERT INTO staging.atc (description, atc_code) VALUES ('detaxtran', 'C10AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('detoxifying agents for antineoplastic treatment', 'V03AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone', 'S01CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone', 'S02BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone', 'D10AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone', 'H02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone', 'D07XB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone', 'D07AB19');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone', 'A01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone', 'S03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone', 'C05AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone', 'S01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone', 'R01AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone (dexamethasone sodium phosphate)', 'H02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone and antibiotics', 'D07CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone and antiinfectives', 'S02CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone and antiinfectives', 'S03CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone and antiinfectives', 'S01CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone phosphate (dexamethasone sodium phosphate)', 'H02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone phosphate (dexamethasone sodium phosphate)', 'S03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone sodium phosphate', 'S03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethasone, combinations', 'R01AD53');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamfetamine', 'N06BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexbrompheniramine', 'R06AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexbrompheniramine, combinations', 'R06AB56');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexchlorpheniramine', 'R06AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexchlorpheniramine, combinations', 'R06AB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexetimide', 'N04AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexfenfluramine', 'A08AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexibuprofen', 'M01AE14');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexketoprofen', 'M01AE17');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexlansoprazole', 'A02BC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexmedetomidine (dexmedetomidine hydrochloride)', 'N05CM18');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexmethylphenidate', 'N06BA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexpanthenol', 'D03AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexpanthenol', 'S01XA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexpanthenol', 'A11HA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexrazoxane', 'V03AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextran', 'B05AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextran', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextran (dextran 70)', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextran 40', 'ZXX0060');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextran 70', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextranomer', 'D03AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextriferron', 'B03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextriferron', 'B03AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextriferron', 'B03AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextroamphetamine sulfate', 'N06BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextromethorphan', 'R05DA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextromethorphan hydrobromide (dextromethorphan polistirex)', 'R05DA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextromoramide', 'N02AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextropropoxyphene', 'N02AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextropropoxyphene, comb. excl. psycholeptics', 'N02AC54');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextropropoxyphene, comb. with psycholeptics', 'N02AC74');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextrose', 'B05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextrose', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextrose', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextrose', 'V07AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextrose', 'C01DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextrose anhydrous', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextrose anhydrous (dextrose monohydrate)', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextrothyroxine', 'C10AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dezocine', 'N02AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('diacerein', 'M01AX21');
INSERT INTO staging.atc (description, atc_code) VALUES ('diagnostic agents', 'V04');
INSERT INTO staging.atc (description, atc_code) VALUES ('diagnostic agents', 'S01J');
INSERT INTO staging.atc (description, atc_code) VALUES ('diagnostic radiopharmaceuticals', 'V09');
INSERT INTO staging.atc (description, atc_code) VALUES ('diaminopyrimidines', 'P01BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('diamorphine', 'N02AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('diastase', 'A09AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diatrizoic acid', 'V08AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diazepam', 'N05BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diazepines, oxazepines and thiazepines', 'N05AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('diazoxide', 'V03AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diazoxide', 'C02DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibekacin', 'J01GB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibenzepin', 'N06AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibenzo-bicyclo-octadiene derivatives', 'N05BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibotermin alfa', 'M05BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibromotyrosine', 'H03BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibrompropamidine', 'D08AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibrompropamidine', 'S01AX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibucaine', 'C05AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibucaine hydrochloride', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibunate', 'R05DB16');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibutylphthalate', 'P03BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibutylsuccinate', 'P03BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dichloralphenazone', 'N05CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dichloroacetamide derivatives', 'P01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('dichlorobenzyl alcohol', 'R02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dichlorophen', 'P02DX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenac', 'M01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenac', 'M02AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenac', 'S01BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenac and antiinfectives', 'S01CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenac diethylamine', 'M02AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenac potassium', 'M01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenac sodium', 'M02AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenac sodium', 'S01BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenac sodium', 'M01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenac, combinations', 'M01AB55');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenamide', 'S01EC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dicloxacillin', 'J01CF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dicoumarol', 'B01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dicyclomine hydrochloride', 'A03AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('dicycloverine', 'A03AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('didanosine', 'J05AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('didecyldimethylammonium chloride', 'D08AJ06');
INSERT INTO staging.atc (description, atc_code) VALUES ('dienestrol', 'G03CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dienestrol', 'G03CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dienogest and estrogen', 'G03FA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('diet formulations for treatment of obesity', 'V06A');
INSERT INTO staging.atc (description, atc_code) VALUES ('diethyl ether', 'N01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diethyl-dithiocarbamate', 'Z01AA35');
INSERT INTO staging.atc (description, atc_code) VALUES ('diethylamine salicylate', 'M02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('diethylcarbamazine', 'P02CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('diethylstilbestrol', 'L02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diethylstilbestrol', 'G03CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('diethylstilbestrol', 'G03CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('diethyltoluamide', 'P03BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('difemerine', 'A03AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('difenoxin', 'A07DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('difenpiramide', 'M01AB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('difetarsone', 'P01AR02');
INSERT INTO staging.atc (description, atc_code) VALUES ('diflorasone', 'D07AC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('diflucortolone', 'D07AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('diflucortolone', 'D07XC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('diflucortolone and antiseptics', 'D07BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('diflucortolone valerate', 'D07AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('diflunisal', 'N02BA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('difluprednate', 'D07AC19');
INSERT INTO staging.atc (description, atc_code) VALUES ('digestives, incl. enzymes', 'A09');
INSERT INTO staging.atc (description, atc_code) VALUES ('digestives, incl. enzymes', 'A09A');
INSERT INTO staging.atc (description, atc_code) VALUES ('digitalis antitoxin', 'V03AB24');
INSERT INTO staging.atc (description, atc_code) VALUES ('digitalis glycosides', 'C01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('digitalis glycosides', 'ZXX0061');
INSERT INTO staging.atc (description, atc_code) VALUES ('digitalis leaves', 'C01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('digitoxin', 'C01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('digoxin', 'C01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('digoxin immune fab (ovine)', 'V03AB24');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihexyverine', 'A03AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydralazine', 'C02DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydralazine and diuretics', 'C02LG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydralazine and diuretics, combinations with other drugs', 'C02LG51');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydrocodeine', 'N02AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydrocodeine, combinations', 'N02AA58');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydroemetine', 'P01AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydroergocristine', 'C04AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydroergocristine, combinations', 'C04AE54');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydroergocryptine mesylate', 'N04BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydroergotamine', 'N02CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydroergotamine mesylate', 'N02CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydroergotamine, combinations', 'N02CA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydropyridine derivatives', 'C08CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydropyridines', 'ZXX0062');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydrostreptomycin', 'S01AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydrotachysterol', 'A11CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydroxialumini sodium carbonate', 'A02AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('diiodohydroxypropane', 'D08AG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('diiodohydroxyquin', 'P01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('diiodohydroxyquinoline', 'G01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diiodotyrosine', 'H03BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diisopromine', 'A03AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dilazep', 'C01DX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('diloxanide', 'P01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diltiazem', 'C08DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diltiazem hydrochloride', 'C08DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diluent', 'H01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimazole', 'D01AE17');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimefline', 'R07AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimemorfan', 'R05DA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimenhydrinate', 'R06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimercaprol', 'V03AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimetacrine', 'N06AA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimethicone', 'D02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimethicone', 'A03AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimethil sulfoxide', 'G04BX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimethyl sulfoxide', 'G04BX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimethyl sulfoxide', 'M02AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimethylaminopropionylphenothiazine', 'A03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimethylbenzyl ammonium chloride', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimethylcarbate', 'P03BX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimethylphthalate', 'P03BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimethyltubocurarine', 'M03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimetindene', 'R06AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimetindene', 'D04AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimetofrine', 'C01CA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimetotiazine', 'N02CX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('dinogest and estrogen', 'G03AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('dinoprost', 'G02AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dinoprost (dinoprost tromethamine)', 'G02AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dinoprostone', 'G02AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('diodone', 'V08AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('diosmectite', 'A07BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('diosmin', 'C05CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('diosmin, combinations', 'C05CA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipeptidyl peptidase 4 (dpp-4) inhibitors', 'A10BH');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphemanil', 'A03AB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphemanil and psycholeptics', 'A03CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenadione', 'B01AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenhydramine', 'R06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenhydramine', 'D04AA32');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenhydramine citrate', 'R06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenhydramine hydrochloride', 'D04AA32');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenhydramine methylbromide', 'D04AA33');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenhydramine, combinations', 'R06AA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenoxylate', 'A07DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenylbutylpiperidine derivatives', 'N05AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenylguanidine', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenylmethane derivatives', 'N05BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenylpropylamine derivatives', 'N02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenylpyraline', 'R06AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenylpyraline, combinations', 'R06AA57');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphteria antitoxin', 'J06AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphteria-hemophilus influenzae b-pertussis-poliomyelitis-tetanus-hepatitis b', 'J07CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtheria immunoglobulin', 'J06BB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtheria toxoid', 'J07AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtheria vaccines', 'J07AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtheria-hemophilus influenzae b-pertussis-poliomyelitis-tetanus', 'J07CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtheria-hepatitis b-pertussis-tetanus', 'J07CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtheria-hepatitis b-tetanus', 'J07CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtheria-pertussis-poliomyelitis-tetanus', 'J07CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtheria-poliomyelitis-tetanus', 'J07CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtheria-rubella-tetanus', 'J07CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipiperonylaminoethanol, combinations', 'N05CX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipivefrin hydrochloride', 'S01EA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipivefrine', 'S01EA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('diprophylline', 'R03DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diprophylline and adrenergics', 'R03DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diprophylline, combinations', 'R03DA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipyridamole', 'B01AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipyrocetyl', 'N02BA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipyrocetyl and corticosteroids', 'M01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipyrocetyl, combinations excl. psycholeptics', 'N02BA59');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipyrocetyl, combinations with psycholeptics', 'N02BA79');
INSERT INTO staging.atc (description, atc_code) VALUES ('direct acting antivirals', 'J05A');
INSERT INTO staging.atc (description, atc_code) VALUES ('direct thrombin inhibitors', 'B01AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('dirithromycin', 'J01FA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('disodium dodecyl diphenyloxide disulfonate', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('disodium edetate', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('disopyramide', 'C01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('distigmine', 'N07AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('disulfiram', 'P03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('disulfiram', 'N07BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('disulfiram', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('disulfiram, combinations', 'P03AA54');
INSERT INTO staging.atc (description, atc_code) VALUES ('ditazole', 'B01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dithiobis(benzothiazole)', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('dithranol', 'D05AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dithranol, combinations', 'D05AC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('diuretics', 'C03');
INSERT INTO staging.atc (description, atc_code) VALUES ('diuretics', 'ZXX0063');
INSERT INTO staging.atc (description, atc_code) VALUES ('diuretics and potassium-sparing agents in combination', 'C03E');
INSERT INTO staging.atc (description, atc_code) VALUES ('dixanthogen', 'P03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dixyrazine', 'N05AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dl-methionine', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('dobutamine', 'C01CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('dobutamine (dobutamine hydrochloride)', 'C01CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('docetaxel', 'L01CD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('docosanol', 'D06BB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('docusate calcium', 'A06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('docusate sodium', 'A06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('docusate sodium, incl. combinations', 'A06AG10');
INSERT INTO staging.atc (description, atc_code) VALUES ('dodeclonium bromide, combinations', 'D08AJ59');
INSERT INTO staging.atc (description, atc_code) VALUES ('dodecyl dimethyl benzyl ammonium chloride', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('dodicin', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('dodicin hydrochloride', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('dofetilide', 'C01BD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dolasetron', 'A04AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dolasetron mesylate', 'A04AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dolichovespula arenaria venom protein extract', 'V01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('dolichovespula maculata venom protein extract', 'V01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('domiodol', 'R05CB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('domiphen', 'A01AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('domperidone', 'A03FA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('domperidone (domperidone maleate)', 'A03FA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('donepezil', 'N06DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('donepezil hydrochloride', 'N06DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dopa and dopa derivatives', 'N04BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('dopamine', 'C01CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dopamine agonists', 'N04BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('dopaminergic agents', 'N04B');
INSERT INTO staging.atc (description, atc_code) VALUES ('dopaminergic agents', 'ZXX0068');
INSERT INTO staging.atc (description, atc_code) VALUES ('dopaminergic agents, apart from parkinson''s', 'ZXX0069');
INSERT INTO staging.atc (description, atc_code) VALUES ('dopaminergic anti-parkinson drugs', 'ZXX0039');
INSERT INTO staging.atc (description, atc_code) VALUES ('dopaminergic ergot alkaloids', 'ZXX0007');
INSERT INTO staging.atc (description, atc_code) VALUES ('dopexamine', 'C01CA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('doripenem', 'J01DH04');
INSERT INTO staging.atc (description, atc_code) VALUES ('doripenem (doripenem monohydrate)', 'J01DH04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dornase alfa', 'R05CB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('dornase alfa (desoxyribonuclease)', 'R05CB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('dorzolamide', 'S01EC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dorzolamide (dorzolamide hydrochloride)', 'S01EC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dosulepin', 'N06AA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxacurium chloride', 'M03AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxapram', 'R07AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxazosin', 'C02CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxefazepam', 'N05CD12');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxepin', 'N06AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxepin hydrochloride', 'D04AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxepin hydrochloride', 'N06AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxercalciferol', 'H05BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxofylline', 'R03DA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxorubicin', 'L01DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxorubicin hydrochloride', 'L01DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxycycline', 'J01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxycycline', 'A01AB22');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxycycline (doxycycline hyclate)', 'A01AB22');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxycycline hyclate', 'J01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxylamine', 'R06AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxylamine succinate', 'R06AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dronabinol', 'A04AD10');
INSERT INTO staging.atc (description, atc_code) VALUES ('dronedarone', 'C01BD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('dronedarone (dronedarone hydrochloride)', 'C01BD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('droperidol', 'N05AD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('droperidol', 'N01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dropropizine', 'R05DB19');
INSERT INTO staging.atc (description, atc_code) VALUES ('drospirenone and estrogen', 'G03FA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('drotaverine', 'A03AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('drotrecogin alfa', 'B01AD10');
INSERT INTO staging.atc (description, atc_code) VALUES ('drotrecogin alfa (activated)', 'B01AD10');
INSERT INTO staging.atc (description, atc_code) VALUES ('droxicam', 'M01AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('droxypropine', 'R05DB17');
INSERT INTO staging.atc (description, atc_code) VALUES ('drug used in alcohol dependence', 'N07BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs acting on serotonin receptors', 'A03AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs affecting bone structure and mineralization', 'M05B');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs for acid related desorders', 'A02');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs for bile therapy and lipotropics in combination', 'A05C');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs for embolisation', 'V03AM');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs for functional bowel disorders', 'A03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs for functional gastrointestinal disorders', 'A03');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs for obstructive airway', 'R03');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs for peptic ulcer and gastroesophageal reflux disease', 'A02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs for treatment of bone diseases', 'M05');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs for treatment of hypercalcemia', 'V03AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs for treatment of hyperkalemia and hyperphosphatemia', 'V03AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs for treatment of hypoglycemia', 'V03AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs for treatment of lepra', 'J04BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs for treatment of lepra', 'J04B');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs for treatment of tuberculosis', 'J04A');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs used in addictive disorders', 'N07B');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs used in benign prostatic hypertrophy', 'G04C');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs used in diabetes', 'A10');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs used in erectile dysfunction', 'G04BE');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs used in nicotine dependence', 'N07BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('drugs used in opioid dependence', 'N07BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('duloxetine', 'N06AX21');
INSERT INTO staging.atc (description, atc_code) VALUES ('duloxetine (duloxetine hydrochloride)', 'N06AX21');
INSERT INTO staging.atc (description, atc_code) VALUES ('dutasteride', 'G04CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dyclonine', 'R02AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dyclonine', 'N01BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dyclonine hydrochloride', 'R02AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dydrogesterone', 'G03DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dydrogesterone and estrogen', 'G03FA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('dydrogesterone and estrogen', 'G03FB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('dysprosium (165dy) colloid', 'V10AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ebastine', 'R06AX22');
INSERT INTO staging.atc (description, atc_code) VALUES ('econazole', 'G01AF05');
INSERT INTO staging.atc (description, atc_code) VALUES ('econazole', 'D01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ecothiopate', 'S01EB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ectoparasiticides, incl. scabicides', 'P03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('ectoparasiticides, incl. scabicides, insecticides and repellents', 'P03');
INSERT INTO staging.atc (description, atc_code) VALUES ('eculizumab', 'L04AA25');
INSERT INTO staging.atc (description, atc_code) VALUES ('edetate sodium', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('edetates', 'V03AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('edetic acid', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('edoxudine', 'D06BB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('edrecolomab', 'L03AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('edrecolomab', 'L01XC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('edrophonium chloride', 'V04CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('efalizumab', 'L04AA21');
INSERT INTO staging.atc (description, atc_code) VALUES ('efaproxiral', 'L01XD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('efavirenz', 'J05AG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('eflornithine', 'P01CX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('eflornithine', 'D11AX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('eflornithine hydrochloride', 'D11AX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('efloxate', 'C01DX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('elcatonin', 'H05BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('electrolyte solutions', 'B05XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('electrolytes', 'B05BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('electrolytes in combination with other drugs', 'B05XA31');
INSERT INTO staging.atc (description, atc_code) VALUES ('electrolytes with carbohydrates', 'B05BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('electrolytes with carbohydrates', 'A07C');
INSERT INTO staging.atc (description, atc_code) VALUES ('eletriptan', 'N02CC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('eletriptan (eletriptan hydrobromide)', 'N02CC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('eltrombopag', 'B02BX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('eltrombopag (eltrombopag olamine)', 'B02BX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('emedastine', 'S01GX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('emedastine (emedastine difumarate)', 'S01GX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('emepronium', 'G04BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('emepronium and psycholeptics', 'A03CA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('emepronium, combinations', 'N05CX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('emergency contraceptives', 'G03AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('emetine', 'P01AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('emetine, combinations', 'P01AX52');
INSERT INTO staging.atc (description, atc_code) VALUES ('emollients and protectives', 'D02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('emollients and protectives', 'D02');
INSERT INTO staging.atc (description, atc_code) VALUES ('emtricitabine', 'J05AF09');
INSERT INTO staging.atc (description, atc_code) VALUES ('emylcamate', 'N05BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('enalapril', 'C09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('enalapril and diuretics', 'C09BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('enalapril and lercanidipine', 'C09BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('enalapril maleate', 'C09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('enalapril sodium', 'C09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('enalaprilat', 'C09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('encainide', 'C01BC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('encephalitis vaccines', 'J07BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('encephalitis, japanese, inactivated, whole virus', 'J07BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('encephalitis, tick borne immunoglobulin', 'J06BB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('encephalitis, tick borne, inactivated, whole virus', 'J07BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('endocrine therapy', 'L02');
INSERT INTO staging.atc (description, atc_code) VALUES ('endralazine', 'C02DB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('enemas', 'A06AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('enflurane', 'N01AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('enfuvirtide', 'J05AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('enoxacin', 'J01MA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('enoxaparin', 'B01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('enoxaparin sodium', 'B01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('enoximone', 'C01CE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('enoxolone', 'D03AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('enprostil', 'A02BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('entacapone', 'N04BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('entecavir', 'J05AF10');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzyme and acid preparations, combinations', 'A09AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzyme converting inhibitors', 'ZXX0095');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzyme inducers', 'ZXX0094');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzyme inducing anticonvulsants', 'ZXX0028');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzyme inhibitors', 'L02BG');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzyme preparations', 'A09AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzymes', 'C04AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzymes', 'M09AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzymes', 'D03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzymes', 'B06AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzymes', 'A16AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzymes', 'B01AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzymes et preparations acides', 'A09AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('eosin', 'D08AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('epanolol', 'C07AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('eperisone', 'M03BX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('ephedrine', 'R03CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ephedrine', 'R01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ephedrine', 'S01FB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ephedrine', 'R01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ephedrine (oral or subcutaneous)', 'ZXX0005');
INSERT INTO staging.atc (description, atc_code) VALUES ('ephedrine sulfate', 'R03CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ephedrine, combinations', 'A08AA56');
INSERT INTO staging.atc (description, atc_code) VALUES ('epicillin', 'J01CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('epimestrol', 'G03GB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinastine', 'S01GX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinastine', 'R06AX24');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrine', 'R01AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrine', 'S01EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrine', 'C01CA24');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrine', 'A01AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrine', 'R03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrine', 'B02BC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrine (epinephrine hydrochloride)', 'R01AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrine and other drugs for obstructive airway diseases', 'R03AK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrine racemic', 'R03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrine, combinations', 'S01EA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('epirubicin', 'L01DB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('epirubicin hydrochloride', 'L01DB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('epitizide and potassium-sparing agents', 'C03EA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('eplerenone', 'C03DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('epoetin alfa', 'B03XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('epomediol', 'A05BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('epoprostenol', 'B01AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('epoprostenol (epoprostenol sodium)', 'B01AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('epoxides', 'L01AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('epoxy resin', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('eprazinone', 'R05CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('eprosartan', 'C09CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('eprosartan (eprosartan mesylate)', 'C09CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('eprosartan and diuretics', 'C09DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('eprozinol', 'R03DX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('eptacog alfa (activated)', 'B02BD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('eptifibatide', 'B01AC16');
INSERT INTO staging.atc (description, atc_code) VALUES ('eptotermin alfa', 'M05BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('erbium (169er) citrate colloid', 'V10AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('erdosteine', 'R05CB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergocalciferol', 'A11CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergoloid mesylates', 'C04AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergoloid mesylates, combinations', 'C04AE51');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergometrine', 'G02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergonovine maleate', 'G02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergot alkaloids', 'N02CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergot alkaloids', 'C04AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergot alkaloids', 'G02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergot alkaloids', 'G02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergot alkaloids and oxytocin incl. analogues, in combination', 'G02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergotamine', 'N02CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergotamine, combinations excl. psycholeptics', 'N02CA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergotamine, combinations with psycholeptics', 'N02CA72');
INSERT INTO staging.atc (description, atc_code) VALUES ('eritrityl tetranitrate', 'C01DA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('eritrityl tetranitrate, combinations', 'C01DA63');
INSERT INTO staging.atc (description, atc_code) VALUES ('erlotinib', 'L01XE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('erlotinib (erlotinib hydrochloride)', 'L01XE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ertapenem', 'J01DH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ertapenem (ertapenem sodium)', 'J01DH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythrocytes', 'B05AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythromycin', 'J01FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythromycin', 'S01AA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythromycin', 'D10AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythromycin (erythromycin estolate)', 'J01FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythromycin (erythromycin ethylsuccinate)', 'J01FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythromycin (erythromycin lactobionate)', 'J01FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythromycin (erythromycin stearate)', 'J01FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythromycin, combinations', 'D10AF52');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythropoietin', 'B03XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythrosine', 'V04C');
INSERT INTO staging.atc (description, atc_code) VALUES ('escitalopram', 'N06AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('escitalopram (escitalopram oxalate)', 'N06AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('esketamine', 'N01AX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('esmolol', 'C07AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('esmolol hydrochloride', 'C07AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('esomeprazole', 'A02BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('esomeprazole (esomeprazole magnesium trihydrate)', 'A02BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('esomeprazole (esomeprazole magnesium)', 'A02BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('esomeprazole, amoxicilline et clarithromycine', 'A02BD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('estazolam', 'N05CD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('esterified estrogens', 'G03CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('esters of aminobenzoic acid', 'N01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('esters of benzoic acid', 'N01BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('estradiol', 'G03CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('estradiol valerate', 'G03CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('estradiol, combinations', 'G03CA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('estramustine', 'L01XX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('estramustine phosphate sodium', 'L01XX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('estren derivatives', 'G03DC');
INSERT INTO staging.atc (description, atc_code) VALUES ('estren derivatives', 'A14AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('estriol', 'G03CC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('estriol', 'G03CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('estrogen-based contraceptives', 'ZXX0073');
INSERT INTO staging.atc (description, atc_code) VALUES ('estrogens', 'G03C');
INSERT INTO staging.atc (description, atc_code) VALUES ('estrogens', 'L02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('estrogens, combinations with other drugs', 'G03CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('estrone', 'G03CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('estrone', 'G03CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('estropipate', 'G03CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('etacrynic acid', 'C03CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etafenone', 'C01DX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('etallobarbital', 'N05CA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('etamiphylline', 'R03DA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('etamiphylline and adrenergics', 'R03DB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('etamivan', 'R07AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('etamsylate', 'B02BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etanautine', 'N04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etanercept', 'L04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethacridine lactate', 'B05CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethacridine lactate', 'D08AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethacrynic acid', 'C03CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethacrynic acid (sodium ethacrynate)', 'C03CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethadione', 'N03AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethambutol', 'J04AK02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethambutol and isoniazid', 'J04AM03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethambutol hydrochloride', 'J04AK02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethanol', 'D08AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethanol', 'V03AB16');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethanol', 'V03AZ01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethchlorvynol', 'N05CM08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethenzamide', 'N02BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethenzamide, combinations excl. psycholeptics', 'N02BA57');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethenzamide, combinations with psycholeptics', 'N02BA77');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethers', 'N01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethers chemically close to antihistamines', 'N04AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethers of tropine or tropine derivatives', 'N04AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethers, chemically close to antihistamines', 'M03BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethinylestradiol', 'G03CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethinylestradiol', 'L02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethionamide', 'J04AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethisterone', 'G03DC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethisterone and estrogen', 'G03FA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethopropazine (ethopropazine hydrochloride)', 'N04AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethosuximide', 'N03AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethosuximide, combinations', 'N03AD51');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethotoin', 'N03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethulose', 'A06AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethyl biscoumacetate', 'B01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethyl chloride', 'N01BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethyl esters of iodised fatty acids', 'V08AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethyl hydroxybenzoate', 'D01AE10');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethyl loflazepate', 'N05BA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethyl paraben', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethylene imines', 'L01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethylene oxide', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethylenediamine dihydrochloride', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethylestrenol', 'A14AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethylmorphine', 'S01XA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethylmorphine', 'R05DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etidocaine', 'N01BB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('etidocaine, combinations', 'N01BB57');
INSERT INTO staging.atc (description, atc_code) VALUES ('etidronate disodium', 'M05BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etidronic acid', 'M05BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etidronic acid and calcium', 'M05BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etifoxine', 'N05BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('etilamfetamine', 'A08AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('etilefrine', 'C01CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etilefrine, combinations', 'C01CA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('etilevodopa and decarboxylase inhibitor', 'N04BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('etizolam', 'N05BA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('etodolac', 'M01AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('etofamide', 'P01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('etofenamate', 'M02AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('etofibrate', 'C10AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('etofylline nicotinate', 'C04AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('etoglucid', 'L01AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etohexadiol', 'P03BX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('etomidate', 'N01AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('etonogestrel', 'G03AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('etoperidone', 'N06AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('etoposide', 'L01CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etoricoxib', 'M01AH05');
INSERT INTO staging.atc (description, atc_code) VALUES ('etozolin', 'C03CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etravirine', 'J05AG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('etretinate', 'D05BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etybenzatropine', 'N04AC30');
INSERT INTO staging.atc (description, atc_code) VALUES ('etynodiol', 'G03DC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('etynodiol and estrogen', 'G03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etynodiol and estrogen', 'G03FA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('euflavine', 'D08AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('eugenol', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('everolimus', 'L01XE10');
INSERT INTO staging.atc (description, atc_code) VALUES ('everolimus', 'L04AA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('exemestane', 'L02BG06');
INSERT INTO staging.atc (description, atc_code) VALUES ('exenatide', 'A10BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('expectorants', 'R05CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('expectorants, excl. combinations with cough suppressants', 'R05C');
INSERT INTO staging.atc (description, atc_code) VALUES ('ezetimibe', 'C10AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('factor viii inhibitor bypassing activity', 'B02BD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('famciclovir', 'J05AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('famciclovir', 'S01AD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('famotidine', 'A02BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('famotidine, combinations', 'A02BA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('fasudil', 'C04AX32');
INSERT INTO staging.atc (description, atc_code) VALUES ('fat emulsions', 'B05BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fat/carbohydrates/proteins/minerals/vitamins, combinations', 'V06DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('fatty acid derivatives', 'N03AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('fazadinium bromide', 'M03AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('feather', 'V01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('febarbamate', 'M03BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('febuxostat', 'M04AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fedrilate', 'R05DB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('felbamate', 'N03AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('felbinac', 'M02AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('felodipine', 'C08CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenamates', 'M01AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenbendazole', 'P02CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenbufen', 'M01AE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fencamfamin', 'N06BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('fendiline', 'C08EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenfluramine', 'A08AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenofibrate', 'C10AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenoldopam', 'C01CA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenoprofen', 'M01AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenoterol', 'R03CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenoterol', 'G02CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenoterol', 'R03AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenoterol and other drugs for obstructive airway diseases', 'R03AK03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenoverine', 'A03AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenoxazoline', 'R01AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenozolone', 'N06BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenpiprane', 'A03AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenpiverinium', 'A03AB21');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenquizone', 'C03BA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenspiride', 'R03DX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenspiride', 'R03BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fentanyl', 'N01AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fentanyl', 'N02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fentanyl (fentanyl citrate)', 'N02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fentanyl (fentanyl citrate)', 'N01AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fentanyl, combinations', 'N01AH51');
INSERT INTO staging.atc (description, atc_code) VALUES ('fentiazac', 'M01AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('fentiazac', 'M02AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenticonazole', 'D01AC12');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenticonazole', 'G01AF12');
INSERT INTO staging.atc (description, atc_code) VALUES ('fentonium', 'A03BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('feprazone', 'M02AA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('feprazone', 'M01AX18');
INSERT INTO staging.atc (description, atc_code) VALUES ('feprazone, combinations', 'M01AX68');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferric (59fe) citrate', 'V09XX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferric acetyl transferrin', 'B03AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferric ammonium citrate', 'V08CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferric citrate', 'B03AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferric hydroxide', 'B03AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferric oxide dextran complex', 'B03AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferric proteinsuccinylate', 'B03AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferric sodium citrate', 'B03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferric sodium gluconate complex', 'B03AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferric sorbitol gluconic acid complex', 'B03AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferristene', 'V08CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferrous amino acid complex', 'B03AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferrous ascorbate', 'B03AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferrous aspartate', 'B03AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferrous carbonate', 'B03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferrous chloride', 'B03AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferrous fumarate', 'B03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferrous fumarate', 'B03AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferrous gluconate', 'B03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferrous glycine sulfate', 'B03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferrous iodine', 'B03AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferrous succinate', 'B03AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferrous sulfate', 'B03AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferrous sulfate', 'B03AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferrous tartrate', 'B03AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferumoxsil', 'V08CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fesoterodine', 'G04BD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('fexofenadine', 'R06AX26');
INSERT INTO staging.atc (description, atc_code) VALUES ('fexofenadine hydrochloride', 'R06AX26');
INSERT INTO staging.atc (description, atc_code) VALUES ('fibrates', 'ZXX0074');
INSERT INTO staging.atc (description, atc_code) VALUES ('fibrates', 'C10AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('fibrates (except gemfibrozil)', 'ZXX0076');
INSERT INTO staging.atc (description, atc_code) VALUES ('fibrates (other)', 'ZXX0075');
INSERT INTO staging.atc (description, atc_code) VALUES ('fibrinogen', 'B02BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('fibrinogen (125i)', 'V09GB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fibrinogen, human', 'B02BC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('fibrinolysin', 'B01AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fibrinolysin and desoxyribonuclease', 'B06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('filgrastim', 'L03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('filgrastim (r-methug-csf)', 'L03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('finasteride', 'G04CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('finasteride', 'D11AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('fingolimod (fingolimod hydrochloride)', 'L04AA27');
INSERT INTO staging.atc (description, atc_code) VALUES ('fipexide', 'N06BX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('first-generation cephalosporins', 'J01DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('flavoxate', 'G04BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('flavoxate hydrochloride', 'G04BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('flecainide', 'C01BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('flecainide acetate', 'C01BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fleroxacin', 'J01MA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('floctafenine', 'N02BG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('flosequinan', 'C01DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flowers', 'V01AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluanisone', 'N05AD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('flubendazole', 'P02CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluclorolone', 'D07AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('flucloxacillin', 'J01CF05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluconazole', 'J02AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluconazole', 'D01AC15');
INSERT INTO staging.atc (description, atc_code) VALUES ('flucytosine', 'J02AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flucytosine', 'D01AE21');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludarabine', 'L01BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludarabine phosphate', 'L01BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludeoxyglucose (18f)', 'V09IX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludiazepam', 'N05BA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludrocortisone', 'H02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludrocortisone 21-acetate', 'H02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludrocortisone and antiinfectives', 'S02CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludrocortisone and antiinfectives', 'S01CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludrocortisone and antiinfectives', 'S03CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludroxycortide', 'D07AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludroxycortide and antibiotics', 'D07CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('flufenamic acid', 'M01AG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluindione', 'Z01AA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('flumazenil', 'V03AB25');
INSERT INTO staging.atc (description, atc_code) VALUES ('flumedroxone', 'N02CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flumequine', 'J01MB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('flumetasone', 'D07AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('flumetasone', 'D07XB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flumetasone and antibiotics', 'D07CB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('flumetasone and antiinfectives', 'S02CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('flumetasone and antiseptics', 'D07BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flunarizine', 'N07CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('flunarizine (flunarizine hydrochloride)', 'N07CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('flunisolide', 'R03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('flunisolide', 'R01AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('flunitrazepam', 'N05CD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('flunoxaprofen', 'M01AE15');
INSERT INTO staging.atc (description, atc_code) VALUES ('flunoxaprofen', 'G02CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinolone acetonide', 'S02BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinolone acetonide', 'D07AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinolone acetonide', 'C05AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinolone acetonide and antibiotics', 'D07CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinolone acetonide and antiinfectives', 'S02CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinolone acetonide and antiinfectives', 'S01CA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinolone acetonide and antiseptics', 'D07BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinonide', 'D07AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinonide', 'C05AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinonide and antibiotics', 'D07CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocortin', 'D07AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocortolone', 'C05AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocortolone', 'D07AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocortolone', 'H02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocortolone and antibiotics', 'D07CC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocortolone and antiinfectives', 'S01CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocortolone and antiseptics', 'D07BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorescein', 'S01JA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorescein sodium', 'S01JA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorescein sodium', 'V04CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorescein, combinations', 'S01JA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluoride', 'A12CD');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluoride, combinations', 'A12CD51');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorocarbon blood substitutes', 'B05AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholone', 'S01CB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholone', 'C05AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholone', 'D07AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholone', 'S01BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholone', 'D10AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholone', 'D07XB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholone acetate', 'S01BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholone and antibiotics', 'D07CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholone and antiinfectives', 'S01CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholone and mydriatics', 'S01BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluoromethylcholine (18f)', 'V09IX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluoroquinolones', 'J01MA');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluoroquinolones', 'ZXX0077');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorouracil', 'L01BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorouracil (and, by extrapolation, tegafur and capecitabine)', 'ZXX0078');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorouracil, combinations', 'L01BC52');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluostigmine', 'S01EB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluoxetine', 'N06AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluoxymesterone', 'G03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flupentixol', 'N05AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flupentixol (flupentixol dihydrochloride)', 'N05AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flupentixol decanoate', 'N05AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluperolone', 'D07AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluphenazine', 'N05AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluphenazine decanoate', 'N05AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluphenazine hydrochloride', 'N05AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('flupirtine', 'N02BG07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluprednidene', 'D07XB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluprednidene', 'D07AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluprednidene and antibiotics', 'D07CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('flurazepam', 'N05CD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flurazepam hydrochloride', 'N05CD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flurbiprofen', 'M02AA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('flurbiprofen', 'M01AE09');
INSERT INTO staging.atc (description, atc_code) VALUES ('flurbiprofen', 'S01BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('flurbiprofen', 'R02AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flurithromycin', 'J01FA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluspirilene', 'N05AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flutamide', 'L02BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluticasone', 'R01AD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluticasone', 'D07AC17');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluticasone', 'R03BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluticasone furoate', 'R01AD12');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluticasone propionate', 'D07AC17');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluticasone propionate', 'R01AD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluticasone propionate', 'R03BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('flutrimazole', 'G01AF18');
INSERT INTO staging.atc (description, atc_code) VALUES ('flutrimazole', 'D01AC16');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluvastatin', 'C10AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluvastatin (fluvastatin sodium)', 'C10AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluvoxamine', 'N06AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluvoxamine maleate', 'N06AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('folates', 'ZXX0079');
INSERT INTO staging.atc (description, atc_code) VALUES ('folic acid', 'B03BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('folic acid analogues', 'L01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('folic acid and derivatives', 'B03BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('folic acid, combinations', 'B03BB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('follitropin alfa', 'G03GA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('follitropin alpha', 'G03GA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('follitropin beta', 'G03GA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('fomepizole', 'V03AB34');
INSERT INTO staging.atc (description, atc_code) VALUES ('fomivirsen', 'S01AD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('fondaparinux', 'B01AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fondaparinux sodium', 'B01AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('food', 'V01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('formaldehyde', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('formestane', 'L02BG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('formocortal', 'S01BA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('formoterol', 'R03AC13');
INSERT INTO staging.atc (description, atc_code) VALUES ('formoterol and other drugs for obstructive airway diseases', 'R03AK07');
INSERT INTO staging.atc (description, atc_code) VALUES ('formoterol fumarate', 'R03AC13');
INSERT INTO staging.atc (description, atc_code) VALUES ('formoterol fumarate dihydrate', 'R03AC13');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosamprenavir', 'J05AE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosamprenavir (fosamprenavir calcium)', 'J05AE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosaprepitant (fosaprepitant dimeglumine)', 'A04AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('foscarnet', 'J05AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosfestrol', 'L02AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosfocreatine', 'C01EB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosfomycin', 'J01XX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosfonet', 'J05AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosinopril', 'C09AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosinopril and diuretics', 'C09BA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosinopril sodium', 'C09AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosphenytoin', 'N03AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosphenytoin sodium', 'N03AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fotemustine', 'L01AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fourth-generation cephalosporins', 'J01DE');
INSERT INTO staging.atc (description, atc_code) VALUES ('framycetin', 'R01AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('framycetin', 'S01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('framycetin', 'D09AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('framycetin sulfate', 'D09AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('framycetin sulfate', 'S01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('freediams interacting classes', 'ZXX');
INSERT INTO staging.atc (description, atc_code) VALUES ('freediams interacting molecules', 'Z00');
INSERT INTO staging.atc (description, atc_code) VALUES ('freediams specific codes', 'Z');
INSERT INTO staging.atc (description, atc_code) VALUES ('frovatriptan', 'N02CC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('frovatriptan (frovatriptan succinate)', 'N02CC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fructose', 'V06DC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fructose 1,6-diphosphate', 'C01EB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fulvestrant', 'L02BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fumaric acid', 'D05AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fumaric acid derivatives, combinations', 'D05BX51');
INSERT INTO staging.atc (description, atc_code) VALUES ('furazolidone', 'G01AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('furosemide', 'C03CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('furosemide and potassium', 'C03CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('furosemide and potassium-sparing agents', 'C03EB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fusafungine', 'R02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fusidate sodium', 'D06AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fusidic acid', 'S01AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('fusidic acid', 'D06AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fusidic acid', 'J01XC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fusidic acid', 'D09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('g-strophanthin', 'C01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gabapentin', 'N03AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadobenate dimeglumine', 'V08CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadobenic acid', 'V08CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadobutrol', 'V08CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadodiamide', 'V08CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadofosveset trisodium', 'V08CA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadopentetate dimeglumine', 'V08CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadopentetic acid', 'V08CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadoteric acid', 'V08CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadoteridol', 'V08CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadoversetamide', 'V08CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadoxetate disodium', 'V08CA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('galactose', 'V04CE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('galantamine', 'N06DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('galantamine (galantamine hydrobromide)', 'N06DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('gallamine', 'M03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('gallium (67ga) citrate', 'V09HX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gallopamil', 'C08DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('gamolenic acid', 'D11AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('gamolenic acid, combinations', 'D11AX52');
INSERT INTO staging.atc (description, atc_code) VALUES ('ganciclovir', 'S01AD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('ganciclovir', 'J05AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ganciclovir (ganciclovir sodium)', 'J05AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('gangliosides and ganglioside derivatives', 'N07XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('ganirelix', 'H01CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ganirelix (ganirelix acetate)', 'H01CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gas-gangrene sera', 'J06AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('gatifloxacin', 'S01AX21');
INSERT INTO staging.atc (description, atc_code) VALUES ('gatifloxacin', 'J01MA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('gedocarnil', 'N05BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('gefarnate', 'A02BX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('gefarnate, combinations with psycholeptics', 'A02BX77');
INSERT INTO staging.atc (description, atc_code) VALUES ('gefitinib', 'L01XE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('gelatin agents', 'B05AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('gemcitabine', 'L01BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('gemcitabine (gemcitabine hydrochloride)', 'L01BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('gemeprost', 'G02AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('gemfibrozil', 'C10AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('gemifloxacin', 'J01MA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('gemtuzumab', 'L01XC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('general nutrients', 'V06');
INSERT INTO staging.atc (description, atc_code) VALUES ('genito urinary system and sex hormones', 'G');
INSERT INTO staging.atc (description, atc_code) VALUES ('gentamicin', 'S01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('gentamicin', 'D06AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('gentamicin', 'S03AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('gentamicin', 'J01GB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('gentamicin', 'S02AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('gentamicin (gentamicin sulfate)', 'S01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('gentamicin (gentamicin sulfate)', 'J01GB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('gentamicin sulfate', 'S01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('gentian violet', 'D01AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('gepefrine', 'C01CA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('gepirone', 'N06AX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('geraniol', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestodene and estrogen', 'G03AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestodene and estrogen', 'G03AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestonorone', 'G03DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestonorone', 'L02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestrinone', 'G03XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ginkgo biloba', 'N06DX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ginkgo biloba', 'N06BX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('gitoformate', 'C01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('glafenine', 'N02BG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('glatiramer acetate', 'L03AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('glibenclamide', 'A10BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glibornuride', 'A10BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('gliclazide', 'A10BB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('glimepiride', 'A10BB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('glipizide', 'A10BB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('gliquidone', 'A10BB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('glisoxepide', 'A10BB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('glitazone blood glucose lowering drugs', 'ZXX0030');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucagon', 'H04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucagon (recombinant dna origin)', 'H04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucagon (recombinant dna origin) (glucagon hydrochloride)', 'H04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucocorticoids', 'H02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucocorticoids', 'R03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucocorticoids (except replacement therapy)', 'ZXX0081');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucosamine', 'M01AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucosaminoglycan polysulfate', 'M01AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucose', 'B05CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucose', 'V04CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucose', 'V06DC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucose, combinations', 'C05BB56');
INSERT INTO staging.atc (description, atc_code) VALUES ('glutamic acid hydrochloride', 'A09AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glutaral', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('glutathione', 'V03AB32');
INSERT INTO staging.atc (description, atc_code) VALUES ('glutathione disulfide', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('glutethimide', 'N05CE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glyburide', 'A10BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycerine', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycerine', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycerine', 'V07AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycerol', 'A06AG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycerol', 'A06AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glyceryl trinitrate', 'C01DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('glyceryl trinitrate', 'C05AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glyceryl trinitrate, combinations', 'C01DA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycine', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycine', 'B05CX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycine', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycobiarsol', 'P01AR03');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycobiarsol, combinations', 'P01AR53');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycogenolytic hormones', 'H04A');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycogenolytic hormones', 'H04AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycol salicylate', 'M02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycopeptide antibacterials', 'J01XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycopyrrolate', 'A03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycopyrronium', 'A03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycopyrronium and psycholeptics', 'A03CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('glymidine', 'A10BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gold (198au) colloidal', 'V10AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('gold preparations', 'M01CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('gold sodium thiomalate', 'M01CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('golimumab', 'L04AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('gonadorelin', 'H01CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gonadorelin', 'V04CM01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gonadorelin acetate', 'H01CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gonadotropin releasing hormone analogues', 'L02AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('gonadotropin-releasing hormones', 'H01CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('gonadotropins', 'G03GA');
INSERT INTO staging.atc (description, atc_code) VALUES ('gonadotropins and other ovulation stimulants', 'G03G');
INSERT INTO staging.atc (description, atc_code) VALUES ('goserelin', 'L02AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('goserelin (goserelin acetate)', 'L02AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('gramicidin', 'R02AB30');
INSERT INTO staging.atc (description, atc_code) VALUES ('gramicidin', 'D06AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('granisetron', 'A04AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('granisetron (granisetron hydrochloride)', 'A04AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('grapefruit juice', 'ZXX0103');
INSERT INTO staging.atc (description, atc_code) VALUES ('grass pollen', 'V01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('grepafloxacin', 'J01MA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('griseofulvin', 'D01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('griseofulvin', 'D01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('guacetisal', 'N02BA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('guaiacolsulfonate', 'R05CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('guaiazulen', 'S01XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('guaifenesin', 'R05CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanazodine', 'C02CC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanethidine', 'S01EX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanethidine', 'C02CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanethidine and diuretics', 'C02LF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanethidine sulfate', 'C02CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanfacine', 'C02AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanidine derivatives', 'C02CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanidine derivatives', 'C02DG');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanidine derivatives and diuretics', 'C02LF');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanoclor', 'C02CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanoxabenz', 'C02CC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanoxan', 'C02CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('guar gum', 'A10BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gusperimus', 'L04AA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('gynecological antiinfectives and antiseptics', 'G01');
INSERT INTO staging.atc (description, atc_code) VALUES ('h2-receptor antagonists', 'A02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('hachimycin', 'J02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hachimycin', 'D01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hachimycin', 'G01AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('halazepam', 'N05BA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('halcinonide', 'D07AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('halobetasol propionate', 'D07AC21');
INSERT INTO staging.atc (description, atc_code) VALUES ('halofantrine', 'P01BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('halogenated hydrocarbons', 'N01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('halometasone', 'D07AC12');
INSERT INTO staging.atc (description, atc_code) VALUES ('haloperidol', 'N05AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('haloperidol (haloperidol decanoate)', 'N05AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('haloprogin', 'D01AE11');
INSERT INTO staging.atc (description, atc_code) VALUES ('halothane', 'N01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('haloxazolam', 'Z01AA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('hamamelis virginiana', 'C05AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('helium', 'V03AN03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hematin', 'B06AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hemodialytics and hemofiltrates', 'B05Z');
INSERT INTO staging.atc (description, atc_code) VALUES ('hemodialytics, concentrates', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('hemofiltrates', 'B05ZB');
INSERT INTO staging.atc (description, atc_code) VALUES ('hemoglobin crosfumaril', 'B05AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('hemoglobine raffimer', 'B05AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('hemophilus influenzae b and hepatitis b', 'J07CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('hemophilus influenzae b and poliomyelitis', 'J07CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('hemophilus influenzae b vaccines', 'J07AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('hemophilus influenzae b, combinations with pertussis and toxoids', 'J07AG52');
INSERT INTO staging.atc (description, atc_code) VALUES ('hemophilus influenzae b, combinations with toxoids', 'J07AG51');
INSERT INTO staging.atc (description, atc_code) VALUES ('hemophilus influenzae b, purified antigen conjugated', 'J07AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparin', 'C05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparin', 'B01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparin', 'S01XA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparin group', 'B01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparin sodium', 'B01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparin, combinations', 'C05BA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparin, combinations', 'B01AB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparinoid, combinations', 'C05BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparins', 'ZXX0088');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparins or heparinoids for topical use', 'C05BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('hepatic and reticulo endothelial system', 'V09D');
INSERT INTO staging.atc (description, atc_code) VALUES ('hepatitis a immunoglobulin', 'J06BB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('hepatitis a vaccine, inactivated', 'J07BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hepatitis a, inactivated, whole virus', 'J07BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hepatitis b immune globulin human', 'J06BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('hepatitis b immunoglobulin', 'J06BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('hepatitis b surface antigen (recombinant)', 'J07BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hepatitis b, purified antigen', 'J07BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hepatitis vaccines', 'J07BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('heptabarbital', 'N05CA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('heptaminol', 'C01DX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('hetacillin', 'J01CA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('hetastarch', 'B05AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexachlorophene', 'D08AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexafluronium', 'M03AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexamidine', 'R02AA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexamidine', 'D08AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexamidine', 'S03AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexamidine', 'S01AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexamidine', 'R01AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexapropymate', 'N05CM10');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexetidine', 'A01AB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexobarbital', 'N01AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexobarbital', 'N05CA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexobendine', 'C01DX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexocyclium', 'A03AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexoprenaline', 'R03AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexoprenaline', 'R03CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexylresorcinol', 'R02AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('hidrosmin', 'C05CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('high-ceiling diuretics', 'C03C');
INSERT INTO staging.atc (description, atc_code) VALUES ('high-ceiling diuretics and potassium-sparing agents', 'C03EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('histamine', 'V04CG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('histamine h1 receptor antagonists', 'ZXX0211');
INSERT INTO staging.atc (description, atc_code) VALUES ('histamine phosphate', 'V04CG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('histamine phosphate', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('histapyrrodine', 'R06AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('histapyrrodine, combinations', 'R06AC52');
INSERT INTO staging.atc (description, atc_code) VALUES ('histidine', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('histrelin', 'H01CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('histrelin acetate', 'H01CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hmg coa reductase inhibitors', 'C10AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('hmg coa reductase inhibitors in comibnation with other lipid modifying agents', 'C10BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('hmg coa reductase inhibitors, other combinations', 'C10BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('homatropine', 'S01FA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('homatropine hydrobromide', 'S01FA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('homosalate', 'D11AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('honey bee venom protein', 'V01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('hormonal contraceptives for systemic use', 'G03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('hormone antagonists and related agents', 'L02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('hormones and related agents', 'L02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('hormons inhibitors', 'L02BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('house dust', 'V01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('human c1 esterase inhibitor', 'B02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('human fibrinogen', 'B02BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('human insulin', 'A10AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('human menopausal gonadotropin', 'G03GA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyaluronic acid', 'M09AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyaluronic acid', 'S01KA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyaluronic acid', 'D03AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyaluronic acid, combinations', 'S01KA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyaluronidase', 'B06AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydantoin derivatives', 'N03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydralazine', 'C02DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydralazine and diuretics', 'C02LG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydralazine hydrochloride', 'C02DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrazides', 'J04AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrazinophthalazine derivatives', 'C02DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrazinophthalazine derivatives and diuretics', 'C02LG');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrochloric acid', 'A09AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrochloric acid', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrochloric acid', 'B05XA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrochlorothiazide', 'C03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrochlorothiazide and potassium', 'C03AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrochlorothiazide and potassium-sparing agents', 'C03EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrochlorothiazide, combinations', 'C03AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocodone', 'R05DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocodone bitartrate', 'R05DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone', 'C05AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone', 'A07EA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone', 'D07XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone', 'H02AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone', 'S01CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone', 'S01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone', 'D07AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone', 'S02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone', 'A01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone aceponate', 'D07AC16');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone acetate', 'D07AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone acetate', 'A07EA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone acetate', 'S01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone and antibiotics', 'D07CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone and antiinfectives', 'S02CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone and antiinfectives', 'S01CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone and antiinfectives', 'S03CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone and antiseptics', 'D07BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone and mydriatics', 'S01BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone buteprate', 'D07AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone butyrate', 'D07AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone butyrate and antiseptics', 'D07BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone valerate', 'D07AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisone, combinations', 'R01AD60');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroflumethiazide', 'C03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroflumethiazide and potassium', 'C03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroflumethiazide, combinations', 'C03AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrogen peroxide', 'S02AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrogen peroxide', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrogen peroxide', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrogen peroxide', 'A01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrogen peroxide', 'D08AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydromorphone', 'N02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydromorphone and antispasmodics', 'N02AG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydromorphone hydrochloride', 'N02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroquinidine', 'Z01AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroquinine', 'M09AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroquinone', 'D11AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrotalcite', 'A02AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxocobalamin', 'V03AB33');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxocobalamin', 'B03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxocobalamin, combinations', 'B03BA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxybutyric acid', 'N01AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxycarbamide', 'L01XX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxychloroquine', 'P01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxychloroquine sulfate', 'P01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxycitronellal', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyethyl starch 130/0.4', 'B05AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyethylcellulose', 'S01FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyethylpromethazine', 'R06AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyethylpromethazine, combinations', 'R06AD55');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyprogesterone', 'G03DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyprogesterone and estrogen', 'G03FA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyquinoline derivatives', 'P01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyurea', 'L01XX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyzine', 'N05BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyzine, combinations', 'N05BB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('hymecromone', 'A05AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyoscine butylbromide', 'A04AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyoscine butylbromide', 'A03BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyoscyamine', 'A03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyoscyamine and psycholeptics', 'A03CB31');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyperkalemics', 'ZXX0084');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypertonic solutions', 'B05DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypnotics', 'ZXX0085');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypnotics and sedatives', 'N05C');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypnotics and sedatives in combination, excl. barbiturates', 'N05CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypokalemics', 'ZXX0086');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyponatremics', 'ZXX0087');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypotensive agents', 'ZXX0110');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypothalamic hormones', 'H01C');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyprolose', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypromellose', 'S01KA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypromellose', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('i.v. solution additives', 'B05X');
INSERT INTO staging.atc (description, atc_code) VALUES ('i.v. solutions', 'B05B');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibacitabine', 'D06BB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibandronic acid', 'M05BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibopamine', 'C01CA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibopamine', 'S01FB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibritumomab tiuxetan (90y)', 'V10XX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibudilast', 'R03DX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibudilast', 'R03DC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibuprofen', 'M01AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibuprofen', 'M02AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibuprofen', 'C01EB16');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibuprofen', 'G02CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibuprofen, combinations', 'M01AE51');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibuproxam', 'M01AE13');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibutilide', 'C01BD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibutilide fumarate', 'C01BD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('icatibant', 'C01EB19');
INSERT INTO staging.atc (description, atc_code) VALUES ('ichtasol', 'D10BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('iclaprim', 'J01EA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('idanpramine', 'A03AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('idarubicin', 'L01DB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('idarubicin hydrochloride', 'L01DB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('idebenone', 'N06BX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('idoxuridine', 'S01AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('idoxuridine', 'J05AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('idoxuridine', 'D06BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('idursulfase', 'A16AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('ifenprodil', 'C04AX28');
INSERT INTO staging.atc (description, atc_code) VALUES ('ifosfamide', 'L01AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('iloprost', 'B01AC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('imatinib', 'L01XE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('imatinib (imatinib mesylate)', 'L01XE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidapril', 'C09AA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazole and triazole derivatives', 'D01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazole derivatives', 'G01AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazole derivatives', 'A07AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazole derivatives', 'J01XD');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazole derivatives', 'J02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazole derivatives and corticosteroids', 'G01BF');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazole salicylate', 'N02BA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazoline derivatives', 'C04AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazoline receptor agonists', 'C02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazoline receptor agonists in combination with diuretics', 'C02LC');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazothiazole derivatives', 'P02CE');
INSERT INTO staging.atc (description, atc_code) VALUES ('imiglucerase', 'A16AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('imipenem and enzyme inhibitor', 'J01DH51');
INSERT INTO staging.atc (description, atc_code) VALUES ('imipramine', 'N06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('imipramine hydrochloride', 'N06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('imipramine oxide', 'N06AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('imipraminic antidepressants', 'ZXX0031');
INSERT INTO staging.atc (description, atc_code) VALUES ('imiquimod', 'D06BB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('immune globulin (human)', 'J06BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('immune globulin (human)', 'J06BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('immune sera', 'J06AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('immune sera', 'J06A');
INSERT INTO staging.atc (description, atc_code) VALUES ('immune sera and immunoglobulins', 'J06');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunocyanin', 'L03AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunoglobulin g (human)', 'J06BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunoglobulins', 'J06B');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunoglobulins, normal human', 'J06BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunoglobulins, normal human, for extravascular adm.', 'J06BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunoglobulins, normal human, for intravascular adm.', 'J06BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunostimulants', 'L03');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunosuppressive agents', 'L04A');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunosuppressive agents', 'L04');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunosuppressives', 'ZXX0093');
INSERT INTO staging.atc (description, atc_code) VALUES ('imolamine', 'C01DX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('inact.japanese encephal virus(attenuat. strain sa14-14-2 produced in vero cells)', 'J07BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('incontinence equipment', 'V07AN');
INSERT INTO staging.atc (description, atc_code) VALUES ('indacaterol', 'R03AC18');
INSERT INTO staging.atc (description, atc_code) VALUES ('indapamide', 'C03BA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('indifferent preparations', 'S02DC');
INSERT INTO staging.atc (description, atc_code) VALUES ('indigo carmine', 'V04CH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('indinavir', 'J05AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('indinavir (indinavir sulfate)', 'J05AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('indirect sympathomimetics', 'ZXX0142');
INSERT INTO staging.atc (description, atc_code) VALUES ('indium (111in) antiovariumcarcinoma antibody', 'V09IB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('indium (111in) capromab pendetide', 'V09IB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('indium (111in) compounds', 'V09HB');
INSERT INTO staging.atc (description, atc_code) VALUES ('indium (111in) compounds', 'V09IB');
INSERT INTO staging.atc (description, atc_code) VALUES ('indium (111in) imciromab', 'V09GX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('indium (111in) oxinate labelled cells', 'V09HB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('indium (111in) pentetic acid', 'V09AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('indium (111in) pentetreotide', 'V09IB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('indium (111in) satumomab pendetide', 'V09IB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('indium (111in) tropolonate labelled cells', 'V09HB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('indobufen', 'B01AC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('indocyanine green', 'V04CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('indole derivatives', 'N05AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('indometacin', 'S01BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('indometacin', 'M02AA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('indometacin', 'M01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('indometacin', 'C01EB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('indometacin, combinations', 'M01AB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('indomethacin', 'M01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('indomethacin (sodium indomethacin)', 'C01EB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('indoprofen', 'M01AE10');
INSERT INTO staging.atc (description, atc_code) VALUES ('indoramin', 'C02CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('inducers of p-glycoprotein', 'ZXX0162');
INSERT INTO staging.atc (description, atc_code) VALUES ('infant formulas', 'V06C');
INSERT INTO staging.atc (description, atc_code) VALUES ('inflammation and infection detection', 'V09H');
INSERT INTO staging.atc (description, atc_code) VALUES ('infliximab', 'L04AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('influenza vaccines', 'J07BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('influenza, inactivated, whole virus', 'J07BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('influenza, purified antigen', 'J07BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('inhaled corticoids', 'ZXX0055');
INSERT INTO staging.atc (description, atc_code) VALUES ('inhibitors of p-glycoprotein', 'ZXX0161');
INSERT INTO staging.atc (description, atc_code) VALUES ('inosine', 'D06BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('inosine', 'G01AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('inosine', 'S01XA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('inosine pranobex', 'J05AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('inositol', 'A11HA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('inositol nicotinate', 'C04AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('insecticides and repellents', 'P03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('insects', 'V01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin', 'ZXX0102');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (beef)', 'A10AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (beef)', 'A10AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (beef)', 'A10AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (beef)', 'A10AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (human)', 'A10AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (human)', 'A10AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (human)', 'A10AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (human)', 'A10AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (pork)', 'A10AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (pork)', 'A10AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (pork)', 'A10AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (pork)', 'A10AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin aspart', 'A10AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin detemir', 'A10AE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin glargine', 'A10AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin glulisine', 'A10AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin glulisine (recombinant dna origin)', 'A10AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin injection human biosynthetic', 'A10AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin injection pork', 'A10AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin isophane human biosynthetic', 'A10AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin isophane injection pork', 'A10AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin lispro', 'A10AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin lispro', 'A10AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin lispro', 'A10AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin nph human dna origin', 'A10AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin semi synthetic human', 'A10AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('insuline aspart', 'A10AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('insuline detemir', 'A10AE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('insuline glargine', 'A10AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulins and analogues', 'A10A');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulins and analogues for inhalation', 'A10AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulins and analogues, fast-acting', 'A10AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulins and analogues, intermediate-acting', 'A10AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulins and analogues, intermediate-acting combined with fast-acting', 'A10AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulins and analogues, long-acting', 'A10AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon', 'S01AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon alfa natural', 'L03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon alfa-2a', 'L03AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon alfa-2b', 'L03AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon alfa-n1', 'L03AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon alfacon-1', 'L03AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon beta natural', 'L03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon beta-1a', 'L03AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon beta-1b', 'L03AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon gamma', 'L03AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferons', 'L03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('interleukin inhibitors', 'L04AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('interleukins', 'L03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('intermediate-acting sulfonamides', 'J01EC');
INSERT INTO staging.atc (description, atc_code) VALUES ('intestinal adsorbents', 'A07B');
INSERT INTO staging.atc (description, atc_code) VALUES ('intestinal antiinfectives', 'A07A');
INSERT INTO staging.atc (description, atc_code) VALUES ('intestinal antiinflammatory agents', 'A07E');
INSERT INTO staging.atc (description, atc_code) VALUES ('intrauterine contraceptives', 'G02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('intravaginal contraceptives', 'G02BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('inulin and other polyfructosans', 'V04CH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('invert sugar', 'C05BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('iobenguane (123i)', 'V09IX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('iobenguane (131i)', 'V10XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('iobenguane (131i)', 'V09IX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('iobenzamic acid', 'V08AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('iobitridol', 'V08AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('iocarmic acid', 'V08AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('iocetamic acid', 'V08AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodamide', 'V08AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodide (sodium iodide)', 'A12CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodinated contrast products', 'ZXX0128');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine', 'C05BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine', 'D08AG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine (123i) compounds', 'V09AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine (124i) 2beta-carbomethoxy-3beta-(4 iodophenyl)-tropane', 'V09AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine (125i) cc49-monoclonal antibody', 'V09IX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine (125i) compounds', 'V09GB');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine (125i) human albumin', 'V09GB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine (131i) cholesterol', 'V09XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine (131i) compounds', 'V09XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine (131i) compounds', 'V10XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine (131i) human albumin', 'V09XA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine (131i) norcholesterol', 'V09XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine (ethiodized oil)', 'V08AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine (nonyl phenoxypoly ethoxy ethanol-iodine complex)', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine (nonyl phenoxypoly ethoxy ethanol-iodine)', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine (nonylphenyl-omega-hydroxypoly oxyethylene - iodine complex)', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine iofetamine (123i)', 'V09AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine ioflupane (123i)', 'V09AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine iolopride (123i)', 'V09AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine products', 'D08AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine therapy', 'H03C');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine therapy', 'H03CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodine/octylphenoxypolyglycolether', 'D08AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodixanol', 'V08AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodoform', 'D09AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodoheparinate', 'S01XA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodoxamic acid', 'V08AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('iofendylate', 'V08AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ioglicic acid', 'V08AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ioglycamic acid', 'V08AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('iohexol', 'V08AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('iomeprol', 'V08AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('iopamidol', 'V08AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('iopanoic acid', 'V08AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('iopentol', 'V08AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('iopromide', 'V08AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('iopydol', 'V08AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('iotalamic acid', 'V08AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('iothalamate meglumine', 'V08AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('iotrolan', 'V08AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('iotroxic acid', 'V08AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ioversol', 'V08AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ioxaglic acid', 'V08AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ioxilan', 'V08AB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('ioxitalamic acid', 'V08AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ipecacuanha', 'R05CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ipecacuanha', 'V03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ipratropium bromide', 'R03BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ipratropium bromide', 'R01AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('iprazochrome', 'N02CX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ipriflavone', 'M05BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('iprindole', 'N06AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('iproclozide', 'N06AF06');
INSERT INTO staging.atc (description, atc_code) VALUES ('iproniazide', 'N06AF05');
INSERT INTO staging.atc (description, atc_code) VALUES ('irbesartan', 'C09CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('irbesartan and diuretics', 'C09DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('irinotecan', 'L01XX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('irinotecan hydrochloride', 'L01XX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('irinotecan hydrochloride (irinotecan hydrochloride trihydrate)', 'L01XX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron (iron dextran complex)', 'B03AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron (iron sucrose)', 'B03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron (sodium ferric gluconate complex in sucrose injection)', 'B03AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron and multivitamins', 'B03AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron bivalent, oral preparations', 'B03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron chelating agents', 'V03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron in combination with folic acid', 'B03AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron in other combinations', 'B03AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron oxide, nanoparticles', 'V08CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron preparations', 'B03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron salts for injection', 'ZXX0135');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron trivalent, oral preparations', 'B03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron trivalent, parenteral preparations', 'B03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron, multivitamins and folic acid', 'B03AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron, multivitamins and minerals', 'B03AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron, vitamin b12 and folic acid', 'B03AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('iron-sorbitol-citric acid complex', 'B03AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('irrigating solutions', 'B05C');
INSERT INTO staging.atc (description, atc_code) VALUES ('isepamicin', 'J01GB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoaminile', 'R05DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('isobromindione', 'M04AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('isocarboxazid', 'N06AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoconazole', 'G01AF07');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoconazole', 'D01AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoetarine', 'R03AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoetarine', 'R03CC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoeugenol', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoflurane', 'N01AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoleucine', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('isometheptene', 'A03AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoniazid', 'J04AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoniazid, combinations', 'J04AC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoprenaline', 'C01CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoprenaline', 'R03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoprenaline', 'R03CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoprenaline and other drugs for obstructive airway diseases', 'R03AK02');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoprenaline, combinations', 'R03CB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('isopropamide', 'A03AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('isopropamide and psycholeptics', 'A03CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('isopropanol', 'D08AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('isopropyl alcohol', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('isopropyl myristate', 'P03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('isopropyl myristate', 'D02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoproterenol hydrochloride', 'C01CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('isosorbide dinitrate', 'C01DA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('isosorbide dinitrate', 'C05AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('isosorbide dinitrate, combinations', 'C01DA58');
INSERT INTO staging.atc (description, atc_code) VALUES ('isosorbide mononitrate', 'C01DA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('isosorbide-5-mononitrate', 'C01DA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('isothipendyl', 'D04AA22');
INSERT INTO staging.atc (description, atc_code) VALUES ('isothipendyl', 'R06AD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('isotonic solutions', 'B05DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('isotretinoin', 'D10BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('isotretinoin', 'D10AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('isotretinoin, combinations', 'D10AD54');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoxsuprine', 'C04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ispaghula (psylla seeds)', 'A06AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ispaghula, combinations', 'A06AC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('isradipine', 'C08CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('itraconazole', 'J02AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('itramin tosilate', 'C01DX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('itramin tosilate, combinations', 'C01DX51');
INSERT INTO staging.atc (description, atc_code) VALUES ('ivabradine', 'C01EB17');
INSERT INTO staging.atc (description, atc_code) VALUES ('ivermectin', 'P02CF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('josamycin', 'J01FA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('juniper tar', 'D05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('kallidinogenase', 'C04AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('kanamycin', 'S01AA24');
INSERT INTO staging.atc (description, atc_code) VALUES ('kanamycin', 'A07AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('kanamycin', 'J01GB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaolin', 'A07BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('kebuzone', 'M01AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('kentucky blue/june', 'V01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('kentucky bluegrass', 'V01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketamine', 'N01AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketamine (ketamine hydrochloride)', 'N01AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketanserin', 'C02KD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketazolam', 'N05BA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketobemidone', 'N02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketobemidone and antispasmodics', 'N02AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketoconazole', 'J02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketoconazole', 'G01AF11');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketoconazole', 'D01AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketoprofen', 'M01AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketoprofen', 'M02AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketoprofen, combinations', 'M01AE53');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketorolac', 'S01BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketorolac', 'M01AB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketorolac tromethamine', 'S01BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketorolac tromethamine', 'M01AB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketotifen', 'R06AX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketotifen', 'S01GX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketotifen (ketotifen fumarate)', 'R06AX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketotifen (ketotifen fumarate)', 'S01GX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketotifen fumarate', 'R06AX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('krypton (81mkr) gas', 'V09EX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('l-menthol', 'M02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('l-menthol', 'R02AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('labetalol', 'C07AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('labetalol and other diuretics', 'C07CG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('labetalol and thiazides', 'C07BG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('labetalol hydrochloride', 'C07AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lacidipine', 'C08CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('lacosamide', 'N03AX18');
INSERT INTO staging.atc (description, atc_code) VALUES ('lactic acid', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('lactic acid', 'G01AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lactic acid', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('lactic acid producing organisms', 'A07FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lactic acid producing organisms, combinations', 'A07FA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('lactitol', 'A06AD12');
INSERT INTO staging.atc (description, atc_code) VALUES ('lactobacillus fermentum', 'G01AX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('lactulose', 'A06AD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('lactulose, combinations', 'A06AD61');
INSERT INTO staging.atc (description, atc_code) VALUES ('lafutidine', 'A02BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('lamivudine', 'J05AF05');
INSERT INTO staging.atc (description, atc_code) VALUES ('lamotrigine', 'N03AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('lanatoside c', 'C01AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('lanolin', 'D02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('lanolin', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('lanreotide', 'H01CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lanreotide (lanreotide acetate)', 'H01CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lansoprazole', 'A02BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lansoprazole, amoxicillin and clarithromycin', 'A02BD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lansoprazole, amoxicillin and metronidazole', 'A02BD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lansoprazole, tetracycline and metronidazole', 'A02BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lanthanum (lanthanum carbonate hydrate)', 'V03AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lanthanum carbonate', 'V03AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lapatinib', 'L01XE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lapatinib (lapatinib ditosylate monohydrate)', 'L01XE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('laronidase', 'A16AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('latamoxef', 'J01DD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('latanoprost', 'S01EE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('latex based preservatives', 'ZXX0131');
INSERT INTO staging.atc (description, atc_code) VALUES ('laurilsulfate, incl. combinations', 'A06AG11');
INSERT INTO staging.atc (description, atc_code) VALUES ('laxatives', 'A06A');
INSERT INTO staging.atc (description, atc_code) VALUES ('laxatives', 'A06');
INSERT INTO staging.atc (description, atc_code) VALUES ('leflunomide', 'L04AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('lenalidomide', 'L04AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('lenograstim', 'L03AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('lentinan', 'L03AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lepirudin', 'B01AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lercanidipine', 'C08CA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('letosteine', 'R05CB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('letrozole', 'L02BG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('leucine', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('leucovorin (leucovorin calcium)', 'V03AF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('leukotriene receptor antagonists', 'R03DC');
INSERT INTO staging.atc (description, atc_code) VALUES ('leuprolide acetate', 'L02AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('leuprorelin', 'L02AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('levacetylmethadol', 'N07BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('levamisole', 'P02CE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('level ii opioids', 'ZXX0013');
INSERT INTO staging.atc (description, atc_code) VALUES ('level iii opioids', 'ZXX0014');
INSERT INTO staging.atc (description, atc_code) VALUES ('levetiracetam', 'N03AX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('levobunolol', 'S01ED03');
INSERT INTO staging.atc (description, atc_code) VALUES ('levobunolol hydrochloride', 'S01ED03');
INSERT INTO staging.atc (description, atc_code) VALUES ('levobupivacaine', 'N01BB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('levocabastine', 'S01GX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('levocabastine', 'R01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('levocabastine (levocabastine hydrochloride)', 'R01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('levocarnitine', 'A16AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('levocetirizine', 'R06AE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('levodopa', 'N04BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('levodopa and decarboxylase inhibitor', 'N04BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('levodopa, decarboxylase inhibitor and comt inhibitor', 'N04BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('levodropropizine', 'R05DB27');
INSERT INTO staging.atc (description, atc_code) VALUES ('levofloxacin', 'S01AX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('levofloxacin', 'J01MA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('levoglutamide', 'A16AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('levomepromazine', 'N05AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('levonorgestrel', 'G03AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('levonorgestrel', 'G02BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('levonorgestrel', 'G03AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('levonorgestrel and estrogen', 'G03FB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('levonorgestrel and estrogen', 'G03AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('levonorgestrel and estrogen', 'G03AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('levonorgestrel and estrogen', 'G03FA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('levosimendan', 'C01CX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('levosulpiride', 'N05AL07');
INSERT INTO staging.atc (description, atc_code) VALUES ('levothyroxine sodium', 'H03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('levoverbenone', 'R05CA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocaine', 'N01BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocaine', 'S02DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocaine', 'C01BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocaine', 'C05AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocaine', 'S01HA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocaine', 'D04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocaine', 'R02AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocaine (lidocaine hydrochloride)', 'R02AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocaine (lidocaine hydrochloride)', 'N01BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocaine hydrochloride', 'D04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocaine hydrochloride', 'N01BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocaine hydrochloride', 'C01BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocaine, combinations', 'N01BB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidoflazine', 'C08EX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lincomycin', 'J01FF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lincomycin (lincomycin hydrochloride)', 'J01FF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lincosamides', 'J01FF');
INSERT INTO staging.atc (description, atc_code) VALUES ('lincosanides', 'ZXX0104');
INSERT INTO staging.atc (description, atc_code) VALUES ('lindane', 'P03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('linezolid', 'J01XX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('linopirdine', 'N06BX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('linseed', 'A06AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('linseed, combinations', 'A06AC55');
INSERT INTO staging.atc (description, atc_code) VALUES ('linsidomine', 'C01DX18');
INSERT INTO staging.atc (description, atc_code) VALUES ('liothyronine', 'H03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('liothyronine sodium', 'H03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lipase', 'A09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lipid modifying agents, combinations', 'C10B');
INSERT INTO staging.atc (description, atc_code) VALUES ('liquid paraffin', 'A06AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('liquid paraffin, combinations', 'A06AA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('liquid plasters', 'D02AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('liraglutide', 'A10BX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lisdexamfetamine dimesylate', 'N06BA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('lisinopril', 'C09AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lisinopril and amlodipine', 'C09BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lisinopril and diuretics', 'C09BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lisuride', 'G02CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lisuride', 'N02CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lithium', 'N05AN');
INSERT INTO staging.atc (description, atc_code) VALUES ('lithium', 'N05AN01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lithium (lithium citrate)', 'N05AN01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lithium carbonate', 'N05AN01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lithium succinate', 'D11AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('live attenuated vaccine', 'ZXX0154');
INSERT INTO staging.atc (description, atc_code) VALUES ('live attenuated vaccine (except yellow fever)', 'ZXX0155');
INSERT INTO staging.atc (description, atc_code) VALUES ('liver therapy', 'A05BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('liver therapy, lipotropics', 'A05B');
INSERT INTO staging.atc (description, atc_code) VALUES ('local anesthetics', 'S01HA');
INSERT INTO staging.atc (description, atc_code) VALUES ('local anesthetics', 'S01H');
INSERT INTO staging.atc (description, atc_code) VALUES ('local hemostatics', 'B02BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('lodoxamide', 'S01GX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('lodoxamide (lodoxamide tromethamine)', 'S01GX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('lofepramine', 'N06AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lofexidine', 'N07BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('lomefloxacin', 'S01AX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('lomefloxacin', 'J01MA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lomustine', 'L01AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lonazolac', 'M01AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('long-acting sulfonamides', 'J01ED');
INSERT INTO staging.atc (description, atc_code) VALUES ('lonidamine', 'L01XX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('loop diuretics', 'ZXX0064');
INSERT INTO staging.atc (description, atc_code) VALUES ('loperamide', 'A07DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('loperamide hydrochloride', 'A07DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('loperamide oxide', 'A07DA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('loperamide, combinations', 'A07DA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('lopinavir', 'J05AE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('loprazolam', 'N05CD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('loracarbef', 'J01DC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('lorajmine', 'C01BA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('loratadine', 'R06AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('lorazepam', 'N05BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('lorazepam, combinations', 'N05BA56');
INSERT INTO staging.atc (description, atc_code) VALUES ('lorcainide', 'C01BC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lormetazepam', 'N05CD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('lornoxicam', 'M01AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('losartan', 'C09CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('losartan and diuretics', 'C09DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('losartan potassium', 'C09CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('loteprednol etabonate', 'S01BA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('lovastatin', 'C10AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lovastatin and nicotinic acid', 'C10BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('low molecular weight heparins and related (prophylactic doses)', 'ZXX0090');
INSERT INTO staging.atc (description, atc_code) VALUES ('low molecular weight heparins and related (therapeutic and in the elderly)', 'ZXX0089');
INSERT INTO staging.atc (description, atc_code) VALUES ('low-ceiling diuretics and potassium-sparing agents', 'C03EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('low-ceiling diuretics, excl. thiazides', 'C03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('low-ceiling diuretics, thiazides', 'C03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('low-energy diets', 'V06AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('loxapine', 'N05AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('loxapine (loxapine hydrochloride)', 'N05AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lumefantrine', 'Z01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lumiracoxib', 'M01AH06');
INSERT INTO staging.atc (description, atc_code) VALUES ('lung surfactants', 'R07AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('lutropin alfa', 'G03GA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lutropine alfa', 'G03GA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lymecycline', 'J01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('lymphocyte immune globulin anti-thymocyte globulin (equine)', 'L04AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lynestrenol', 'G03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lynestrenol', 'G03DC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lynestrenol and estrogen', 'G03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lynestrenol and estrogen', 'G03FA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lynestrenol and estrogen', 'G03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lynestrenol and estrogen', 'G03FB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lypressin', 'H01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lysine', 'B05XB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lysine (lysine monohydrochloride)', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('lysozyme', 'J05AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lysozyme', 'D06BB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('macrogol', 'A06AD15');
INSERT INTO staging.atc (description, atc_code) VALUES ('macrogol', 'R01AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('macrogol', 'R01AX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('macrogol, combinations', 'A06AD65');
INSERT INTO staging.atc (description, atc_code) VALUES ('macrolides', 'J01FA');
INSERT INTO staging.atc (description, atc_code) VALUES ('macrolides (except spiramycin)', 'ZXX0105');
INSERT INTO staging.atc (description, atc_code) VALUES ('macrolides, lincosamides and streptogramins', 'J01F');
INSERT INTO staging.atc (description, atc_code) VALUES ('mafenide', 'D06BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('magaldrate', 'A02AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('magaldrate and antiflatulents', 'A02AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium', 'A12CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium (different salts in combination)', 'A12CC30');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium aspartate', 'A12CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium carbonate', 'A02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium carbonate', 'A06AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium chloride', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium chloride', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium chloride', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium chloride', 'B05XA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium chloride', 'A12CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium citrate', 'A06AD19');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium citrate', 'B05CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium citrate', 'A12CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium compounds', 'A02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium gluconate', 'A12CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium hydroxide', 'G04BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium hydroxide', 'A02AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium lactate', 'A12CC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium levulinate', 'A12CC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium orotate', 'A12CC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium oxide', 'A02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium oxide', 'A06AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium oxide', 'A12CC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium peroxide', 'A02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium peroxide', 'A06AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium phosphate', 'B05XA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium pidolate', 'A12CC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium pyridoxal 5-phosphate glutamate', 'C10AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium silicate', 'A02AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium sulfate', 'D11AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium sulfate', 'A06AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium sulfate', 'V04CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium sulfate', 'A12CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium sulfate', 'B05XA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnetic resonance imaging contrast media', 'V08C');
INSERT INTO staging.atc (description, atc_code) VALUES ('malathion', 'P03AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mandelic acid', 'J01XX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('mandelic acid', 'B05CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('mangafodipir', 'V08CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('manganese (manganese sulfate)', 'A12CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('manidipine', 'C08CA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('mannitol', 'A06AD16');
INSERT INTO staging.atc (description, atc_code) VALUES ('mannitol', 'B05CX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('mannitol', 'B05BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mannosulfan', 'L01AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mao inhibitors', 'C02KC');
INSERT INTO staging.atc (description, atc_code) VALUES ('mao inhibitors and diuretics', 'C02LL');
INSERT INTO staging.atc (description, atc_code) VALUES ('maprotiline', 'N06AA21');
INSERT INTO staging.atc (description, atc_code) VALUES ('maprotiline hydrochloride', 'N06AA21');
INSERT INTO staging.atc (description, atc_code) VALUES ('maraviroc', 'J05AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('maribavir', 'J05AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('masoprocol', 'L01XX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('mazaticol', 'N04AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('mazindol', 'A08AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mebendazole', 'P02CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mebendazole, combinations', 'P02CA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('mebeverine', 'A03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('mebhydrolin', 'R06AX15');
INSERT INTO staging.atc (description, atc_code) VALUES ('mebutamate', 'N05BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('mebutizide', 'C03AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('mebutizide and potassium-sparing agents', 'C03EA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mecamylamine', 'C02BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mecasermin', 'H01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mechlorethamine hydrochloride', 'L01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mecillinam', 'J01CA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('meclocycline', 'D10AF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('meclofenamic acid', 'M02AA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('meclofenamic acid', 'M01AG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('meclofenoxate', 'N06BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('meclozine', 'R06AE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('meclozine, combinations', 'R06AE55');
INSERT INTO staging.atc (description, atc_code) VALUES ('medazepam', 'N05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('medical gases', 'V03AN');
INSERT INTO staging.atc (description, atc_code) VALUES ('medicated dressings', 'D09');
INSERT INTO staging.atc (description, atc_code) VALUES ('medicated dressings', 'D09A');
INSERT INTO staging.atc (description, atc_code) VALUES ('medicated shampoos', 'D11AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('medicinal charcoal', 'A07BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('medicinal charcoal, combinations', 'A07BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('medifoxamine', 'N06AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('medrogestone', 'G03DB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('medrogestone and estrogen', 'G03FB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('medroxyprogesterone', 'G03AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('medroxyprogesterone', 'G03DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('medroxyprogesterone', 'L02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('medroxyprogesterone acetate', 'G03DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('medroxyprogesterone acetate', 'G03AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('medroxyprogesterone and estrogen', 'G03FB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('medroxyprogesterone and estrogen', 'G03FA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('medroxyprogesterone and estrogen', 'G03AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('medrysone', 'S01BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('mefenamic acid', 'M01AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mefenidramium', 'Z01AA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('mefenorex', 'A08AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('mefloquine', 'P01BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mefloquine (mefloquine hydrochloride)', 'P01BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mefruside', 'C03BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mefruside and potassium', 'C03BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('megestrol', 'G03DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('megestrol', 'G03AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('megestrol', 'L02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('megestrol acetate', 'L02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('megestrol and estrogen', 'G03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('megestrol and estrogen', 'G03FA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('megestrol and estrogen', 'G03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('megestrol and estrogen', 'G03FB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('meglumine antimonate', 'P01CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('meglumine iodipamide', 'V08AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('meglutol', 'C10AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('meladrazine', 'G04BD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('melagatran', 'B01AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('melanoma vaccine', 'L03AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('melarsoprol', 'P01CD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('melatonin', 'N05CH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('melatonin receptor agonists', 'N05CH');
INSERT INTO staging.atc (description, atc_code) VALUES ('melevodopa', 'N04BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('melevodopa and decarboxylase inhibitor', 'N04BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('melitracen', 'N06AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('melitracen and psycholeptics', 'N06CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('meloxicam', 'M01AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('melperone', 'N05AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('melphalan', 'L01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('melphalan (melphalan hydrochloride)', 'L01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('memantine', 'N06DX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('memantine hydrochloride', 'N06DX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('menadione', 'B02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('meningococcal vaccines', 'J07AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('meningococcus a, purified polysaccharides antigen', 'J07AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('meningococcus b, outer membrane vesicle vaccine', 'J07AH06');
INSERT INTO staging.atc (description, atc_code) VALUES ('meningococcus c,purified polysaccharides antigen conjugated', 'J07AH07');
INSERT INTO staging.atc (description, atc_code) VALUES ('meningococcus, bivalent purified polysaccharides antigen', 'J07AH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('meningococcus, tetravalent purified polysaccharides antigen', 'J07AH04');
INSERT INTO staging.atc (description, atc_code) VALUES ('meningococcus, tetravalent purified polysaccharides antigen conjugated', 'J07AH08');
INSERT INTO staging.atc (description, atc_code) VALUES ('menotropins', 'G03GA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('menthol', 'M02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('menthol', 'D04AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('menthol', 'D04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('menthol', 'D11AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('menthol', 'M02AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('menthol', 'R02AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('menthol', 'D02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('menthol', 'D05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('menthol', 'R05CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepacrine', 'P01AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepartricin', 'G04CX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepartricin', 'D01AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepartricin', 'A01AB16');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepartricin', 'G01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepenzolate', 'A03AB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('meperidine (meperidine hydrochloride)', 'N02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('meperidine hydrochloride', 'N02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mephenesin', 'M03BX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('mephenoxalone', 'N05BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mephentermine', 'C01CA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('mephenytoin', 'N03AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('mephenytoin, combinations', 'N03AB54');
INSERT INTO staging.atc (description, atc_code) VALUES ('mephobarbital', 'Z01AA33');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepindolol', 'C07AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepivacaine', 'N01BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepivacaine hydrochloride', 'N01BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepivacaine, combinations', 'N01BB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepixanox', 'R07AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepolizumab', 'L04AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('meprednisone', 'H02AB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('meprobamate', 'N05BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('meprobamate, combinations', 'N05CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('meprobamate, combinations', 'N05BC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('meprotixol', 'R05DB22');
INSERT INTO staging.atc (description, atc_code) VALUES ('meptazinol', 'N02AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepyramine', 'R06AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepyramine', 'D04AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mequinol', 'D11AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('mequitazine', 'R06AD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('mercaptamine', 'A16AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('mercaptobenzothiazole', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('mercaptopurine', 'L01BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mercurial antiseptics', 'ZXX0040');
INSERT INTO staging.atc (description, atc_code) VALUES ('mercurial diuretics', 'C03BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('mercurial products', 'D08AK');
INSERT INTO staging.atc (description, atc_code) VALUES ('mercuric amidochloride', 'D08AK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mercuric chloride', 'D08AK03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mercuric iodide', 'D08AK30');
INSERT INTO staging.atc (description, atc_code) VALUES ('mercurochrome', 'D08AK04');
INSERT INTO staging.atc (description, atc_code) VALUES ('mercury compounds', 'S01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mercury, metallic', 'D08AK05');
INSERT INTO staging.atc (description, atc_code) VALUES ('meropenem', 'J01DH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mersalyl', 'C03BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mesalazine', 'A07EC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mesna', 'V03AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mesna', 'R05CB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mesoridazine', 'N05AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mesterolone', 'G03BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mesulfen', 'D10AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mesulfen', 'P03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mesuximide', 'N03AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('metabolized anticonvulsants', 'ZXX0029');
INSERT INTO staging.atc (description, atc_code) VALUES ('metabutethamine', 'N01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metacycline', 'J01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('metahexamide', 'A10BB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('metamfetamine', 'N06BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('metamizole sodium', 'N02BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metamizole sodium, combinations excl. psycholeptics', 'N02BB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('metamizole sodium, combinations with psycholeptics', 'N02BB72');
INSERT INTO staging.atc (description, atc_code) VALUES ('metampicillin', 'J01CA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('metandienone', 'A14AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('metandienone', 'D11AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metaraminol', 'C01CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('metenolone', 'A14AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('metergoline', 'G02CB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('metformin', 'A10BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metformin and rosiglitazone', 'A10BD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('metformin and sulfonamides', 'A10BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methacholine chloride', 'V04CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('methadone', 'N07BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methadone hydrochloride', 'N07BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methadone, comb. excl. psycholeptics', 'N02AC52');
INSERT INTO staging.atc (description, atc_code) VALUES ('methallenestril', 'G03CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methallenestril', 'G03CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methanolquinolines', 'P01BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('methantheline', 'A03AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('methapyrilene', 'R06AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('methaqualone', 'N05CM01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methaqualone, combinations', 'N05CX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metharbital', 'N03AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('methazolamide', 'S01EC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('methdilazine', 'R06AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methenamine', 'J01XX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('methenamine mandelate', 'J01XX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('methicillin', 'J01CF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methiodal', 'V08AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('methionine', 'V03AB26');
INSERT INTO staging.atc (description, atc_code) VALUES ('methiosulfonium chloride', 'A02BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methocarbamol', 'M03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methocarbamol, combinations excl. psycholeptics', 'M03BA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('methocarbamol, combinations with psycholeptics', 'M03BA73');
INSERT INTO staging.atc (description, atc_code) VALUES ('methohexital', 'N01AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methohexital', 'N05CA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('methoserpidine', 'C02AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('methoserpidine and diuretics', 'C02LA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methotrexate', 'L01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methotrexate (oral formulations only)', 'L04AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methotrimeprazine (methotrimeprazine hydrochloride)', 'N05AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methotrimeprazine (methotrimeprazine maleate)', 'N05AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methoxamine', 'C01CA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('methoxsalen', 'D05BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methoxsalen', 'D05AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methoxyflurane', 'N02BG09');
INSERT INTO staging.atc (description, atc_code) VALUES ('methoxyphenamine', 'R03CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methsuximide', 'N03AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyclothiazide', 'C03AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyclothiazide and potassium', 'C03AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyl aminolevulinate (methyl aminolevulinate hydrochloride)', 'L01XD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyl salicylate', 'M02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylatropine', 'A03BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylcellulose', 'A06AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylchloroisothiazolinone', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyldopa', 'C02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyldopa', 'C02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyldopa (levorotatory)', 'C02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyldopa (levorotatory) and diuretics', 'C02LB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyldopa (racemic)', 'C02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyldopa and diuretics in combination', 'C02LB');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyle aminolevulinate', 'L01XD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylene blue', 'V03AB17');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylene blue', 'V04CG05');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylenecycline', 'Z01AA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylergometrine', 'G02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylergometrine and oxytocin', 'G02AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylestrenolone', 'G03DC31');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylhomatropine and psycholeptics', 'A03CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylhydrazines', 'L01XB');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylnaltrexone bromide', 'A06AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylnortestosterone and estrogen', 'G03FA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylparaben', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylpentynol', 'N05CM15');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylpentynol, combinations', 'N05CX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylphenidate', 'N06BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylphenidate hydrochloride', 'N06BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylphenobarbital', 'N03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylprednisolone', 'H02AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylprednisolone', 'D07AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylprednisolone', 'D10AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylprednisolone (methylprednisolone sodium succinate)', 'H02AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylprednisolone aceponate', 'D07AC14');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylprednisolone acetate', 'H02AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylprednisolone and antibiotics', 'D07CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylprednisolone and antiinfectives', 'S01CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylprednisolone, combinations', 'H02BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylpropylpropanediol dinitrate', 'C01DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylpropylpropanediol dinitrate, combinations', 'C01DA54');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylrosaniline', 'G01AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylrosaniline', 'D01AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylscopolamine', 'S01FA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylscopolamine', 'A03BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylscopolamine and psycholeptics', 'A03CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyltestosterone', 'G03EK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyltestosterone', 'G03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyltestosterone and estrogen', 'G03EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylthioninium chloride', 'V04CG05');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylthioninium chloride', 'V03AB17');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylthiouracil', 'H03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyprylon', 'N05CE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methysergide', 'N02CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('meticrane', 'C03BA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('metildigoxin', 'C01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('metipranolol', 'S01ED04');
INSERT INTO staging.atc (description, atc_code) VALUES ('metipranolol and thiazides, combinations', 'C07BA68');
INSERT INTO staging.atc (description, atc_code) VALUES ('metipranolol, combinations', 'S01ED54');
INSERT INTO staging.atc (description, atc_code) VALUES ('metirosine', 'C02KB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metisazone', 'J05AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metixene', 'N04AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('metizoline', 'R01AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('metoclopramide', 'A03FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metoclopramide hydrochloride', 'A03FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metolazone', 'C03BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('metolazone and potassium-sparing agents', 'C03EA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('metopimazine', 'A04AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('metoprolol', 'C07AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metoprolol and other antihypertensives', 'C07FB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metoprolol and other diuretics', 'C07CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metoprolol and thiazides', 'C07BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metoprolol and thiazides, combinations', 'C07BB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('metoprolol tartrate', 'C07AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metoprolol, combination packages', 'C07AB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('metrifonate', 'P02BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metrizamide', 'V08AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metrizoic acid', 'V08AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metronidazole', 'P01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metronidazole', 'J01XD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metronidazole', 'A01AB17');
INSERT INTO staging.atc (description, atc_code) VALUES ('metronidazole', 'D06BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metronidazole', 'G01AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metyrapone', 'V04CD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mexiletine', 'C01BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mexiletine hydrochloride', 'C01BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mezlocillin', 'J01CA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('mianserin', 'N06AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mibefradil', 'C08CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('micafungin', 'J02AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('micafungin sodium', 'J02AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('miconazole', 'D01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('miconazole', 'A07AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('miconazole', 'J02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('miconazole', 'G01AF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('miconazole', 'A01AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('miconazole', 'S02AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('miconazole nitrate', 'G01AF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('miconazole, combinations', 'D01AC52');
INSERT INTO staging.atc (description, atc_code) VALUES ('micronomicin', 'S01AA22');
INSERT INTO staging.atc (description, atc_code) VALUES ('microparticles of galactose', 'V08DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('microspheres of human albumin', 'V08DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('microspheres of phospholipids', 'V08DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('midazolam', 'N05CD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('midazolam (midazolam hydrochloride)', 'N05CD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('midecamycin', 'J01FA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('midodrine', 'C01CA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('midodrine hydrochloride', 'C01CA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('mifepristone', 'G03XB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('miglitol', 'A10BF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('miglustat', 'A16AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('milk substitutes', 'V06DF');
INSERT INTO staging.atc (description, atc_code) VALUES ('millepertuis', 'Z01AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('milnacipran', 'N06AX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('milrinone', 'C01CE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('milrinone (milrinone lactate)', 'C01CE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('miltefosine', 'L01XX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('minaprine', 'N06AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('mineral oil', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('mineral oil', 'D02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('mineral oil', 'A06AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mineral oil light', 'D02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('mineral oils', 'ZXX0083');
INSERT INTO staging.atc (description, atc_code) VALUES ('mineral salts in combination', 'A06AD10');
INSERT INTO staging.atc (description, atc_code) VALUES ('mineral supplements', 'A12');
INSERT INTO staging.atc (description, atc_code) VALUES ('mineralocorticoids', 'ZXX0106');
INSERT INTO staging.atc (description, atc_code) VALUES ('mineralocorticoids', 'H02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('minocycline', 'A01AB23');
INSERT INTO staging.atc (description, atc_code) VALUES ('minocycline', 'J01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('minocycline (minocycline hydrochloride)', 'A01AB23');
INSERT INTO staging.atc (description, atc_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('minoxidil', 'D11AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('minoxidil', 'C02DC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('miocamycin', 'J01FA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('mirtazapine', 'N06AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('misoprostol', 'A02BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mitiglinide', 'A10BX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('mitobronitol', 'L01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mitoguazone', 'L01XX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('mitomycin', 'L01DC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mitotane', 'L01XX23');
INSERT INTO staging.atc (description, atc_code) VALUES ('mitoxantrone', 'L01DB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('mitoxantrone (mitoxantrone hydrochloride)', 'L01DB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('mivacurium chloride', 'M03AC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('mixed adrenergic-serotoninergic agents', 'ZXX0113');
INSERT INTO staging.atc (description, atc_code) VALUES ('mizolastine', 'R06AX25');
INSERT INTO staging.atc (description, atc_code) VALUES ('moclobemide', 'N06AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('modafinil', 'N06BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('moderate cytochrome p450 1a2 inhibitors', 'ZXX0166');
INSERT INTO staging.atc (description, atc_code) VALUES ('moderate cytochrome p450 2b6 inhibitors', 'ZXX0172');
INSERT INTO staging.atc (description, atc_code) VALUES ('moderate cytochrome p450 2c19 inhibitors', 'ZXX0190');
INSERT INTO staging.atc (description, atc_code) VALUES ('moderate cytochrome p450 2c8 inhibitors', 'ZXX0178');
INSERT INTO staging.atc (description, atc_code) VALUES ('moderate cytochrome p450 2c9 inhibitors', 'ZXX0184');
INSERT INTO staging.atc (description, atc_code) VALUES ('moderate cytochrome p450 2d6 inhibitors', 'ZXX0196');
INSERT INTO staging.atc (description, atc_code) VALUES ('moderate cytochrome p450 2e1 inhibitors', 'ZXX0202');
INSERT INTO staging.atc (description, atc_code) VALUES ('moderate cytochrome p450 3a4,5,7 inhibitors', 'ZXX0208');
INSERT INTO staging.atc (description, atc_code) VALUES ('modified ragweed tyrosine adsorbate', 'V01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('moexipril', 'C09AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('moexipril and diuretics', 'C09BA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('mofebutazone', 'M02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mofebutazone', 'M01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('molgramostim', 'L03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('molindone', 'N05AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('molsidomine', 'C01DX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('mometasone', 'R03BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('mometasone', 'D07AC13');
INSERT INTO staging.atc (description, atc_code) VALUES ('mometasone', 'R01AD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('mometasone', 'D07XC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mometasone furoate', 'R01AD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('mometasone furoate', 'D07AC13');
INSERT INTO staging.atc (description, atc_code) VALUES ('monoamine oxidase a inhibitors', 'N06AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('monoamine oxidase b inhibitors', 'N04BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('monoamine oxidase inhibitors, non-selective', 'N06AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('monobactams', 'J01DF');
INSERT INTO staging.atc (description, atc_code) VALUES ('monobenzone', 'D11AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('monoclonal antibodies', 'L01XC');
INSERT INTO staging.atc (description, atc_code) VALUES ('monoethanolamine oleate', 'C05BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('monoxerutin', 'C05CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('montelukast', 'R03DC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('montelukast (montelukast sodium)', 'R03DC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('moperone', 'N05AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('moracizine', 'C01BG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('morbilli immunoglobulin', 'J06BB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('morbilli vaccines', 'J07BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('morbilli, combinations with parotitis and rubella, live attenuated', 'J07BD52');
INSERT INTO staging.atc (description, atc_code) VALUES ('morbilli, combinations with parotitis, live attenuated', 'J07BD51');
INSERT INTO staging.atc (description, atc_code) VALUES ('morbilli, combinations with rubella, live attenuated', 'J07BD53');
INSERT INTO staging.atc (description, atc_code) VALUES ('morbilli, live attenuated', 'J07BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('morclofone', 'R05DB25');
INSERT INTO staging.atc (description, atc_code) VALUES ('morinamide', 'J04AK04');
INSERT INTO staging.atc (description, atc_code) VALUES ('morniflumate', 'M01AX22');
INSERT INTO staging.atc (description, atc_code) VALUES ('moroctocog alfa', 'B02BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('moroxydine', 'J05AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('morphinan derivatives', 'N02AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('morphine', 'N02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('morphine and antispasmodics', 'N02AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('morphine hydrochloride', 'N02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('morphine sulfate', 'N02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('morphine, combinations', 'N02AA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('morphine, combinations', 'A07DA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('morphine-based antitussives', 'ZXX0044');
INSERT INTO staging.atc (description, atc_code) VALUES ('morphine-like antitussives', 'ZXX0043');
INSERT INTO staging.atc (description, atc_code) VALUES ('morpholine salicylate', 'N02BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('mosapramine', 'N05AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('motretinide', 'D10AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mould fungus and yeast fungus', 'V01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('moxaverine', 'A03AD30');
INSERT INTO staging.atc (description, atc_code) VALUES ('moxestrol', 'G03CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('moxifloxacin', 'J01MA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('moxifloxacin (moxifloxacin hydrochloride)', 'J01MA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('moxifloxacin (moxifloxacin hydrochloride)', 'S01AX22');
INSERT INTO staging.atc (description, atc_code) VALUES ('moxisylyte', 'G04BE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('moxisylyte', 'C04AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('moxonidine', 'C02AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('moxonidine and diuretics', 'C02LC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mucolytics', 'R05CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('multienzymes (lipase, protease etc.)', 'A09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamins and calcium', 'A11AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamins and iron', 'A11AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamins and other minerals, incl. combinations', 'A11AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamins and trace elements', 'A11AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamins with minerals', 'A11AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamins, combinations', 'A11A');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamins, other combinations', 'A11AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamins, plain', 'A11B');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamins, plain', 'A11BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('mupirocin', 'D06AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('mupirocin', 'R01AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('mupirocin (mupirocin calcium dihydrate)', 'D06AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('muromonab-cd3', 'L04AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('muscle relaxants', 'C05AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('muscle relaxants', 'M03');
INSERT INTO staging.atc (description, atc_code) VALUES ('muscle relaxants, centrally acting agents', 'M03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('muscle relaxants, directly acting agents', 'M03C');
INSERT INTO staging.atc (description, atc_code) VALUES ('muscle relaxants, peripherally acting agents', 'M03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('musculo-skeletal system', 'M');
INSERT INTO staging.atc (description, atc_code) VALUES ('muzolimine', 'C03CD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mycophenolate mofetil', 'L04AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('mycophenolate mofetil (mycophenolate mofetil hydrochloride)', 'L04AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('mycophenolic acid', 'L04AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('mycophenolic acid (mycophenolate sodium)', 'L04AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('mydriatics and cycloplegics', 'S01F');
INSERT INTO staging.atc (description, atc_code) VALUES ('myristalkonium', 'Z01AA21');
INSERT INTO staging.atc (description, atc_code) VALUES ('myristamidopropyl dimethylamine', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('myristyl-benzalkonium', 'R02AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('n,n''-diphenyl-para-phenylenediamine', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('n-cyclohexyl-2-benzothiazolesulfenamide', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('n-cyclohexyl-n''-phenyl-para-phenylenediamine', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('n-hydroxymethylsuccinimide', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('n-isopropyl-n''-phenyl-para-phenylenediamine', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('nabilone', 'A04AD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('nabiximols', 'N02BG10');
INSERT INTO staging.atc (description, atc_code) VALUES ('nabumetone', 'M01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nadolol', 'C07AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('nadolol and thiazides', 'C07BA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('nadoxolol', 'Z01AA22');
INSERT INTO staging.atc (description, atc_code) VALUES ('nadroparin', 'B01AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('nadroparin calcium', 'B01AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('nafarelin', 'H01CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nafarelin (nafarelin acetate)', 'H01CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('naftidrofuryl', 'C04AX21');
INSERT INTO staging.atc (description, atc_code) VALUES ('naftifine', 'D01AE22');
INSERT INTO staging.atc (description, atc_code) VALUES ('nalbuphine', 'N02AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nalbuphine hydrochloride', 'N02AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nalfurafine', 'V03AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nalidixic acid', 'J01MB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nalorphine', 'V03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('naloxone', 'V03AB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('naloxone hydrochloride', 'V03AB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('naltrexone', 'N07BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('naltrexone hydrochloride', 'N07BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nandrolone', 'A14AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nandrolone', 'S01XA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('naphazoline', 'R01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('naphazoline', 'S01GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('naphazoline', 'R01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('naphazoline hydrochloride', 'S01GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('naphazoline nitrate', 'S01GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('naphazoline, combinations', 'S01GA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('naproxen', 'M02AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('naproxen', 'G02CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('naproxen', 'M01AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('naproxen (naproxen sodium)', 'M01AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('naproxen sodium', 'M01AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('naratriptan', 'N02CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('naratriptan (naratriptan hydrochloride)', 'N02CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('narcobarbital', 'N01AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nasal decongestants for systemic use', 'R01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('nasal preparations', 'R01');
INSERT INTO staging.atc (description, atc_code) VALUES ('natalizumab', 'L04AA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('natamycin', 'A01AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('natamycin', 'G01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('natamycin', 'S01AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('natamycin', 'A07AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('natamycin', 'D01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nateglinide', 'A10BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('natural and semisynthetic estrogens, plain', 'G03CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('natural opium alkaloids', 'N02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('natural phospholipids', 'R07AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nebacumab', 'J06BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nebivolol', 'C07AB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('nedocromil', 'R03BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('nedocromil', 'S01GX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nedocromil', 'R01AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('nedocromil sodium', 'S01GX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nefazodone', 'N06AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('nefopam', 'N02BG06');
INSERT INTO staging.atc (description, atc_code) VALUES ('nelarabine', 'L01BB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('nelfinavir', 'J05AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nelfinavir (nelfinavir mesylate)', 'J05AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('neltenexine', 'R05CB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'A01AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'S01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'S03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'B05CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'J01GB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'D06AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'A07AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'S02AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'R02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin sulfate', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin, combinations', 'A07AA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('neostigmine', 'S01EB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('neostigmine', 'N07AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('neostigmine bromide', 'N07AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('neostigmine methylsulfate', 'N07AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('neostigmine, combinations', 'N07AA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('nepafenac', 'S01BC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('nephrotoxic agents', 'ZXX0114');
INSERT INTO staging.atc (description, atc_code) VALUES ('nepinalone', 'R05DB26');
INSERT INTO staging.atc (description, atc_code) VALUES ('nerve depressants', 'V03AZ');
INSERT INTO staging.atc (description, atc_code) VALUES ('nervous system', 'N');
INSERT INTO staging.atc (description, atc_code) VALUES ('nesiritide', 'C01DX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('netilmicin', 'S01AA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('netilmicin', 'J01GB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('neuraminidase inhibitors', 'J05AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('neuroleptics', 'ZXX0119');
INSERT INTO staging.atc (description, atc_code) VALUES ('neuroleptics predisposing to torsades de pointes', 'ZXX0123');
INSERT INTO staging.atc (description, atc_code) VALUES ('neuroleptics, in tardive dyskinesia', 'N05AK');
INSERT INTO staging.atc (description, atc_code) VALUES ('nevirapine', 'J05AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nialamide', 'N06AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('niaprazine', 'N05CM16');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicardipine', 'C08CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicergoline', 'C04AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('niceritrol', 'C10AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nickel sulfate', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('niclosamide', 'P02DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicofetamide', 'A03AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicofuranose', 'C10AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicomorphine', 'N02AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicorandil', 'C01DX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotinamide', 'A11HA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotine', 'N07BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotine replacement agents', 'ZXX0148');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotinic acid', 'C10AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotinic acid', 'C04AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotinic acid and derivatives', 'C10AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotinic acid and derivatives', 'C04AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotinyl alcohol (pyridylcarbinol)', 'C04AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotinyl alcohol (pyridylcarbinol)', 'C10AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotinyl methylamide', 'A05AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifedipine', 'C08CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifedipine and diuretics', 'C08GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifedipine, combinations', 'C08CA55');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifenazone', 'M02AA24');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifenazone', 'N02BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('niflumic acid', 'M01AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('niflumic acid', 'M02AA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifuratel', 'G01AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifuroxazide', 'A07AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifurtimox', 'P01CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifurtoinol', 'J01XE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifurzide', 'A07AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nikethamide', 'R07AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nikethamide, combinations', 'R07AB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('nilotinib', 'L01XE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('nilotinib (nilotinib hydrochloride monohydrate)', 'L01XE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('nilutamide', 'L02BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nilvadipine', 'C08CA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('nimesulide', 'M01AX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('nimetazepam', 'Z01AA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('nimodipine', 'C08CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('nimorazole', 'P01AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('nimustine', 'L01AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('niperotidine', 'A02BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('niridazole', 'P02BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nisoldipine', 'C08CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitisinone', 'A16AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrate derived and related', 'ZXX0071');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrazepam', 'N05CD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrendipine', 'C08CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitric oxide', 'R07AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitro-imidazoles', 'ZXX0124');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitroferricyanide derivatives', 'C02DD');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofural', 'S02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofural', 'D08AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofural', 'B05CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofural', 'S01AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofural', 'P01CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofural', 'D09AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofuran derivatives', 'D08AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofuran derivatives', 'J01XE');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofuran derivatives', 'P01CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofurantoin', 'J01XE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrogen', 'V03AN05');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrogen', 'V03AN04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrogen mustard analogues', 'L01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitroglycerin', 'C01DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitroimidazole derivatives', 'P01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitroimidazole derivatives', 'P01CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitroprusside', 'C02DD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrosoureas', 'L01AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrous oxide', 'N01AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitroxoline', 'J01XX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('nizatidine', 'A02BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nizofenone', 'N06BX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('nomegestrol', 'G03DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nomegestrol and estrogen', 'G03AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('nomifensine', 'N06AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('non depolarizing curare alkaloids', 'ZXX0057');
INSERT INTO staging.atc (description, atc_code) VALUES ('non pollen', 'V01AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('non-contraceptive estrogens', 'ZXX0072');
INSERT INTO staging.atc (description, atc_code) VALUES ('non-nucleoside reverse transcriptase inhibitors', 'J05AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('non-selective beta-adrenoreceptor agonists', 'R03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('non-selective beta-adrenoreceptor agonists', 'R03CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('non-selective calcium channel blockers', 'C08E');
INSERT INTO staging.atc (description, atc_code) VALUES ('non-selective monoamine reuptake inhibitors', 'N06AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('non-steroidal anti-inflammatories', 'ZXX0021');
INSERT INTO staging.atc (description, atc_code) VALUES ('non-watersoluble x-ray contrast media', 'V08AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('nonacog alfa', 'B02BD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('nonoxynol 9', 'Z01AA24');
INSERT INTO staging.atc (description, atc_code) VALUES ('nonselective maoi', 'ZXX0001');
INSERT INTO staging.atc (description, atc_code) VALUES ('nonyl phenoxypoly ethoxy ethanol-iodine', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('nonyl phenoxypoly ethoxy ethanol-iodine complex', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('nonylphenoxypoly(ethyleneoxy)ethanol-iodine complex', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('nordazepam', 'N05BA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('norelgestromin and estrogen', 'G03AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('norepinephrine', 'C01CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('norepinephrine (norepinephrine bitartrate)', 'C01CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('norethandrolone', 'A14AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('norethindrone', 'G03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('norethindrone acetate', 'G03DC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('norethisterone', 'G03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('norethisterone', 'G03DC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('norethisterone and estrogen', 'G03FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('norethisterone and estrogen', 'G03AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('norethisterone and estrogen', 'G03AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('norethisterone and estrogen', 'G03FB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('noretynodrel and estrogen', 'G03FA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('norfenefrine', 'C01CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('norfloxacin', 'S01AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('norfloxacin', 'J01MA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('norgestimate and estrogen', 'G03AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('norgestimate and estrogen', 'G03FA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('norgestrel and estrogen', 'G03FA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('norgestrel and estrogen', 'G03AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('norgestrel and estrogen', 'G03FB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('norgestrienone', 'G03AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('normethadone', 'R05DA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('nortriptyline', 'N06AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('nortriptyline hydrochloride', 'N06AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('noscapine', 'R05DA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('noxytiolin', 'B05CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('nucleoside and nucleotide reverse transcriptase inhibitors', 'J05AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('nucleosides and nucleotides excl. reverse transcriptase inhibitors', 'J05AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('nutrients without phenylalanine', 'V06CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('nylidrin hydrochloride', 'C04AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nystatin', 'G01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nystatin', 'A07AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nystatin', 'D01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nystatin, combinations', 'G01AA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('o-phenylphenol', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('oak moss', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('obidoxime', 'V03AB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('oblimersen', 'L01XX36');
INSERT INTO staging.atc (description, atc_code) VALUES ('octanoic acid', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('octenidine, combinations', 'D08AJ57');
INSERT INTO staging.atc (description, atc_code) VALUES ('octenidine, combinations', 'G01AX66');
INSERT INTO staging.atc (description, atc_code) VALUES ('octinoxate', 'D11AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('octinoxate', 'D02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('octocrylene', 'D11AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('octopamine', 'C01CA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('octreotide', 'H01CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('octreotide (octreotide acetate)', 'H01CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('octyl methoxycinnamate', 'D02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ocular vascular disorder agents', 'S01L');
INSERT INTO staging.atc (description, atc_code) VALUES ('ofatumumab', 'L01XC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('ofloxacin', 'S01AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('ofloxacin', 'J01MA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ofloxacin', 'S02AA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('oil', 'A06AG06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ointment dressings with antiinfectives', 'D09AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('olaflur', 'A01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('olanzapine', 'N05AH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('olanzapine (olanzapine tartrate)', 'N05AH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oleandomycin', 'J01FA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('olmesartan  medoxomil', 'C09CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('olmesartan medoxomil', 'C09CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('olmesartan medoxomil and amlodipine', 'C09DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('olopatadine', 'S01GX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('olopatadine (olopatadine hydrochloride)', 'S01GX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('olsalazine', 'A07EC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('olsalazine sodium', 'A07EC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('omalizumab', 'R03DX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('omapatrilat', 'C09EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('omega-3-triglycerides', 'C10AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('omeprazole', 'A02BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('omeprazole (omeprazole magnesium)', 'A02BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('omeprazole, amoxicillin and clarithromycin', 'A02BD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('omeprazole, amoxicillin and metronidazole', 'A02BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('omoconazole', 'D01AC13');
INSERT INTO staging.atc (description, atc_code) VALUES ('omoconazole', 'G01AF16');
INSERT INTO staging.atc (description, atc_code) VALUES ('ondansetron', 'A04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ondansetron (ondansetron hydrochloride)', 'A04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ophthalmological and otological preparations', 'S03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ophthalmologicals', 'S01');
INSERT INTO staging.atc (description, atc_code) VALUES ('opioid agonist-antagonists', 'ZXX0108');
INSERT INTO staging.atc (description, atc_code) VALUES ('opioid anesthetics', 'N01AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('opioids', 'ZXX0107');
INSERT INTO staging.atc (description, atc_code) VALUES ('opioids', 'N02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('opioids in combination with antispasmodics', 'N02AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('opioids in substitution therapy', 'ZXX0109');
INSERT INTO staging.atc (description, atc_code) VALUES ('opipramol', 'N06AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('opium', 'A07DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('opium', 'N02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('opium alkaloids and derivatives', 'R05DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('opium alkaloids with morphine', 'R05DA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('opium derivatives and expectorants', 'R05FA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('opium derivatives and expectorants', 'R05FA');
INSERT INTO staging.atc (description, atc_code) VALUES ('opium derivatives and mucolytics', 'R05FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('oprelvekin', 'L03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oral anticoagulants', 'ZXX0027');
INSERT INTO staging.atc (description, atc_code) VALUES ('oral blood glucose lowering drugs', 'A10B');
INSERT INTO staging.atc (description, atc_code) VALUES ('oral rehydration salt formulations', 'A07CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('orciprenaline', 'R03AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('orciprenaline', 'R03CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('orciprenaline sulfate', 'R03CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('orciprenaline, combinations', 'R03CB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('ordinary salt combinations', 'A02AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ordinary salt combinations and antiflatulents', 'A02AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('organic acids', 'G01AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('organic nitrates', 'C01DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('organic nitrates in combination', 'C01DA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('organic nitrates in combination with psycholeptics', 'C01DA70');
INSERT INTO staging.atc (description, atc_code) VALUES ('organo-heparinoid', 'C05BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('organophosphorous compounds', 'P02BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('organoplatinum compounds', 'ZXX0125');
INSERT INTO staging.atc (description, atc_code) VALUES ('orgotein', 'M01AX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('oripavine derivatives', 'N02AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('oritavancin', 'J01XA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('orlistat', 'A08AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ornidazole', 'G01AF06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ornidazole', 'P01AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ornidazole', 'J01XD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ornipressin', 'H01BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ornithine oxoglurate', 'A05BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('orphenadrine (chloride)', 'N04AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('orphenadrine (citrate)', 'M03BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('orphenadrine citrate', 'M03BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('orphenadrine, combinations', 'M03BC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('ortho-phthalaldehyde', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('oseltamivir', 'J05AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oseltamivir (oseltamivir phosphate)', 'J05AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('osmotically acting laxatives', 'A06AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('other agents acting on the renin-angiotensin system', 'C09X');
INSERT INTO staging.atc (description, atc_code) VALUES ('other agents against amoebiasis and other protozoal diseases', 'P01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other agents against leishmaniasis and trypanosomiasis', 'P01CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other agents for local oral treatment', 'A01AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('other agents predisposing to torsades de pointes', 'ZXX0045');
INSERT INTO staging.atc (description, atc_code) VALUES ('other alimentary tract and metabolism products', 'A16');
INSERT INTO staging.atc (description, atc_code) VALUES ('other alimentary tract and metabolism products', 'A16A');
INSERT INTO staging.atc (description, atc_code) VALUES ('other alkylating agents', 'L01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other aminoglycosides', 'J01GB');
INSERT INTO staging.atc (description, atc_code) VALUES ('other anabolic agents', 'A14B');
INSERT INTO staging.atc (description, atc_code) VALUES ('other analgesics and antipyretics', 'N02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('other analgesics and antipyretics', 'N02BG');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antacids, drugs for treatment of peptic ulcer and flatulence', 'A02X');
INSERT INTO staging.atc (description, atc_code) VALUES ('other anterior pituitary lobe hormones and analogues', 'H01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other anti-acne preparations for systemic use', 'D10BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other anti-acne preparations for topical use', 'D10AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other anti-dementia drugs', 'N06DX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other anti-parathyroid agents', 'H05BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antiallergics', 'S01GX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antianemic preparations', 'B03XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antianemic preparations', 'B03X');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antibacterials', 'J01XX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antibacterials', 'J01X');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antibiotics for topical use', 'D06AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other anticestodals', 'P02DX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antidepressants', 'N06AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antidiarrheals', 'A07X');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antidiarrheals', 'A07XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antiemetics', 'A04AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antiepileptics', 'N03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antifungals for topical use', 'D01AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antiglaucoma preparations', 'S01EX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antigout preparations', 'M04AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antihemorrhoidals for topical use', 'C05AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antihistamines for systemic use', 'R06AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antihypertensives', 'C02KX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antihypertensives', 'C02K');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antihypertensives and diuretics', 'C02LX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antiinfectives', 'S01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antiinfectives and antiseptics', 'G01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antiinflammatory and antirheumatic agents, non-steroids', 'M01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antiinflammatory therapeutic radiopharmaceuticals', 'V10AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antiinflammatory/antirheumatic agents in combination with other drugs', 'M01BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antimalarials', 'P01BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antimigraine preparations', 'N02CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antimycotics for systemic use', 'J02AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antinematodals', 'P02CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antineoplastic agents', 'L01XX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antineoplastic agents', 'L01X');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antipruritics', 'D04AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antipsoriatics for systemic use', 'D05BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antipsoriatics for topical use', 'D05AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antipsychotics', 'N05AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antiseptics and disinfectants', 'D08AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antispasmodics in combination with analgesics', 'A03DC');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antispasmodics in combination with psycholeptics', 'A03CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antithrombotic agents', 'B01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antithyroid preparations', 'H03BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antitrematodal agents', 'P02BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other antivirals', 'J05AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other anxiolytics', 'N05BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other bacterial vaccines', 'J07AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other beta-lactam antibacterials', 'J01D');
INSERT INTO staging.atc (description, atc_code) VALUES ('other blood products', 'B05AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other capillary stabilizing agents', 'C05CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cardiac combination products', 'C01EX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cardiac glycosides', 'C01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cardiac preparations', 'C01EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cardiac preparations', 'C01E');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cardiac stimulants', 'C01CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cardiovascular system diagnostic radiopharmaceuticals', 'V09GX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other central nervous system diagnostic radiopharmaceuticals', 'V09AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other centrally acting agents', 'M03BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cephalosporins', 'J01DI');
INSERT INTO staging.atc (description, atc_code) VALUES ('other chemotherapeutics', 'D06BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cholesterol and triglyceride reducers', 'C10AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cicatrizants', 'D03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other class i antiarrhythmics', 'C01BG');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cold combination preparations', 'R05X');
INSERT INTO staging.atc (description, atc_code) VALUES ('other combinations of nutrients', 'V06DX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cough suppressants', 'R05DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cough suppressants and expectorants', 'R05FB');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cytochrome p450 1a2 inhibitors', 'ZXX0168');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cytochrome p450 2b6 inhibitors', 'ZXX0174');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cytochrome p450 2c19 inhibitors', 'ZXX0192');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cytochrome p450 2c8 inhibitors', 'ZXX0180');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cytochrome p450 2c9 inhibitors', 'ZXX0186');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cytochrome p450 2d6 inhibitors', 'ZXX0198');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cytochrome p450 2e1 inhibitors', 'ZXX0204');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cytochrome p450 3a4,5,7 inhibitors', 'ZXX0210');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cytokines and immunomodulators', 'L03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other cytotoxic antibiotics', 'L01DC');
INSERT INTO staging.atc (description, atc_code) VALUES ('other dermatological preparations', 'D11');
INSERT INTO staging.atc (description, atc_code) VALUES ('other dermatological preparations', 'D11A');
INSERT INTO staging.atc (description, atc_code) VALUES ('other dermatologicals', 'D11AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other diagnostic agents', 'V04CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other diagnostic agents', 'V04C');
INSERT INTO staging.atc (description, atc_code) VALUES ('other diagnostic radiopharmaceuticals', 'V09X');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxiconazole', 'G01AF17');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxiconazole', 'D01AC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('other diagnostic radiopharmaceuticals for inflammation and infection detection', 'V09HX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other diagnostic radiopharmaceuticals for tumour detection', 'V09IX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other dopaminergic agents', 'N04BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other drugs affecting mineralization', 'M05BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other drugs for bile therapy', 'A05AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other drugs for disorders of the musculo-skeletal system', 'M09');
INSERT INTO staging.atc (description, atc_code) VALUES ('other drugs for disorders of the musculo-skeletal system', 'M09AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other drugs for disorders of the musculo-skeletal system', 'M09A');
INSERT INTO staging.atc (description, atc_code) VALUES ('other drugs for functional bowel disorders', 'A03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other drugs for obstructive airway diseases, inhalants', 'R03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('other drugs for obstructive airway diseases, inhalants', 'R03BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other drugs for peptic ulcer and gastroesophageal reflux disease', 'A02BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other drugs for treatment of tuberculosis', 'J04AK');
INSERT INTO staging.atc (description, atc_code) VALUES ('other drugs used in benign prostatic hypertrophy', 'G04CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other drugs used in diabetes', 'A10X');
INSERT INTO staging.atc (description, atc_code) VALUES ('other ectoparasiticides, incl. scabicides', 'P03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other emollients and protectives', 'D02AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other estrogens', 'G03CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other general anesthetics', 'N01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other gynecologicals', 'G02CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other gynecologicals', 'G02C');
INSERT INTO staging.atc (description, atc_code) VALUES ('other gynecologicals', 'G02');
INSERT INTO staging.atc (description, atc_code) VALUES ('other hem products', 'B06AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('other hematological agents', 'B06');
INSERT INTO staging.atc (description, atc_code) VALUES ('other hematological agents', 'B06A');
INSERT INTO staging.atc (description, atc_code) VALUES ('other hepatic and reticulo endothelial system diagnostic radiopharmaceuticals', 'V09DX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other high-ceiling diuretics', 'C03CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other hormones', 'L02AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other hypnotics and sedatives', 'N05CM');
INSERT INTO staging.atc (description, atc_code) VALUES ('other i.v. solution additives', 'B05XX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other immunoglobulins', 'J06BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('other immunosuppressive agents', 'L04AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other insecticides and repellents', 'P03BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other intestinal adsorbents', 'A07BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('other intestinal antiinfectives', 'A07AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other irrigating solutions', 'B05CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other laxatives', 'A06AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other local anesthetics', 'N01BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other low-ceiling diuretics', 'C03BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other magnetic resonance imaging contrast media', 'V08CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other meningococcal monovalent purified polysaccharides antigen', 'J07AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('other meningococcal polyvalent purified polysaccharides antigen', 'J07AH05');
INSERT INTO staging.atc (description, atc_code) VALUES ('other mineral products', 'A12CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other mineral supplements', 'A12C');
INSERT INTO staging.atc (description, atc_code) VALUES ('other muscle relaxants, peripherally acting agents', 'M03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other nasal preparations', 'R01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other nervous system drugs', 'N07');
INSERT INTO staging.atc (description, atc_code) VALUES ('other nervous system drugs', 'N07XX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other nervous system drugs', 'N07X');
INSERT INTO staging.atc (description, atc_code) VALUES ('other non-selective calcium channel blockers', 'C08EX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other non-therapeutic auxiliary products', 'V07AY');
INSERT INTO staging.atc (description, atc_code) VALUES ('other nutrients', 'V06D');
INSERT INTO staging.atc (description, atc_code) VALUES ('other ophthalmological and otological preparations', 'S03D');
INSERT INTO staging.atc (description, atc_code) VALUES ('other ophthalmological diagnostic agents', 'S01JX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other ophthalmologicals', 'S01X');
INSERT INTO staging.atc (description, atc_code) VALUES ('other ophthalmologicals', 'S01XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('other opioids', 'N02AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other oral blood glucose lowering drugs', 'A10BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other otologicals', 'S02D');
INSERT INTO staging.atc (description, atc_code) VALUES ('other oxytocics', 'G02AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other parasympathomimetics', 'N07AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other peripheral vasodilators', 'C04AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other plain vitamin preparations', 'A11H');
INSERT INTO staging.atc (description, atc_code) VALUES ('other plain vitamin preparations', 'A11HA');
INSERT INTO staging.atc (description, atc_code) VALUES ('other plant alkaloids and natural products', 'L01CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other plasma protein fractions', 'B05AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('other potassium-sparing agents', 'C03DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('other preparations, combinations', 'C05AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('other psychostimulants and nootropics', 'N06BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other quaternary ammonium compounds', 'M03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('other quinolones', 'J01MB');
INSERT INTO staging.atc (description, atc_code) VALUES ('other renal system diagnostic radiopharmaceuticals', 'V09CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other respiratory system diagnostic radiopharmaceuticals', 'V09EX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other respiratory system products', 'R07');
INSERT INTO staging.atc (description, atc_code) VALUES ('other respiratory system products', 'R07A');
INSERT INTO staging.atc (description, atc_code) VALUES ('other respiratory system products', 'R07AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other sclerosing agents', 'C05BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other selective calcium channel blockers with mainly vascular effects', 'C08CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other sex hormones and modulators of the genital system', 'G03X');
INSERT INTO staging.atc (description, atc_code) VALUES ('other specific antirheumatic agents', 'M01CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other surgical aids', 'S01KX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other systemic drugs for obstructive airway diseases', 'R03D');
INSERT INTO staging.atc (description, atc_code) VALUES ('other systemic drugs for obstructive airway diseases', 'R03DX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other systemic hemostatics', 'B02BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other therapeutic products', 'V03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other therapeutic radiopharmaceuticals', 'V10X');
INSERT INTO staging.atc (description, atc_code) VALUES ('other throat preparations', 'R02AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other topical products for joint and muscular pain', 'M02AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other urologicals', 'G04BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other urologicals, incl. antispasmodics', 'G04B');
INSERT INTO staging.atc (description, atc_code) VALUES ('other vaccines', 'J07X');
INSERT INTO staging.atc (description, atc_code) VALUES ('other vasodilators used in cardiac diseases', 'C01DX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other viral vaccines', 'J07BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('other vitamin products, combinations', 'A11J');
INSERT INTO staging.atc (description, atc_code) VALUES ('others', 'D11AC30');
INSERT INTO staging.atc (description, atc_code) VALUES ('otilonium bromide', 'A03AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('otilonium bromide and psycholeptics', 'A03CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('otologicals', 'S02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ovulation stimulants, synthetic', 'G03GB');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxabolone cipionate', 'A14AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxaceprol', 'M01AX24');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxaceprol', 'D11AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxacillin', 'J01CF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxaflozane', 'N06AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxaliplatin', 'L01XA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxametacin', 'M01AB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxamniquine', 'P02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxandrolone', 'A14AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxantel', 'P02CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxaprozin', 'M01AE12');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxatomide', 'R06AE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxazepam', 'N05BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxazol, thiazine, and triazine derivatives', 'M03BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxazolam', 'Z01AA25');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxazolidine derivatives', 'N03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxcarbazepine', 'N03AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxedrine', 'C01CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxedrine', 'S01GA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxedrine, combinations', 'S01GA56');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxeladin', 'R05DB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxetacaine', 'C05AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxetorone', 'N02CX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxicams', 'M01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxidized cellulose', 'B02BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxiracetam', 'N06BX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxitriptan', 'N06AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxitropium bromide', 'R03BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxolamine', 'R05DB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxolinic acid', 'J01MB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxomemazine', 'R06AD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxprenolol', 'C07AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxprenolol and other diuretics', 'C07CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxprenolol and thiazides', 'C07BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxtriphylline', 'R03DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxybenzone', 'D11AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxybuprocaine', 'D04AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxybuprocaine', 'S01HA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxybutynin', 'G04BD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxybutynin chloride', 'G04BD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxycinchophen', 'M01CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxycodone', 'N02AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxycodone hydrochloride', 'N02AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyfedrine', 'C01DX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyfedrine, combinations', 'C01DX53');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxygen', 'V03AN01');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxygen', 'V03AN05');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxymetazoline', 'S01GA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxymetazoline', 'R01AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxymetazoline', 'R01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxymetazoline hydrochloride', 'S01GA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxymetazoline hydrochloride', 'R01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxymetholone', 'A14AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxypertine', 'N05AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyphenbutazone', 'M02AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyphenbutazone', 'S01BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyphenbutazone', 'M01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyphencyclimine', 'A03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyphencyclimine and psycholeptics', 'A03CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyphenonium', 'A03AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyphenonium, combinations', 'A03AB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyquinoline', 'R02AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyquinoline', 'D08AH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyquinoline', 'G01AC30');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyquinoline', 'A01AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxytetracycline', 'S01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxytetracycline', 'G01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxytetracycline', 'J01AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxytetracycline', 'D06AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxytetracycline, combinations', 'J01AA56');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxytocics', 'G02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxytocin', 'H01BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxytocin and analogues', 'H01BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('p-phenylenediamine', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('p-tert-butylphenol formaldehyde resin', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('p-tert-pentylphenol', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('paclitaxel', 'L01CD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('paclitaxel (taxus canadensis)', 'L01CD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('padimate o', 'D11AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('pain palliation (bone seeking agents)', 'V10B');
INSERT INTO staging.atc (description, atc_code) VALUES ('palifermin', 'V03AF08');
INSERT INTO staging.atc (description, atc_code) VALUES ('paliperidone', 'N05AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('paliperidone (paliperidone palmitate)', 'N05AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('palivizumab', 'J06BB16');
INSERT INTO staging.atc (description, atc_code) VALUES ('paltitrexid', 'L01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pamabrom', 'C03BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('pamidronate disodium', 'M05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pamidronic acid', 'M05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pancreatic hormones', 'H04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pancreatin', 'A09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pancreozymin (cholecystokinin)', 'V04CK02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pancuronium', 'M03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pancuronium bromide', 'M03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('panipenem and betamipron', 'J01DH55');
INSERT INTO staging.atc (description, atc_code) VALUES ('panitumumab', 'L01XC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pantethine', 'A11HA32');
INSERT INTO staging.atc (description, atc_code) VALUES ('pantoprazole', 'A02BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pantoprazole (pantoprazole magnesium)', 'A02BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pantoprazole (pantoprazole sodium sesquihydrate)', 'A02BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pantoprazole, amoxicillin and clarithromycin', 'A02BD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('papaveretum', 'N02AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('papaverine', 'G04BE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('papaverine', 'A03AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('papaverine and derivatives', 'A03AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('papaverine hydrochloride', 'A03AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('papaverine, combinations', 'A03AD51');
INSERT INTO staging.atc (description, atc_code) VALUES ('papaverine, combinations', 'G04BE52');
INSERT INTO staging.atc (description, atc_code) VALUES ('paracetamol', 'N02BE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('paracetamol, combinations excl. psycholeptics', 'N02BE51');
INSERT INTO staging.atc (description, atc_code) VALUES ('paracetamol, combinations with psycholeptics', 'N02BE71');
INSERT INTO staging.atc (description, atc_code) VALUES ('paraldehyde', 'N05CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('paramagnetic contrast media', 'V08CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('paramethadione', 'N03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('paramethasone', 'H02AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('paraoxon', 'S01EB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('parasympathomimetics', 'N07A');
INSERT INTO staging.atc (description, atc_code) VALUES ('parasympathomimetics', 'S01EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('parathyroid gland extract', 'H05AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('parathyroid hormones and analogues', 'H05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('parathyroid hormones and analogues', 'H05A');
INSERT INTO staging.atc (description, atc_code) VALUES ('parecoxib', 'M01AH04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pargyline', 'C02KC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pargyline and diuretics', 'C02LL01');
INSERT INTO staging.atc (description, atc_code) VALUES ('paricalcitol', 'H05BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('parnaparin', 'B01AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('paromomycin', 'A07AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('paromomycin (paromomycin sulfate)', 'A07AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('parotitis immunoglobulin', 'J06BB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('parotitis vaccines', 'J07BE');
INSERT INTO staging.atc (description, atc_code) VALUES ('parotitis, live attenuated', 'J07BE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('paroxetine', 'N06AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('paroxetine (paroxetine hydrochloride, isopropyl solvate)', 'N06AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('patent blue sodium', 'V04CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('pazopanib', 'L01XE11');
INSERT INTO staging.atc (description, atc_code) VALUES ('pazopanib (pazopanib hydrochloride)', 'L01XE11');
INSERT INTO staging.atc (description, atc_code) VALUES ('pecilocin', 'D01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pectin', 'A07BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pefloxacin', 'J01MA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pegademase', 'L03AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pegaptanib', 'S01LA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pegaspargase', 'L01XX24');
INSERT INTO staging.atc (description, atc_code) VALUES ('pegfilgrastim', 'L03AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('peginterferon alfa-2a', 'L03AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('peginterferon alfa-2b', 'L03AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('pegloticase', 'M04AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pegvisomant', 'H01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pemetrexed', 'L01BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pemetrexed (pemetrexed disodium)', 'L01BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pemoline', 'N06BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('penamecillin', 'J01CE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('penbutolol', 'C07AA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('penbutolol and other diuretics', 'C07CA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('penciclovir', 'J05AB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('penciclovir', 'D06BB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('penems', 'ZXX0159');
INSERT INTO staging.atc (description, atc_code) VALUES ('penfluridol', 'N05AG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('penicillamine', 'M01CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('penicillamine and similar agents', 'M01CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('penicillin g (penicillin g sodium)', 'J01CE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('penicillin g benzathine', 'J01CE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('penicillin g sodium', 'J01CE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('penicillin v (penicillin v potassium)', 'J01CE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('penicillin v potassium', 'J01CE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('penicillins', 'ZXX0132');
INSERT INTO staging.atc (description, atc_code) VALUES ('penicillins a', 'ZXX0133');
INSERT INTO staging.atc (description, atc_code) VALUES ('penicillins with extended spectrum', 'J01CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('penicillins, comb. with other antibacterials', 'J01RA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('penimepicycline', 'J01AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentaerithrityl', 'A06AD14');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentaerithrityl tetranitrate', 'C01DA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentaerithrityl tetranitrate, combinations', 'C01DA55');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentagastrin', 'V04CG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentamidine isethionate', 'P01CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentamycin', 'G01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentastarch', 'B05AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentazocine', 'N02AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentazocine (pentazocine hydrochloride)', 'N02AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentazocine (pentazocine lactate)', 'N02AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentetrazol', 'R07AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentetrazol, combinations', 'R07AB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('penthienate', 'A03AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentifylline', 'C04AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentobarbital', 'N05CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentosan polysulfate sodium', 'C05BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentostatin', 'L01XX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentoxifylline', 'C04AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentoxyverine', 'R05DB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pepsin', 'A09AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pepsin and acid preparations', 'A09AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('peracetic acid', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('perazine', 'N05AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('perchlorates', 'H03BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('perflenapent', 'V08DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('perflubron', 'V08CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('perflutren', 'V08DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pergolide', 'N04BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('perhexiline', 'C08EX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('periciazine', 'N05AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('perindopril', 'C09AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('perindopril and amlodipine', 'C09BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('perindopril and diuretics', 'C09BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('peripheral opioid receptor antagonists', 'A06AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('peripheral vasodilators', 'C04');
INSERT INTO staging.atc (description, atc_code) VALUES ('peripheral vasodilators', 'C04A');
INSERT INTO staging.atc (description, atc_code) VALUES ('peripherally acting antiobesity products', 'A08AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('peritoneal dialytics', 'B05D');
INSERT INTO staging.atc (description, atc_code) VALUES ('permethrin', 'P03AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('permethrin, combinations', 'P03AC54');
INSERT INTO staging.atc (description, atc_code) VALUES ('peroxides', 'D10AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('perphenazine', 'N05AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pertussis immunoglobulin', 'J06BB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('pertussis vaccines', 'J07AJ');
INSERT INTO staging.atc (description, atc_code) VALUES ('pertussis, inactivated, whole cell', 'J07AJ01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pertussis, inactivated, whole cell, combinations with toxoids', 'J07AJ51');
INSERT INTO staging.atc (description, atc_code) VALUES ('pertussis, purified antigen', 'J07AJ02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pertussis, purified antigen, combinations with toxoids', 'J07AJ52');
INSERT INTO staging.atc (description, atc_code) VALUES ('peruvian balsam', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('peruvoside', 'C01AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pethidine', 'N02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pethidine and antispasmodics', 'N02AG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pethidine, combinations excl. psycholeptics', 'N02AB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('pethidine, combinations with psycholeptics', 'N02AB72');
INSERT INTO staging.atc (description, atc_code) VALUES ('petrolatum', 'D02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('petrolatum', 'D02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('petrolatum', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('phanquinone', 'P01AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenacemide', 'N03AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenacetin', 'N02BE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenacetin, combinations excl. psycholeptics', 'N02BE53');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenacetin, combinations with psycholeptics', 'N02BE73');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenazocine', 'N02AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenazone', 'S02DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenazone', 'N02BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenazone, combinations excl. psycholeptics', 'N02BB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenazone, combinations with psycholeptics', 'N02BB71');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenazopyridine', 'G04BX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenazopyridine hydrochloride', 'G04BX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenelzine', 'N06AF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenelzine (phenelzine sulfate)', 'N06AF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pheneticillin', 'J01CE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pheneturide', 'N03AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenformin', 'A10BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenformin and sulfonamides', 'A10BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenglutarimide', 'N04AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenindamine', 'R06AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenindione', 'B01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pheniramine', 'R06AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenobarbital', 'N03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenobarbital (and, by extrapolation, primidone)', 'ZXX0126');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenobarbital sodium', 'N03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenol', 'D08AE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenol', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenol', 'D08AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenol', 'C05BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenol', 'N01BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenol', 'R02AA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenol', 'D02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenol', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenol and derivatives', 'D08AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenolate sodium', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenolphthalein', 'A06AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenolsulfonphthalein', 'V04CH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenoperidine', 'N01AH04');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenothiazine derivatives', 'R06AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenothiazine neuroleptics', 'ZXX0122');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenothiazines with aliphatic side-chain', 'N05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenothiazines with piperazine structure', 'N05AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenothiazines with piperidine structure', 'N05AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenothrin', 'P03AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenothrin, combinations', 'P03AC53');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenoxybenzamine', 'C04AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenoxymethylpenicillin', 'J01CE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenprobamate', 'M03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenprobamate, combinations excl. psycholeptics', 'M03BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenprobamate, combinations with psycholeptics', 'M03BA71');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenprocoumon', 'B01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('phensuximide', 'N03AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('phentermine', 'A08AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phentolamine', 'C04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phentolamine', 'G04BE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('phentolamine mesylate', 'C04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenyl salicylate', 'G04BX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylalanine', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylalkylamine derivatives', 'C08EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylalkylamine derivatives', 'C08DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylbutazone', 'M02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylbutazone', 'M01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylbutazone and corticosteroids', 'M01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrine', 'R01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrine', 'R01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrine', 'C01CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrine', 'S01GA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrine', 'S01FB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrine', 'R01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrine (phenylephrine hydrochloride)', 'C01CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrine hydrochloride', 'S01GA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrine hydrochloride', 'R01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrine hydrochloride', 'S01FB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrine hydrochloride', 'C01CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrine hydrochloride', 'C05AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrine, combinations', 'R01BA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrine, combinations', 'S01GA55');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylmercuric borate', 'D08AK02');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylmercuric nitrate', 'D09AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylpiperidine derivatives', 'N02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylpropanolamine', 'R01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylpropanolamine, combinations', 'R01BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenyltoloxamine', 'Z01AA26');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenyramidol', 'M03BX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenytoin', 'N03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenytoin (and, by extrapolation, fosphenytoin)', 'ZXX0127');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenytoin sodium', 'N03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenytoin, combinations', 'N03AB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('phloroglucinol', 'A03AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('pholcodine', 'R05DA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('phosphate-buffered saline (diluent)', 'L03AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phosphodiesterase inhibitors', 'C01CE');
INSERT INTO staging.atc (description, atc_code) VALUES ('phospholipid', 'R07AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('phosphonic acid derivatives', 'J05AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('phosphore', 'Z01AA27');
INSERT INTO staging.atc (description, atc_code) VALUES ('phosphoric acid', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('phosphorous (32p) chromicphosphate colloid', 'V10AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phthalylsulfathiazole', 'A07AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('physostigmine', 'S01EB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('physostigmine', 'V03AB19');
INSERT INTO staging.atc (description, atc_code) VALUES ('phytomenadione', 'B02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('picloxydine', 'S01AX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('picodralazine and diuretics', 'C02LG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('picodralazine and diuretics, combinations with psycholeptics', 'C02LG73');
INSERT INTO staging.atc (description, atc_code) VALUES ('picotamide', 'B01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pidotimod', 'L03AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pilocarpine', 'N07AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pilocarpine', 'S01EB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pilocarpine hydrochloride', 'N07AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pilocarpine hydrochloride', 'S01EB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pilocarpine nitrate', 'S01EB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pilocarpine, combinations', 'S01EB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('pimecrolimus', 'D11AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pimethixene', 'R06AX23');
INSERT INTO staging.atc (description, atc_code) VALUES ('pimozide', 'N05AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pinacidil', 'C02DG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pinacidil and diuretics', 'C02LX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pinaverium', 'A03AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pinaverium bromide', 'A03AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pinazepam', 'N05BA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('pindolol', 'C07AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pindolol and other diuretics', 'C07CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pine oil', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('pine tar', 'D05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('pioglitazone', 'A10BG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pioglitazone and alogliptin', 'A10BD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipamperone', 'N05AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipazetate', 'R05DB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipecuronium bromide', 'M03AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipemidic acid', 'J01MB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipenzolate', 'A03AB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperacillin', 'J01CA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperacillin (piperacillin sodium)', 'J01CA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperacillin and enzyme inhibitor', 'J01CR05');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperazine', 'P02CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperazine and derivatives', 'P02CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperazine derivatives', 'R06AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperidinedione derivatives', 'N05CE');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperidione', 'R05DB23');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperidolate', 'A03AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipobroman', 'L01AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipotiazine', 'N05AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipotiazine palmitate', 'N05AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipradrol', 'N06BX15');
INSERT INTO staging.atc (description, atc_code) VALUES ('piprozolin', 'A05AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('piracetam', 'N06BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pirarubicin', 'L01DB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pirbuterol', 'R03CC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('pirbuterol', 'R03AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pirenzepine', 'A02BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('piretanide', 'C03CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('piribedil', 'N04BC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pirisudanol', 'N06BX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('piritramide', 'N02AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('piromidic acid', 'J01MB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('piroxicam', 'M02AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('piroxicam', 'M01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('piroxicam', 'S01BC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('pirprofen', 'M01AE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pitcher plant', 'M02AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('pitofenone and analgesics', 'A03DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pituitary and hypothalamic hormones and analogues', 'H01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pivagabine', 'N06AX15');
INSERT INTO staging.atc (description, atc_code) VALUES ('pivampicillin', 'J01CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pivmecillinam', 'J01CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pivmecillinam (pivmecillinam hydrochloride)', 'J01CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pizotifen', 'N02CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pizotifen (pizotifen malate)', 'N02CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('plague vaccines', 'J07AK');
INSERT INTO staging.atc (description, atc_code) VALUES ('plague, inactivated, whole cell', 'J07AK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('plant alkaloids and other natural products', 'L01C');
INSERT INTO staging.atc (description, atc_code) VALUES ('plasters', 'V07AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('plastic iud', 'G02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('plastic iud with copper', 'G02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('plastic iud with progestogens', 'G02BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('platelet aggregation inhibitors', 'ZXX0022');
INSERT INTO staging.atc (description, atc_code) VALUES ('platelet aggregation inhibitors excl. heparin', 'B01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('platinum compounds', 'L01XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('pleconaril', 'J05AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('plicamycin', 'L01DC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysacc. serot. 18c conjug. to tetanus toxoid carrier prot.', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharid serot. 19f conjug. to diphtheria toxoid carrier prot.', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotyp 19a', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotyp 8', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 1', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 1 conjugated to protein d carrier protein', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 10a', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 11a', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 12f', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 14', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 14 conjugated to protein d carrier protein', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 15b', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 17f', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 18c', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 19a', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 19f', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 2', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 20', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 22f', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 23f', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 23f conjugated to protein d carrier protein', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 3', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 33f', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 4', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 4 conjugated to protein d carrier protein', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 5', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 5 conjugated to protein d carrier protein', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 6a', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 6b', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 6b conjugated to protein d carrier protein', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 7f', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 7f conjugated to protein d carrier protein', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 9n', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 9v', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal polysaccharide serotype 9v conjugated to protein d carrier protein', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal vaccine polyvalent', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcal vaccines', 'J07AL');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcus, purified polysaccharides antigen', 'J07AL01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumococcus, purified polysaccharides antigen conjugated', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('podophyllin', 'D06BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('podophyllotoxin', 'D06BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('podophyllotoxin derivatives', 'L01CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('poldine', 'A03AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('policosanol', 'C10AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('policresulen', 'D08AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('policresulen', 'G01AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('polidocanol', 'C05BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('polihexanide', 'D08AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('poliomyelitis oral, monovalent live attenuated', 'J07BF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('poliomyelitis oral, trivalent, live attenuated', 'J07BF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('poliomyelitis vaccines', 'J07BF');
INSERT INTO staging.atc (description, atc_code) VALUES ('poliomyelitis, trivalent, inactivated, whole virus', 'J07BF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('polistes spp venom protein extract', 'V01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('pollen', 'V01AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('pollen and non pollen', 'V01AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('poly i:c', 'L03AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('poly iclc', 'L03AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('polyaminopropyl biguanide', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('polycarbophil (calcium polycarbophil)', 'A06AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('polycarbophil calcium', 'A06AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('polyestradiol phosphate', 'L02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('polyethoxy polypropoxy polyethoxy ethanol - iodine complex', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('polyethylene glycol 3350', 'A06AD15');
INSERT INTO staging.atc (description, atc_code) VALUES ('polyethylene glycol 400', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('polyethylene glycol p-isooctylphenyl ether', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('polygeline', 'B05AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('polyhexanide', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('polymyxin b', 'S01AA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('polymyxin b', 'J01XB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('polymyxin b', 'S02AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('polymyxin b', 'A07AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('polymyxin b', 'S03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('polymyxins', 'J01XB');
INSERT INTO staging.atc (description, atc_code) VALUES ('polynoxylin', 'D01AE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('polynoxylin', 'A01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('polyquaternium-1', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('polysorbate 80', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('polystyrene sulfonate', 'V03AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('polythiazide', 'C03AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('polythiazide and potassium', 'C03AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('polyvinyl alcohol', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('porfimer sodium', 'L01XD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('posaconazole', 'J02AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('posterior pituitary lobe hormones', 'H01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium', 'A12BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium', 'A12B');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium acetate', 'B05XA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium canrenoate', 'C03DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium chloride', 'B05XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium chloride', 'A12BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium chloride', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium chloride', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium chloride, combinations', 'A12BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium citrate', 'A12BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium clorazepate', 'N05BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium dichromate', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium gluconate', 'A12BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium hydrogencarbonate', 'A12BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium hydrogentartrate', 'A12BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium hydroxide', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium iodide', 'S01XA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium iodide', 'V03AB21');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium iodide', 'R05CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium lactate', 'B05XA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium p-aminobenzoate', 'V03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium perchlorate', 'H03BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium permanganate', 'D08AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium permanganate', 'V03AB18');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium peroxymonosulfate', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium phosphate dibasic', 'B05XA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium phosphate monobasic', 'B05XA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium phosphate, incl. comb. with other potassium salts', 'B05XA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium polysulfide', 'P03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium salicylate', 'N02BA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium-losing diuretics', 'ZXX0065');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium-sparing agents', 'C03D');
INSERT INTO staging.atc (description, atc_code) VALUES ('potassium-sparing diuretics', 'ZXX0067');
INSERT INTO staging.atc (description, atc_code) VALUES ('potent inhibitors of cyp3a4', 'ZXX0100');
INSERT INTO staging.atc (description, atc_code) VALUES ('povidone', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('povidone-iodine', 'D11AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('povidone-iodine', 'G01AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('povidone-iodine', 'D08AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('povidone-iodine', 'D09AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('povidone-iodine', 'R02AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('povidone-iodine', 'S01AX18');
INSERT INTO staging.atc (description, atc_code) VALUES ('practolol', 'C07AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('prajmaline', 'C01BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pralatrexate', 'L01BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pralidoxime', 'V03AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pramipexole', 'N04BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pramiracetam', 'N06BX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('pramlintide', 'A10BX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pramocaine', 'D04AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('pramocaine', 'C05AD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('pramoxine hydrochloride', 'D04AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('pranlukast', 'R03DC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pranoprofen', 'S01BC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('prasterone', 'A14AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('prasterone and estrogen', 'G03EA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('prasugrel', 'B01AC22');
INSERT INTO staging.atc (description, atc_code) VALUES ('prasugrel (prasugrel hydrochloride)', 'B01AC22');
INSERT INTO staging.atc (description, atc_code) VALUES ('pravastatin', 'C10AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pravastatin and acetylsalicylic acid', 'C10BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pravastatin and fenofibrate', 'C10BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('prazepam', 'N05BA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('praziquantel', 'P02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('prazosin', 'C02CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('prazosin (prazosin hydrochloride)', 'C02CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('prazosin and diuretics', 'C02LE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('prazosin hydrochloride', 'C02CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednicarbate', 'D07AC18');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednimustine', 'L01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone', 'D07AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone', 'A07EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone', 'S03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone', 'D07XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone', 'S01CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone', 'H02AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone', 'R01AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone', 'S01BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone', 'S02BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone', 'C05AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone (prednisolone sodium phosphate)', 'H02AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone acetate', 'S01BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone and antibiotics', 'D07CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone and antiinfectives', 'S02CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone and antiinfectives', 'S03CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone and antiinfectives', 'S01CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone and antiseptics', 'D07BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone and mydriatics', 'S01BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone and promethazine', 'V03AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone sodium phosphate', 'S01BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone, combinations', 'R01AD52');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolone, combinations', 'A01AC54');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisone', 'H02AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisone', 'A07EA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednylidene', 'H02AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('pregabalin', 'N03AX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('pregnadien derivatives', 'G03DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('pregnen (4) derivatives', 'G03DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('prenalterol', 'C01CA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('prenoxdiazine', 'R05DB18');
INSERT INTO staging.atc (description, atc_code) VALUES ('prenylamine', 'C01DX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('prenylamine, combinations', 'C01DX52');
INSERT INTO staging.atc (description, atc_code) VALUES ('preparations containing sulfur', 'D10AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('preparations for biliary tract therapy', 'A05AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('preparations for treatment of wounds and ulcers', 'D03');
INSERT INTO staging.atc (description, atc_code) VALUES ('preparations increasing uric acid excretion', 'M04AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('preparations inhibiting uric acid production', 'M04AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('preparations with no effect on uric acid metabolism', 'M04AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('preparations with salicylic acid derivatives', 'M02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('prethcamide', 'R07AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('pridinol', 'M03BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('prifinium bromide', 'A03AB18');
INSERT INTO staging.atc (description, atc_code) VALUES ('prilocaine', 'N01BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('prilocaine hydrochloride', 'N01BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('prilocaine, combinations', 'N01BB54');
INSERT INTO staging.atc (description, atc_code) VALUES ('primaquine', 'P01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('primaquine phosphate', 'P01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('primidone', 'N03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pristinamycin', 'J01FG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('probenecid', 'M04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('probucol', 'C10AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('procainamide', 'C01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('procainamide hydrochloride', 'C01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('procaine', 'N01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('procaine', 'C05AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('procaine', 'S01HA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('procaine hydrochloride', 'N01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('procaine penicillin', 'J01CE09');
INSERT INTO staging.atc (description, atc_code) VALUES ('procaine, combinations', 'N01BA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('procarbazine', 'L01XB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('procarbazine (procarbazine hydrochloride)', 'L01XB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('procaterol', 'R03CC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('procaterol', 'R03AC16');
INSERT INTO staging.atc (description, atc_code) VALUES ('prochlorperazine', 'N05AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('prochlorperazine (prochlorperazine maleate)', 'N05AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('prochlorperazine (prochlorperazine mesylate)', 'N05AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('procyclidine', 'N04AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('procyclidine hydrochloride', 'N04AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('products containing antibiotics', 'C05AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('products containing corticosteroids', 'C05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('products containing local anesthetics', 'C05AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('profenamine', 'N04AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('progabide', 'N03AG05');
INSERT INTO staging.atc (description, atc_code) VALUES ('progesterone', 'G03DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('progesterone and estrogen', 'G03FA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('progestin contraceptives', 'ZXX0129');
INSERT INTO staging.atc (description, atc_code) VALUES ('progestin noncontraceptives', 'ZXX0130');
INSERT INTO staging.atc (description, atc_code) VALUES ('progestogens', 'L02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('progestogens', 'G03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('progestogens', 'G03D');
INSERT INTO staging.atc (description, atc_code) VALUES ('progestogens and estrogens in combination', 'G03F');
INSERT INTO staging.atc (description, atc_code) VALUES ('progestogens and estrogens, combinations', 'G03FA');
INSERT INTO staging.atc (description, atc_code) VALUES ('progestogens and estrogens, fixed combinations', 'G03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('progestogens and estrogens, sequential preparations', 'G03FB');
INSERT INTO staging.atc (description, atc_code) VALUES ('progestogens and estrogens, sequential preparations', 'G03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('proglumetacin', 'M01AB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('proglumide', 'A02BX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('proguanil', 'P01BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('proguanil, combinations', 'P01BB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('prolactine inhibitors', 'G02CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('proline', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('prolintane', 'N06BX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('promazine', 'N05AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('promegestone', 'G03DB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('promestriene', 'G03CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('promethazine', 'D04AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('promethazine', 'R06AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('promethazine (promethazine hydrochloride)', 'R06AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('promethazine hydrochloride', 'R06AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('promethazine, combinations', 'R06AD52');
INSERT INTO staging.atc (description, atc_code) VALUES ('propacetamol', 'N02BE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('propafenone', 'C01BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('propafenone hydrochloride', 'C01BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('propamidine', 'D08AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('propamidine', 'S01AX15');
INSERT INTO staging.atc (description, atc_code) VALUES ('propanidid', 'N01AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('propanol', 'D08AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('propanol, combinations', 'D08AX53');
INSERT INTO staging.atc (description, atc_code) VALUES ('propantheline', 'A03AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('propantheline and psycholeptics', 'A03CA34');
INSERT INTO staging.atc (description, atc_code) VALUES ('propatylnitrate', 'C01DA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('propatylnitrate, combinations', 'C01DA57');
INSERT INTO staging.atc (description, atc_code) VALUES ('propenidazole', 'P01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('propenidazole', 'G01AF14');
INSERT INTO staging.atc (description, atc_code) VALUES ('propentofylline', 'N06BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('propicillin', 'J01CE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('propiomazine', 'N05CM06');
INSERT INTO staging.atc (description, atc_code) VALUES ('propionic acid derivatives', 'M01AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('propiverine', 'G04BD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('propofol', 'N01AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('propranolol', 'C07AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('propranolol and other antihypertensives', 'C07FA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('propranolol and thiazides', 'C07BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('propranolol hydrochloride', 'C07AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('propulsives', 'A03FA');
INSERT INTO staging.atc (description, atc_code) VALUES ('propulsives', 'A03F');
INSERT INTO staging.atc (description, atc_code) VALUES ('propyl alcohol', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('propylene glycol', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('propylene glycol', 'R01AX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('propylene glycol', 'D02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('propylene glycol', 'R01AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('propyliodone', 'V08AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('propylparaben', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('propylthiouracil', 'H03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('propyphenazone', 'N02BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('propyphenazone, combinations excl. psycholeptics', 'N02BB54');
INSERT INTO staging.atc (description, atc_code) VALUES ('propyphenazone, combinations with psycholeptics', 'N02BB74');
INSERT INTO staging.atc (description, atc_code) VALUES ('proquazone', 'M01AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('proscillaridin', 'C01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('proscillaridin, combinations', 'C01AB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('prostaglandin analogues', 'S01EE');
INSERT INTO staging.atc (description, atc_code) VALUES ('prostaglandins', 'C01EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('prostaglandins', 'G02AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('prostaglandins', 'A02BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('protamine', 'V03AB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('protamine sulfate', 'V03AB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('protease', 'A09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('protease inhibitors', 'J05AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('protease inhibitors', 'ZXX0097');
INSERT INTO staging.atc (description, atc_code) VALUES ('protease inhibitors (except ritonavir)', 'ZXX0098');
INSERT INTO staging.atc (description, atc_code) VALUES ('protectives against uv-radiation', 'D02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('protectives against uv-radiation for systemic use', 'D02BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('protectives against uv-radiation for topical use', 'D02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('protein c', 'B01AD12');
INSERT INTO staging.atc (description, atc_code) VALUES ('protein hydrolysates', 'B05BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('protein kinase inhibitors', 'L01XE');
INSERT INTO staging.atc (description, atc_code) VALUES ('protein supplements', 'V06B');
INSERT INTO staging.atc (description, atc_code) VALUES ('proteinase inhibitors', 'B02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('proteolytic enzymes', 'D03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('prothipendyl', 'N05AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('protiofate', 'G01AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('protionamide', 'J04AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('protirelin', 'V04CJ02');
INSERT INTO staging.atc (description, atc_code) VALUES ('proton pump inhibitors', 'ZXX0042');
INSERT INTO staging.atc (description, atc_code) VALUES ('proton pump inhibitors', 'A02BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('protriptyline', 'N06AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('proxazole', 'A03AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('proxibarbal', 'N05CA22');
INSERT INTO staging.atc (description, atc_code) VALUES ('proxymetacaine', 'S01HA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('proxyphylline', 'R03DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('proxyphylline and adrenergics', 'R03DB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('prussian blue', 'V03AB31');
INSERT INTO staging.atc (description, atc_code) VALUES ('pseudoephedrine', 'R01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pseudoephedrine, combinations', 'R01BA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('psoralens for systemic use', 'D05BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('psoralens for topical use', 'D05AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('psychoanaleptics', 'N06');
INSERT INTO staging.atc (description, atc_code) VALUES ('psycholeptics', 'N05');
INSERT INTO staging.atc (description, atc_code) VALUES ('psycholeptics and psychoanaleptics in combination', 'N06C');
INSERT INTO staging.atc (description, atc_code) VALUES ('psychostimulants in combination with psycholeptics', 'N06CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('psychostimulants, agents used for adhd and nootropics', 'N06B');
INSERT INTO staging.atc (description, atc_code) VALUES ('purified protein derivative of tuberculin', 'V04CF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('purine analogues', 'L01BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('purine derivatives', 'C04AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('pygeum africanum', 'G04CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrantel', 'P02CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrantel (pyrantel pamoate)', 'P02CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrazinamide', 'J04AK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrazolone derivatives', 'C03CD');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrazolones', 'N02BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrethrines', 'P03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrethrines, incl. synthetic compounds', 'P03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrethrum', 'P03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrethrum, combinations', 'P03AC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyridostigmine', 'N07AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyridostigmine bromide', 'N07AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyridoxal phosphate', 'A11HA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyridoxine (vit b6)', 'A11HA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyridoxine hydrochloride', 'A11HA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrimethamine', 'P01BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrimethamine, combinations', 'P01BD51');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrimidine analogues', 'L01BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrimidine derivatives', 'C02DC');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrithione disulfide', 'D05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrithione zinc', 'D11AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrithyldione', 'N05CE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyritinol', 'N06BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrrobutamine', 'R06AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrrobutamine, combinations', 'R06AX58');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrrolnitrin', 'D01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrvinium', 'P02CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('quassia', 'P03AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('quaternary ammonium compounds', 'D08AJ');
INSERT INTO staging.atc (description, atc_code) VALUES ('quaternium-15', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('quazepam', 'N05CD10');
INSERT INTO staging.atc (description, atc_code) VALUES ('quercetin', 'Z01AA34');
INSERT INTO staging.atc (description, atc_code) VALUES ('quetiapine', 'N05AH04');
INSERT INTO staging.atc (description, atc_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinagolide', 'G02CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinagolide (quinagolide hydrochloride)', 'G02CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinapril', 'C09AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinapril (quinapril hydrochloride)', 'C09AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinapril and diuretics', 'C09BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinbolone', 'A14AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinethazone', 'C03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinethazone and potassium', 'C03BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('quingestanol', 'G03AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('quingestanol and estrogen', 'G03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinidine', 'C01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinidine sulfate', 'C01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinidine, combinations excl. psycholeptics', 'C01BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinidine, combinations with psycholeptics', 'C01BA71');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinine', 'P01BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinine and derivatives', 'M09AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinine sulfate', 'P01BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinine, combinations with psycholeptics', 'M09AA72');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinisocaine', 'D04AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinoline derivatives', 'D08AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinoline derivatives', 'G01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinoline derivatives and corticosteroids', 'G01BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinoline derivatives and related substances', 'P02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinolines', 'M01CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinolone antibacterials', 'J01M');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinolone vasodilators', 'C01DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinupramine', 'N06AA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('qunupristin/dalfopristin', 'J01FG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rabeprazole', 'A02BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('rabeprazole sodium', 'A02BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('rabies immune globulin human', 'J06BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('rabies immunoglobulin', 'J06BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('rabies serum', 'J06AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('rabies vaccine inactivated (human diploid-cell culture)', 'J07BG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('rabies vaccine inactivated (purified chick embryo cell culture)', 'J07BG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('rabies vaccines', 'J07BG');
INSERT INTO staging.atc (description, atc_code) VALUES ('rabies, inactivated, whole virus', 'J07BG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('raloxifene', 'G03XC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('raloxifene hydrochloride', 'G03XC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('raltegravir', 'J05AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('raltegravir (raltegravir potassium)', 'J05AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('raltitrexed', 'L01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('raltitrexed (raltitrexed disodium)', 'L01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ramelteon', 'N05CH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ramipril', 'C09AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ramipril and calcium channel blockers', 'C09BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ramipril and diuretics', 'C09BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ranibizumab', 'S01LA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ranimustine', 'L01AD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ranitidine', 'A02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ranitidine bismuth citrate', 'A02BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ranolazine', 'C01EB18');
INSERT INTO staging.atc (description, atc_code) VALUES ('rasagiline', 'N04BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rasagiline (rasagiline mesylate)', 'N04BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rasburicase', 'V03AF07');
INSERT INTO staging.atc (description, atc_code) VALUES ('rauwolfia alkaloids', 'C02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('rauwolfia alkaloids and diuretics in combination', 'C02LA');
INSERT INTO staging.atc (description, atc_code) VALUES ('rauwolfia alkaloids, whole root', 'C02AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('rauwolfia alkaloids, whole root and diuretics', 'C02LA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('reboxetine', 'N06AX18');
INSERT INTO staging.atc (description, atc_code) VALUES ('regadenoson', 'C01EB21');
INSERT INTO staging.atc (description, atc_code) VALUES ('remifentanil', 'N01AH06');
INSERT INTO staging.atc (description, atc_code) VALUES ('remifentanil (remifentanil hydrochloride)', 'N01AH06');
INSERT INTO staging.atc (description, atc_code) VALUES ('remikiren', 'C09XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('remoxipride', 'N05AL04');
INSERT INTO staging.atc (description, atc_code) VALUES ('renal system', 'V09C');
INSERT INTO staging.atc (description, atc_code) VALUES ('renin-inhibitors', 'C09XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('repaglinide', 'A10BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('reposal', 'N05CA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('reproterol', 'R03AC15');
INSERT INTO staging.atc (description, atc_code) VALUES ('reproterol', 'R03CC14');
INSERT INTO staging.atc (description, atc_code) VALUES ('reproterol and other drugs for obstructive airway diseases', 'R03AK05');
INSERT INTO staging.atc (description, atc_code) VALUES ('rescinnamine', 'C02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('rescinnamine and diuretics', 'C02LA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rescinnamine and diuretics, combinations with other drugs', 'C02LA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('reserpine', 'C02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('reserpine and diuretics', 'C02LA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('reserpine and diuretics, combinations with other drugs', 'C02LA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('reserpine and diuretics, combinations with psycholeptics', 'C02LA71');
INSERT INTO staging.atc (description, atc_code) VALUES ('reserpine, combinations', 'C02AA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('resorcinol', 'D05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('resorcinol', 'D10AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('resorcinol', 'S01AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('respiratory stimulants', 'R07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('respiratory system', 'R');
INSERT INTO staging.atc (description, atc_code) VALUES ('respiratory system', 'V09E');
INSERT INTO staging.atc (description, atc_code) VALUES ('reteplase', 'B01AD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('retinoids', 'ZXX0134');
INSERT INTO staging.atc (description, atc_code) VALUES ('retinoids for topical use in acne', 'D10AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('retinoids for treatment of acne', 'D10BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('retinoids for treatment of psoriasis', 'D05BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('retinol', 'D10AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('retinol', 'S01XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('retinol', 'R01AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('retinol (vit a)', 'A11CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('reviparin', 'B01AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('rhenium (186re) etidronic acid', 'V10BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('rhenium (186re) sulfide colloid', 'V10AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('rho d immune globulin human', 'J06BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('rhubarbe', 'Z01AA28');
INSERT INTO staging.atc (description, atc_code) VALUES ('ribavirin', 'J05AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ribavirin, combinations', 'L03AB60');
INSERT INTO staging.atc (description, atc_code) VALUES ('riboflavin (vit b2)', 'A11HA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ribostamycin', 'J01GB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('ricinus communis', 'Z01AA29');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifabutin', 'J04AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifampicin', 'J04AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifampicin and isoniazid', 'J04AM02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifampicin, pyrazinamide and isoniazid', 'J04AM05');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifampicin, pyrazinamide, ethambutol and isoniazid', 'J04AM06');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifampin', 'J04AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifamycin', 'J04AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifamycin', 'S02AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifamycine', 'S01AA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifapentin', 'J04AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifaximin', 'A07AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifaximin', 'D06AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('rilmenidine', 'C02AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('rilonacept', 'L04AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('riluzole', 'N07XX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rimantadine', 'J05AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rimazolium', 'N02BG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rimexolone', 'H02AB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('rimexolone', 'S01BA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('rimiterol', 'R03AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('risedronate sodium (risedronate sodium monohydrate)', 'M05BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('risedronic acid', 'M05BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('risperidone', 'N05AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('risperidone (risperidone tartrate)', 'N05AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ritiometan', 'R01AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ritodrine', 'G02CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ritonavir', 'J05AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('rituximab', 'L01XC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rivaroxaban', 'B01AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('rivastigmine', 'N06DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('rizatriptan', 'N02CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('rizatriptan (rizatriptan benzoate)', 'N02CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('rociverine', 'A03AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('rocuronium bromide', 'M03AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('rofecoxib', 'M01AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('roflumilast', 'R03DX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('rokitamycin', 'J01FA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('rolitetracycline', 'J01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('romidepsin', 'L01XX39');
INSERT INTO staging.atc (description, atc_code) VALUES ('romiplostim', 'B02BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ronifibrate', 'C10AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ropinirole', 'N04BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ropivacaine', 'N01BB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('ropivacaine hydrochloride', 'N01BB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('roquinimex', 'L03AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rose bengal', 'S01JA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rose bengal sodium', 'S01JA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rosiglitazone', 'A10BG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rosiglitazone (rosiglitazone maleate)', 'A10BG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rosin', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('rosoxacin', 'J01MB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('rosuvastatin', 'C10AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('rosuvastatin (rosuvastatin calcium)', 'C10AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('rota virus diarrhea vaccines', 'J07BH');
INSERT INTO staging.atc (description, atc_code) VALUES ('rota virus, live attenuated', 'J07BH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('rotavirus vaccine (rix4414 strain), live, oral, attenuated (human)', 'J07BH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('roxatidine', 'A02BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('roxithromycin', 'J01FA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('rubella immunoglobulin', 'J06BB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('rubella vaccines', 'J07BJ');
INSERT INTO staging.atc (description, atc_code) VALUES ('rubella, combinations with parotitis, live attenuated', 'J07BJ51');
INSERT INTO staging.atc (description, atc_code) VALUES ('rubella, live attenuated', 'J07BJ01');
INSERT INTO staging.atc (description, atc_code) VALUES ('rufloxacin', 'J01MA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('rupatadine', 'R06AX28');
INSERT INTO staging.atc (description, atc_code) VALUES ('rutoside', 'C05CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('rutoside, combinations', 'C05CA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('s-atenolol', 'C07AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('saccharated iron oxide', 'B03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('saccharated iron oxide', 'B03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('saccharomyces boulardii', 'A07FA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sacrosidase', 'A16AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('salbutamol', 'R03CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('salbutamol', 'R03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('salbutamol and other drugs for obstructive airway diseases', 'R03AK04');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylamide', 'N02BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylamide, combinations excl. psycholeptics', 'N02BA55');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylamide, combinations with psycholeptics', 'N02BA75');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylic acid', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylic acid', 'S01BC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylic acid', 'D05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylic acid', 'D01AE12');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylic acid and derivatives', 'N02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylic acid derivatives', 'P02DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylic acid preparations', 'D02AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicyloylsalicylic acid', 'N02BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('salmeterol', 'R03AC12');
INSERT INTO staging.atc (description, atc_code) VALUES ('salmeterol (salmeterol xinafoate)', 'R03AC12');
INSERT INTO staging.atc (description, atc_code) VALUES ('salmeterol and other drugs for obstructive airway diseases', 'R03AK06');
INSERT INTO staging.atc (description, atc_code) VALUES ('salmonella typhi vi capsular polysaccharide vaccine', 'J07AP03');
INSERT INTO staging.atc (description, atc_code) VALUES ('salt solutions', 'B05CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('samarium (153sm) hydroxyapatite colloid', 'V10AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('samarium (153sm) lexidronam', 'V10BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sapropterin', 'A16AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('sapropterin dihydrochloride', 'A16AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('saquinavir', 'J05AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('saquinavir (saquinavir mesylate)', 'J05AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sargramostim', 'L03AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('saruplase', 'B01AD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('satraplatin', 'L01XA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('saxagliptin', 'A10BH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('saxagliptin (saxagliptin hydrochloride)', 'A10BH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('scilla glycosides', 'C01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sclerosing agents for local injection', 'C05BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('scopolamine', 'S01FA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('scopolamine', 'A04AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('scopolamine', 'N05CM05');
INSERT INTO staging.atc (description, atc_code) VALUES ('scopolamine hydrobromide', 'N05CM05');
INSERT INTO staging.atc (description, atc_code) VALUES ('scopolamine hydrobromide', 'A04AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('scopolamine, combinations', 'A04AD51');
INSERT INTO staging.atc (description, atc_code) VALUES ('secnidazole', 'P01AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('secobarbital', 'N05CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('second-generation cephalosporins', 'J01DC');
INSERT INTO staging.atc (description, atc_code) VALUES ('secondary and tertiary amines', 'C02BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('secretin', 'V04CK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sedative agents', 'ZXX0116');
INSERT INTO staging.atc (description, atc_code) VALUES ('selective beta-2-adrenoreceptor agonists', 'R03CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('selective beta-2-adrenoreceptor agonists', 'R03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('selective calcium channel blockers with direct cardiac effects', 'C08D');
INSERT INTO staging.atc (description, atc_code) VALUES ('selective calcium channel blockers with mainly vascular effects', 'C08C');
INSERT INTO staging.atc (description, atc_code) VALUES ('selective estrogen receptor modulators', 'G03XC');
INSERT INTO staging.atc (description, atc_code) VALUES ('selective immunosuppressive agents', 'L04AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('selective maoi-a', 'ZXX0002');
INSERT INTO staging.atc (description, atc_code) VALUES ('selective maoi-b', 'ZXX0003');
INSERT INTO staging.atc (description, atc_code) VALUES ('selective serotonin (5ht1) agonists', 'N02CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('selective serotonin reuptake inhibitors', 'ZXX0101');
INSERT INTO staging.atc (description, atc_code) VALUES ('selective serotonin reuptake inhibitors', 'N06AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('selegiline', 'N04BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('selegiline hydrochloride', 'N04BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('selenium', 'A12CE');
INSERT INTO staging.atc (description, atc_code) VALUES ('selenium (75se) norcholesterol', 'V09XX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('selenium (75se) tauroselcholic acid', 'V09DX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('selenium (selenious acid)', 'A12CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('selenium compounds', 'D11AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('selenium sulfide', 'D01AE13');
INSERT INTO staging.atc (description, atc_code) VALUES ('semustine', 'L01AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('senega', 'R05CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('senna glycosides', 'A06AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('senna glycosides, combinations', 'A06AB56');
INSERT INTO staging.atc (description, atc_code) VALUES ('sensitivity tests, discs and tablets', 'V07AR');
INSERT INTO staging.atc (description, atc_code) VALUES ('sensory organs', 'S');
INSERT INTO staging.atc (description, atc_code) VALUES ('seratrodast', 'R03DX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('serenoa repens', 'G04CX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('serine', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sermorelin', 'V04CD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sermorelin', 'H01AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('serotonin (5ht3) antagonists', 'A04AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('serotonin antagonists', 'C02KD');
INSERT INTO staging.atc (description, atc_code) VALUES ('serotonin antagonists and diuretics', 'C02LN');
INSERT INTO staging.atc (description, atc_code) VALUES ('sertaconazole', 'D01AC14');
INSERT INTO staging.atc (description, atc_code) VALUES ('sertindole', 'N05AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sertraline', 'N06AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('serum gonadotropin', 'G03GA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('serum lipid reducing agents', 'C10');
INSERT INTO staging.atc (description, atc_code) VALUES ('sevelamer', 'V03AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sevelamer carbonate', 'V03AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sevelamer hydrochloride', 'V03AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sevoflurane', 'N01AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('sex hormones and modulators of the genital system', 'G03');
INSERT INTO staging.atc (description, atc_code) VALUES ('short-acting sulfonamides', 'J01EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sibutramine', 'A08AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('sildenafil', 'G04BE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sildenafil (sildenafil citrate)', 'G04BE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('silicone', 'D02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('silicone products', 'D02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('silicones', 'A03AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('silodosin', 'G04CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('silver', 'D08AL30');
INSERT INTO staging.atc (description, atc_code) VALUES ('silver compounds', 'D08AL');
INSERT INTO staging.atc (description, atc_code) VALUES ('silver compounds', 'S01AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('silver dihydrogen citrate', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('silver nitrate', 'D08AL01');
INSERT INTO staging.atc (description, atc_code) VALUES ('silver sulfadiazine', 'D06BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('silver sulfadiazine, combinations', 'D06BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('silymarin', 'A05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('simethicone', 'A03AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('simfibrate', 'C10AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('simvastatin', 'C10AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('simvastatin and acetylsalicylic acid', 'C10BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('simvastatin and ezetimide', 'C10BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sincalide', 'V04CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sirolimus', 'L04AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('sisomicin', 'J01GB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('sitagliptin', 'A10BH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sitagliptin (sitagliptin phosphate monohydrate)', 'A10BH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sitimagene ceradenovec', 'L01XX37');
INSERT INTO staging.atc (description, atc_code) VALUES ('skeleton', 'V09B');
INSERT INTO staging.atc (description, atc_code) VALUES ('snake venom antiserum', 'J06AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sobrerol', 'R05CB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium', 'A12CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium (ricinoleate de)', 'Z01AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium acetate', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium acetate', 'B05XA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium acetate', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium acetate trihydrate', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium alkyl polyether sulfate', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium aminosalicylate', 'J04AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium apolate', 'C05BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium ascorbate', 'A11GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium aurothiomalate', 'M01CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium aurothiosulfate', 'M01CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium bicarbonate', 'B05CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium bicarbonate', 'B05XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium bicarbonate', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium bicarbonate', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium borate', 'S01AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium carbonate (anhydrous)', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium carboxymethyl cellulose', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium cellulose phosphate', 'V03AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium chloride', 'R01AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium chloride', 'B05XA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium chloride', 'A12CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium chloride', 'B05CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium chloride', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium chloride', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium chloride', 'V04CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium chloride', 'H01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium chloride', 'H01CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium chloride', 'R01AX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium chloride', 'A07EA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium chloride, hypertonic', 'S01XA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium chlorite', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium citrate', 'B05CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium citrate', 'V07AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium citrate', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium citrate dihydrate', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium dichloroisocyanurate', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium dodecylbenzenesulfonate', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium edetate', 'S01XA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium feredetate', 'B03AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium fluoride', 'A12CD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium fluoride', 'A01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium fluoride (18f)', 'V09IX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium fluoride, combinations', 'A01AA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium folinate', 'V03AF06');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium glycerophosphate', 'B05XA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium hydroxide', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium hydroxide', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium hypochlorite', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium hypochlorite', 'D08AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium iodide', 'C05BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium iodide (123i)', 'V09FX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium iodide (124i)', 'V09FX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium iodide (131i)', 'V10XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium iodide (131i)', 'V09FX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium iodohippurate (123i)', 'V09CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium iodohippurate (131i)', 'V09CX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium iopodate', 'V08AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium iothalamate (125i)', 'V09CX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium lactate', 'V07AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium lactate', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium lauryl ether sulfate', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium levofolinate', 'V03AF10');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium metasilicate', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium monofluorophosphate', 'A01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium monofluorophosphate', 'A12CD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium nitrite', 'V03AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium nitroprusside', 'C02DD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium ortho-phenylphenate', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium oxybate', 'N07XX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium perborate', 'A01AB19');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium perborate monohydrate', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium phenylbutyrate', 'A16AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium phosphate', 'A06AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium phosphate', 'B05XA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium phosphate', 'A06AD17');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium phosphate (32p)', 'V10XX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium phosphate (tribasic)', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium phosphate dibasic', 'V04CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium phosphate dibasic', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium phosphate dibasic', 'V07AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium phosphate monobasic', 'V07AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium phosphate monobasic', 'V04CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium picosulfate', 'A06AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium picosulfate, combinations', 'A06AB58');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium polystyrene sulfonate', 'V03AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium propionate', 'S01AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium salicylate', 'N02BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium salicylate', 'C05BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium selenate', 'A12CE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium selenite', 'A12CE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium stibogluconate', 'P01CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium sulfate', 'A06AD13');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium sulfate', 'A12CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium tartrate', 'A06AD21');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium tetradecyl sulfate', 'C05BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium thiosulfate', 'V03AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('sodium tripolyphosphate', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('soft paraffin and fat products', 'D02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('soft paraffin dressings', 'D09AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('softeners, emollients', 'A06AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('solifenacin', 'G04BD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('solifenacin succinate', 'G04BD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('solutions affecting the electrolyte balance', 'B05BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('solutions for parenteral nutrition', 'B05BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('solutions producing osmotic diuresis', 'B05BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('solvents and diluting agents, incl. irrigating solutions', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('somatorelin', 'V04CD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('somatostatin', 'H01CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('somatostatin (somatostatin acetate)', 'H01CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('somatostatin analogs', 'ZXX0015');
INSERT INTO staging.atc (description, atc_code) VALUES ('somatrem', 'H01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('somatropin', 'H01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('somatropin and somatropin agonists', 'H01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('sorafenib', 'L01XE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sorafenib (sorafenib tosylate)', 'L01XE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sorbitol', 'B05CX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sorbitol', 'A06AD18');
INSERT INTO staging.atc (description, atc_code) VALUES ('sorbitol', 'V04CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sorbitol', 'A06AG07');
INSERT INTO staging.atc (description, atc_code) VALUES ('sotalol', 'C07AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('sotalol and thiazides', 'C07BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('sotalol hydrochloride', 'C07AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('sotalol, combination packages', 'C07AA57');
INSERT INTO staging.atc (description, atc_code) VALUES ('spaglumic acid', 'S01GX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('spaglumic acid', 'R01AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sparfloxacin', 'J01MA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('sparteine', 'C01BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('specific antirheumatic agents', 'M01C');
INSERT INTO staging.atc (description, atc_code) VALUES ('specific immunoglobulins', 'J06BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('spectinomycin', 'J01XX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('spermicides', 'ZXX0136');
INSERT INTO staging.atc (description, atc_code) VALUES ('spiramycin', 'J01FA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('spirapril', 'C09AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('spironolactone', 'C03DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('standardized cat hair acetone precipitated', 'V01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('standardized cat pelt', 'V01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('standardized cat pelt acetone precipitated', 'V01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('standardized june grass pollen', 'V01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('standardized meadow fescue grass pollen', 'V01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('standardized orchard grass pollen', 'V01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('standardized perennial rye grass pollen', 'V01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('standardized redtop grass pollen', 'V01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('standardized sweet vernal grass pollen', 'V01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('standardized timothy grass pollen', 'V01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('stannous fluoride', 'A01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('stanozolol', 'A14AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('staphylococcus immunoglobulin', 'J06BB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('starch', 'D02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('stavudine', 'J05AF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('stavudine, lamivudine and nevirapine', 'J05AR07');
INSERT INTO staging.atc (description, atc_code) VALUES ('stem cells from umbilical cord blood', 'B05AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('stepronin', 'R05CB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('sterculia', 'A06AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sterculia, combinations', 'A06AC53');
INSERT INTO staging.atc (description, atc_code) VALUES ('steroid antibacterials', 'J01XC');
INSERT INTO staging.atc (description, atc_code) VALUES ('stibophen', 'P02BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('stiripentol', 'N03AX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('stomatological preparations', 'A01');
INSERT INTO staging.atc (description, atc_code) VALUES ('stomatological preparations', 'A01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('stomi equipment', 'V07AS');
INSERT INTO staging.atc (description, atc_code) VALUES ('stramoni preparations', 'R03BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptoduocin', 'J01GA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptogramins', 'J01FG');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptokinase', 'B01AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptokinase, combinations', 'B06AA55');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptomycin', 'A07AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptomycin', 'J01GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptomycin (streptomycin sulfate)', 'J01GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptomycin and isoniazid', 'J04AM01');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptomycin, combinations', 'A07AA54');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptomycins', 'J01GA');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptozocin', 'L01AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('strong cytochrome p450 1a2 inhibitors', 'ZXX0165');
INSERT INTO staging.atc (description, atc_code) VALUES ('strong cytochrome p450 2b6 inhibitors', 'ZXX0171');
INSERT INTO staging.atc (description, atc_code) VALUES ('strong cytochrome p450 2c19 inhibitors', 'ZXX0189');
INSERT INTO staging.atc (description, atc_code) VALUES ('strong cytochrome p450 2c8 inhibitors', 'ZXX0177');
INSERT INTO staging.atc (description, atc_code) VALUES ('strong cytochrome p450 2c9 inhibitors', 'ZXX0183');
INSERT INTO staging.atc (description, atc_code) VALUES ('strong cytochrome p450 2d6 inhibitors', 'ZXX0195');
INSERT INTO staging.atc (description, atc_code) VALUES ('strong cytochrome p450 2e1 inhibitors', 'ZXX0201');
INSERT INTO staging.atc (description, atc_code) VALUES ('strong cytochrome p450 3a4,5,7 inhibitors', 'ZXX0207');
INSERT INTO staging.atc (description, atc_code) VALUES ('strontium (89sr) chloride', 'V10BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('strontium ranelate', 'M05BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('strophantus glycosides', 'C01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('styramate', 'M03BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('substituted alkylamines', 'R06AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('substituted ethylene diamines', 'R06AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('substituted phenols', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('substrates of p-glycoprotein', 'ZXX0160');
INSERT INTO staging.atc (description, atc_code) VALUES ('succinimide', 'G04BX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('succinimide derivatives', 'N03AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('succinylcholine chloride', 'M03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('succinylsulfathiazole', 'A07AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sucralfate', 'A02BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sufentanil', 'N01AH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sufentanil (sufentanil citrate)', 'N01AH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulbactam', 'J01CG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulbenicillin', 'J01CA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulbentine', 'D01AE09');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulbutiamine', 'A11DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulconazole', 'D01AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulcotidil', 'C04AX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfacetamide', 'S01AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfacetamide sodium', 'S01AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfadiazine', 'J01EC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfadiazine and tetroxopriim', 'J01EE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfadiazine and trimethoprim', 'J01EE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfadicramide', 'S01AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfadimethoxine', 'J01ED01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfadimidine', 'J01EB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfadimidine and trimethoprim', 'J01EE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfafenazol', 'S01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfafurazole', 'S01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfafurazole', 'J01EB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfaguanidine', 'A07AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfaisodimidine', 'J01EB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfalene', 'J01ED02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamazon', 'J01ED09');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamerazine', 'J01ED07');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamethizole', 'D06BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamethizole', 'B05CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamethizole', 'J01EB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamethizole', 'S01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamethoxazole', 'J01EC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamethoxazole and trimethoprim', 'J01EE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamethoxypyridazine', 'J01ED05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfametomidine', 'J01ED03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfametoxydiazine', 'J01ED04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfametrole and trimethoprim', 'J01EE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamoxole', 'J01EC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamoxole and trimethoprim', 'J01EE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfanilamide', 'J01EB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfaperin', 'J01ED06');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfaphenazole', 'J01ED08');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfapyridine', 'J01EB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfasalazine', 'A07EC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfated oils', 'D10AX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfathiazole', 'J01EB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfathiazole', 'D06BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfathiourea', 'J01EB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfatolamide', 'G01AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfinpyrazone', 'M04AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfisoxazole', 'J01EB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfobromophthalein', 'V04CE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamides', 'A07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamides', 'D06BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamides', 'S01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamides', 'G01AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamides (heterocyclic)', 'A10BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamides and corticosteroids', 'G01BE');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamides and potassium in combination', 'C03BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamides and potassium in combination', 'C03CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamides and trimethoprim', 'J01E');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamides, comb. with other antibacterials (excl. trimethoprim)', 'J01RA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamides, combinations with other drugs', 'C03BK');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamides, plain', 'C03CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamides, plain', 'C03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamides, urea derivatives', 'A10BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonium derivatives', 'C02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfur', 'D05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfur', 'D10AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfur compounds', 'D11AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfur containing products', 'P03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfur-containing imidazole derivatives', 'H03BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulglicotide', 'A02BX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulindac', 'M01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulodexide', 'B01AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulphonamide antibacterials', 'ZXX0138');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulphonylurea hypoglycemics', 'ZXX0139');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulphur hexafluoride', 'V08DA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulpiride', 'N05AL01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulprostone', 'G02AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sultamicillin', 'J01CR04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sultiame', 'N03AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sultopride', 'N05AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sumatriptan', 'N02CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sumatriptan (sumatriptan hemisulfate)', 'N02CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sunitinib', 'L01XE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sunitinib (sunitinib malate)', 'L01XE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('superparamagnetic contrast media', 'V08CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('suprofen', 'M01AE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('suramin sodium', 'P01CX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('surfactant-associated proteins sp-b and sp-c', 'R07AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('surgical aids', 'S01K');
INSERT INTO staging.atc (description, atc_code) VALUES ('surgical dressings', 'V20');
INSERT INTO staging.atc (description, atc_code) VALUES ('suxamethonium', 'M03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('suxibuzone', 'M02AA22');
INSERT INTO staging.atc (description, atc_code) VALUES ('sweet vernal grass', 'V01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetics', 'R01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetics excl. antiglaucoma preparations', 'S01FB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetics in glaucoma therapy', 'S01EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetics used as decongestants', 'S01GA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetics, combinations excl. corticosteroids', 'R01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetics, labour repressants', 'G02CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetics, plain', 'R01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('synthetic anticholinergic agents in combination with analgesics', 'A03DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('synthetic anticholinergic agents in combination with psycholeptics', 'A03CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('synthetic anticholinergics, esters with tertiary amino group', 'A03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('synthetic anticholinergics, quaternary ammonium compounds', 'A03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('synthetic antispasmodics, amides with tertiary amines', 'A03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('synthetic estrogens, plain', 'G03CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('syrosingopine and diuretics', 'C02LA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('systemic hormonal preparations, excl. sex hormones and insulins', 'H');
INSERT INTO staging.atc (description, atc_code) VALUES ('tacalcitol', 'D05AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tacrine', 'N06DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tacrolimus', 'L04AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tacrolimus', 'D11AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tadalafil', 'G04BE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('tadalafil', 'C02KX');
INSERT INTO staging.atc (description, atc_code) VALUES ('talampicillin', 'J01CA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('talastine', 'R06AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('talbutal', 'N05CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('talinolol', 'C07AB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('tamoxifen', 'L02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tamoxifen (tamoxifen citrate)', 'L02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tamsulosin', 'G04CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tamsulosin and dutasteride', 'G04CA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('tamsulosin hydrochloride', 'G04CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tapentadol', 'N02AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tapentadol (tapentadol hydrochloride)', 'N02AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tars', 'D05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('tasonermin', 'L03AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tasosartan', 'C09CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('taurolidine', 'B05CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('taxanes', 'L01CD');
INSERT INTO staging.atc (description, atc_code) VALUES ('tazarotene', 'D05AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tazobactam', 'J01CG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) anticarcinoembryonicantigen antibody', 'V09IA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) antigranulocyte antibody', 'V09HA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) antimelanoma antibody', 'V09IA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) apcitide', 'V09GA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) arcitumomab', 'V09IA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) bicisate', 'V09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) butedronic acid', 'V09BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) compounds', 'V09DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) compounds', 'V09CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) compounds', 'V09HA');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) compounds', 'V09IA');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) compounds', 'V09AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) compounds', 'V09GA');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) compounds', 'V09BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) depreotide', 'V09IA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) disofenin', 'V09DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) etifenin', 'V09DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) exametazime', 'V09AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) exametazime labelled cells', 'V09HA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) furifosmin', 'V09GA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) galtifenin', 'V09DA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) gluceptate', 'V09CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) gluconate', 'V09CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) human albumin', 'V09GA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) human immunoglobulin', 'V09HA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) lidofenin', 'V09DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) macrosalb', 'V09EB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) mebrofenin', 'V09DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) medronic acid', 'V09BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) mertiatide', 'V09CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) microcolloid', 'V09DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) microspheres', 'V09EB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) millimicrospheres', 'V09DB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) nanocolloid', 'V09DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) nanocolloid', 'V09EA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) oxidronic acid', 'V09BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) pentavalent succimer', 'V09IA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) pentetic acid', 'V09EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) pentetic acid', 'V09CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) pertechnetate', 'V09FX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) phytate', 'V09DB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) pyrophosphate', 'V09BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) rheniumsulfide colloid', 'V09DB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) sestamibi', 'V09GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) stannous agent labelled cells', 'V09GA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) succimer', 'V09CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) sulesomab', 'V09HA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) sulfur colloid', 'V09DB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) teboroxime', 'V09GA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) technegas', 'V09EA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) tetrofosmin', 'V09GA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) tin colloid', 'V09DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc) votumumab', 'V09IA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc), inhalants', 'V09EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc), particles and colloids', 'V09DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('technetium (99mtc), particles for injection', 'V09EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('technical disinfectants', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('teclozan', 'P01AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tedisamil', 'C01BD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tegafur', 'L01BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tegafur, combinations', 'L01BC53');
INSERT INTO staging.atc (description, atc_code) VALUES ('tegaserod', 'A03AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('teicoplanin', 'J01XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('telbivudine', 'J05AF11');
INSERT INTO staging.atc (description, atc_code) VALUES ('telithromycin', 'J01FA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('telmisartan', 'C09CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('telmisartan and amlodipine', 'C09DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('telmisartan and diuretics', 'C09DA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('temafloxacin', 'J01MA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('temazepam', 'N05CD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('temocapril', 'C09AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('temocillin', 'J01CA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('temoporfin', 'L01XD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('temozolomide', 'L01AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('temsirolimus', 'L01XE09');
INSERT INTO staging.atc (description, atc_code) VALUES ('tenecteplase', 'B01AD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tenidap', 'M01AX23');
INSERT INTO staging.atc (description, atc_code) VALUES ('teniposide', 'L01CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tenitramine', 'C01DA38');
INSERT INTO staging.atc (description, atc_code) VALUES ('tenofovir disoproxil', 'J05AF07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tenonitrozole', 'P01AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('tenoxicam', 'M01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('terazosin', 'G04CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('terazosin hydrochloride', 'G04CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('terbinafine', 'D01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('terbinafine', 'D01AE15');
INSERT INTO staging.atc (description, atc_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('terbinafine hydrochloride', 'D01AE15');
INSERT INTO staging.atc (description, atc_code) VALUES ('terbutaline', 'R03CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('terbutaline', 'R03AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('terbutaline sulfate', 'R03AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('terbutaline, combinations', 'R03CC53');
INSERT INTO staging.atc (description, atc_code) VALUES ('terconazole', 'G01AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('terfenadine', 'R06AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('teriparatide', 'H05AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('terizidone', 'J04AK03');
INSERT INTO staging.atc (description, atc_code) VALUES ('terlipressin', 'H01BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('terodiline', 'G04BD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tertatolol', 'C07AA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('tertiary amines', 'N04AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('testosterone', 'G03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('testosterone and estrogen', 'G03EA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('testosterone cypionate', 'G03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('testosterone enanthate', 'G03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('testosterone propionate', 'G03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('testosterone undecanoate', 'G03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('testosterone-5-alpha reductase inhibitors', 'G04CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('tests for allergic diseases', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('tests for bile duct patency', 'V04CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('tests for diabetes', 'V04CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('tests for fat absorption', 'V04CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('tests for fertility disturbances', 'V04CM');
INSERT INTO staging.atc (description, atc_code) VALUES ('tests for gastric secretion', 'V04CG');
INSERT INTO staging.atc (description, atc_code) VALUES ('tests for liver functional capacity', 'V04CE');
INSERT INTO staging.atc (description, atc_code) VALUES ('tests for pancreatic function', 'V04CK');
INSERT INTO staging.atc (description, atc_code) VALUES ('tests for pituitary function', 'V04CD');
INSERT INTO staging.atc (description, atc_code) VALUES ('tests for renal function', 'V04CH');
INSERT INTO staging.atc (description, atc_code) VALUES ('tests for thyreoidea function', 'V04CJ');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetanus antitoxin', 'J06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetanus immune globulin (human)', 'J06BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetanus immunoglobulin', 'J06BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetanus toxoid', 'J07AM01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetanus toxoid, combinations with diphtheria toxoid', 'J07AM51');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetanus toxoid, combinations with tetanus immunoglobulin', 'J07AM52');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetanus vaccines', 'J07AM');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetrabenazine', 'N07XX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracaine', 'D04AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracaine', 'N01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracaine', 'S01HA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracaine', 'C05AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracaine (tetracaine hydrochloride)', 'D04AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracaine hydrochloride', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracaine hydrochloride', 'S01HA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracaine hydrochloride', 'N01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracosactide', 'H01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracycline', 'D06AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracycline', 'J01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracycline', 'S02AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracycline', 'A01AB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracycline', 'S03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracycline', 'S01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracycline and derivatives', 'D06AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracycline hydrochloride', 'S01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracycline hydrochloride', 'J01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracyclines', 'J01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracyclines', 'J01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetragalacturonic acid hydroxymethylester', 'B02BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetrahydropyrimidine derivatives', 'P02CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetrahydrozoline hydrochloride', 'S01GA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetramethrin', 'P03BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetramethylthiuram monosulfide', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetrazepam', 'M03BX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetryzoline', 'R01AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetryzoline', 'S01GA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetryzoline', 'R01AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetryzoline, combinations', 'S01GA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('textiles', 'V01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('thalidomide', 'L04AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('thallium (201tl) chloride', 'V09GX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('thebacon', 'R05DA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('theine', 'ZXX0144');
INSERT INTO staging.atc (description, atc_code) VALUES ('thenalidine', 'D04AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('thenalidine', 'R06AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('thenalidine, combinations', 'R06AX53');
INSERT INTO staging.atc (description, atc_code) VALUES ('thenyldiamine', 'Z01AA31');
INSERT INTO staging.atc (description, atc_code) VALUES ('theobromine', 'R03DA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('theobromine', 'C03BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('theobromine, combinations', 'R03DA57');
INSERT INTO staging.atc (description, atc_code) VALUES ('theodrenaline', 'C01CA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('theophylline', 'R03DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('theophylline (and, by extrapolation, aminophylline)', 'ZXX0145');
INSERT INTO staging.atc (description, atc_code) VALUES ('theophylline and adrenergics', 'R03DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('theophylline, combinations excl. psycholeptics', 'R03DA54');
INSERT INTO staging.atc (description, atc_code) VALUES ('theophylline, combinations with psycholeptics', 'R03DA74');
INSERT INTO staging.atc (description, atc_code) VALUES ('therapeutic radiopharmaceuticals', 'V10');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiamazole', 'H03BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiamazole, combinations', 'H03BB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiamine (vit b1)', 'A11DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiamine hydrochloride', 'A11DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiamphenicol', 'J01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiamphenicol, combinations', 'J01BA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiazide derivatives', 'C02DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiazide diuretics and related', 'ZXX0066');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiazides and potassium in combination', 'C03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiazides, combinations with other drugs', 'C03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiazides, combinations with psycholeptics and/or analgesics', 'C03AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiazides, plain', 'C03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiazinam', 'R06AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiazolidinediones', 'A10BG');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiethylperazine', 'R06AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('thimerosal', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('thioacetazone and isoniazid', 'J04AM04');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiocarbamide derivatives', 'J04AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiocolchicoside', 'M03BX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('thioguanine', 'L01BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiomersal', 'D08AK06');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiopental', 'N05CA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiopental', 'N01AF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiopental sodium', 'N01AF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiopropazate', 'N05AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('thioproperazine', 'N05AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('thioproperazine (thioproperazine mesylate)', 'N05AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('thioridazine', 'N05AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiosemicarbazones', 'J05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiosulfate', 'V03AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiotepa', 'L01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiothixene', 'N05AF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiouracils', 'H03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('thioxanthene derivatives', 'N05AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiram', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiram', 'P03AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('third-generation cephalosporins', 'J01DD');
INSERT INTO staging.atc (description, atc_code) VALUES ('thonzylamine', 'D04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('thonzylamine', 'R06AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('thonzylamine', 'R01AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('threonine', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('throat preparations', 'R02');
INSERT INTO staging.atc (description, atc_code) VALUES ('throat preparations', 'R02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('thrombin', 'B02BD30');
INSERT INTO staging.atc (description, atc_code) VALUES ('thrombin', 'B02BC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('thrombin alfa', 'B02BD30');
INSERT INTO staging.atc (description, atc_code) VALUES ('thrombocytes', 'B05AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('thrombolytics', 'ZXX0143');
INSERT INTO staging.atc (description, atc_code) VALUES ('thymol', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('thymol', 'D04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('thymol (thyme oil)', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('thymopentin', 'L03AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('thyroid', 'H03AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('thyroid', 'V09F');
INSERT INTO staging.atc (description, atc_code) VALUES ('thyroid gland preparations', 'H03AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('thyroid hormones', 'H03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('thyroid hormones', 'ZXX0082');
INSERT INTO staging.atc (description, atc_code) VALUES ('thyroid preparations', 'H03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('thyroid therapy', 'H03');
INSERT INTO staging.atc (description, atc_code) VALUES ('thyrotropin', 'H01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('thyrotropin', 'V04CJ01');
INSERT INTO staging.atc (description, atc_code) VALUES ('thyrotropin', 'H01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('thyrotropin alfa', 'V04CJ01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiabendazole', 'D01AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiabendazole', 'P02CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiadenol', 'C10AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiagabine', 'N03AG06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tianeptine', 'N06AX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiapride', 'N05AL03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiaprofenic acid', 'M01AE11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiazofurine', 'L01XX18');
INSERT INTO staging.atc (description, atc_code) VALUES ('tibezonium iodide', 'A01AB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('tibolone', 'G03CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ticagrelor', 'B01AC24');
INSERT INTO staging.atc (description, atc_code) VALUES ('ticarcillin', 'J01CA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('ticarcillin and enzyme inhibitor', 'J01CR03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tick-borne encephalitis vaccine (inactivated)', 'J07BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ticlatone', 'D01AE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ticlopidine', 'B01AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ticlopidine hydrochloride', 'B01AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tidiacic arginine', 'A05BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiemonium iodide', 'A03AB17');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiemonium iodide and analgesics', 'A03DA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tienilic acid', 'C03CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tigecycline', 'J01AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('tilactase', 'A09AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tilbroquinol', 'P01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tilidine', 'N02AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiludronic acid', 'M05BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('timepidium bromide', 'A03AB19');
INSERT INTO staging.atc (description, atc_code) VALUES ('timolol', 'S01ED01');
INSERT INTO staging.atc (description, atc_code) VALUES ('timolol', 'C07AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('timolol (timolol maleate)', 'S01ED01');
INSERT INTO staging.atc (description, atc_code) VALUES ('timolol and thiazides', 'C07BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('timolol maleate', 'C07AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('timolol maleate', 'S01ED01');
INSERT INTO staging.atc (description, atc_code) VALUES ('timolol, combinations', 'S01ED51');
INSERT INTO staging.atc (description, atc_code) VALUES ('timolol, thiazides and other diuretics', 'C07DA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tinidazole', 'J01XD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tinidazole', 'P01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tinzaparin', 'B01AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('tinzaparin sodium', 'B01AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiocarlide', 'J04AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tioclomarol', 'B01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tioconazole', 'D01AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tioconazole', 'G01AF08');
INSERT INTO staging.atc (description, atc_code) VALUES ('tioctic acid', 'A16AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tioguanine', 'L01BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiopronin', 'R05CB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiotixene', 'N05AF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiotropium (tiotropium bromide monohydrate)', 'R03BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiotropium bromure', 'R03BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tioxolone', 'D10AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tipepidine', 'R05DB24');
INSERT INTO staging.atc (description, atc_code) VALUES ('tipranavir', 'J05AE09');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiracizine', 'C01EB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiratricol', 'D11AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiratricol', 'H03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tirilazad', 'N07XX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tirofiban', 'B01AC17');
INSERT INTO staging.atc (description, atc_code) VALUES ('tirofiban (tirofiban hydrochloride)', 'B01AC17');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiropramide', 'A03AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tisopurine', 'M04AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tissue adhesives', 'V03AK');
INSERT INTO staging.atc (description, atc_code) VALUES ('titanium dioxide', 'D02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tixocortol', 'A07EA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tixocortol', 'R01AD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tixocortol, combinations', 'R01AD57');
INSERT INTO staging.atc (description, atc_code) VALUES ('tizanidine', 'M03BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tizanidine', 'M03BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tizanidine (tizanidine hydrochloride)', 'M03BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tobramycin', 'S01AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('tobramycin', 'J01GB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tobramycin (tobramycin sulfate)', 'J01GB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tocainide', 'C01BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tocilizumab', 'L04AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tocopherol (vit e)', 'A11HA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tofisopam', 'N05BA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolazamide', 'A10BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolazoline', 'M02AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolazoline', 'C04AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolbutamide', 'A10BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolbutamide', 'V04CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolcapone', 'N04BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolciclate', 'D01AE19');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolfenamic acid', 'M01AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolmetin', 'M02AA21');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolmetin', 'M01AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolnaftate', 'D01AE18');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolonidine', 'C02AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('toloxatone', 'N06AG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolperisone', 'M03BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolpropamine', 'D04AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolrestat', 'A10XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolterodine', 'G04BD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolterodine tartrate', 'G04BD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tonics', 'A13A');
INSERT INTO staging.atc (description, atc_code) VALUES ('tonics', 'A13');
INSERT INTO staging.atc (description, atc_code) VALUES ('topical antacids and adsorbants', 'ZXX0146');
INSERT INTO staging.atc (description, atc_code) VALUES ('topical products for joint and muscular pain', 'M02');
INSERT INTO staging.atc (description, atc_code) VALUES ('topical products for joint and muscular pain', 'M02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('topiramate', 'N03AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('topotecan', 'L01XX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('topotecan (topotecan hydrochloride)', 'L01XX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('torasemide', 'C03CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('toremifene', 'L02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('torsadogenics (except antiparasitics, neuroleptics, methadone)', 'ZXX0147');
INSERT INTO staging.atc (description, atc_code) VALUES ('tositumomab', 'V10XA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('tositumomab/iodine (131i) tositumomab', 'V10XA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('tosylchloramide sodium', 'D08AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('trabectedin', 'L01CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tramadol', 'N02AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tramadol hydrochloride', 'N02AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tramadol, combinations', 'N02AX52');
INSERT INTO staging.atc (description, atc_code) VALUES ('tramazoline', 'R01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('trandolapril', 'C09AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('trandolapril and calcium channel blockers', 'C09BB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('tranexamic acid', 'B02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tranylcypromine', 'N06AF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tranylcypromine (tranylcypromine sulfate)', 'N06AF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('trapidil', 'C01DX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('trastuzumab', 'L01XC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('travoprost', 'S01EE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('trazodone', 'N06AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('trazodone (trazodone hydrochloride)', 'N06AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('trazodone hydrochloride', 'N06AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tree pollen', 'V01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('treosulfan', 'L01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('trepibutone', 'A03AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('treprostinil', 'B01AC21');
INSERT INTO staging.atc (description, atc_code) VALUES ('treprostinil (treprostinil sodium)', 'B01AC21');
INSERT INTO staging.atc (description, atc_code) VALUES ('tretinoin', 'D10AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tretinoin', 'L01XX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('tretinoin, combinations', 'D10AD51');
INSERT INTO staging.atc (description, atc_code) VALUES ('tretoquinol', 'R03CC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('tretoquinol', 'R03AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolone', 'R01AD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolone', 'H02AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolone', 'R03BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolone', 'S01BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolone', 'A01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolone', 'D07AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolone', 'D07XB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolone acetonide', 'H02AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolone acetonide', 'R01AD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolone acetonide', 'D07AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolone and antibiotics', 'D07CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolone and antiinfectives', 'S02CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolone and antiseptics', 'D07BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolone diacetate', 'H02AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolone hexacetonide', 'H02AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamterene', 'C03DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('triaziquone', 'L01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('triazolam', 'N05CD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('triazole derivatives', 'J02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('triazole derivatives', 'G01AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('tribenoside', 'C05CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tribenoside', 'C05AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tribromometacresol', 'D01AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('trichlormethiazide', 'C03AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('trichlormethiazide and potassium', 'C03AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('trichlormethiazide and potassium-sparing agents', 'C03EA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('trichloroethylene', 'N01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('triclabendazole', 'P02BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('triclofos', 'N05CM07');
INSERT INTO staging.atc (description, atc_code) VALUES ('triclosan', 'D08AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('triclosan', 'D09AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tridihexethyl', 'A03AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('triethanolamine stearate', 'D02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('triethylene glycol', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('trifluoperazine', 'N05AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('trifluoperazine (trifluoperazine hydrochloride)', 'N05AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('trifluoperazine hydrochloride', 'N05AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('trifluperidol', 'N05AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('triflupromazine', 'N05AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('trifluridine', 'S01AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('triflusal', 'B01AC18');
INSERT INTO staging.atc (description, atc_code) VALUES ('trihexyphenidyl', 'N04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('trihexyphenidyl hydrochloride', 'N04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('trilostane', 'H02CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimazosin', 'C02CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimebutine', 'A03AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimebutine maleate', 'A03AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimegestone and estrogen', 'G03FA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimeprazine (trimeprazine tartrate)', 'R06AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimetaphan', 'C02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimetazidine', 'C01EB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimethadione', 'N03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimethoprim', 'J01EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimethoprim and derivatives', 'J01EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimethyldiphenylpropylamine', 'A03AX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimetrexate', 'P01AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimipramine', 'N06AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('trioxysalen', 'D05AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('trioxysalen', 'D05BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tripelennamine', 'D04AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tripelennamine', 'R06AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tripelennamine hydrochloride', 'D04AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('triprolidine', 'R06AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('triptans', 'ZXX0149');
INSERT INTO staging.atc (description, atc_code) VALUES ('triptans metabolized by mao', 'ZXX0150');
INSERT INTO staging.atc (description, atc_code) VALUES ('triptans not metabolized by mao', 'ZXX0151');
INSERT INTO staging.atc (description, atc_code) VALUES ('triptorelin', 'L02AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('triptorelin (triptorelin pamoate)', 'L02AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tris hydroxymethyl nitromethane', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('trisodium edetate', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('triticum (wheat fibre)', 'A06AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tritoqualine', 'R06AX21');
INSERT INTO staging.atc (description, atc_code) VALUES ('trofosfamide', 'L01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('troglitazone', 'A10BG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('trolamine salicylate', 'M02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('troleandomycin', 'J01FA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('trolnitrate', 'C01DA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('trolnitrate, combinations', 'C01DA59');
INSERT INTO staging.atc (description, atc_code) VALUES ('tromantadine', 'J05AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tromantadine', 'D06BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('trometamol', 'B05XX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('trometamol', 'B05BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tromethamine', 'B05XX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tropatepine', 'N04AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('tropenzilone and analgesics', 'A03DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tropicamide', 'S01FA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tropicamide, combinations', 'S01FA56');
INSERT INTO staging.atc (description, atc_code) VALUES ('tropisetron', 'A04AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('trospium', 'G04BD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('trospium and analgesics', 'A03DA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('trospium chloride', 'G04BD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('trovafloxacin', 'J01MA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('troxerutin', 'C05CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('troxerutin, combinations', 'C05CA54');
INSERT INTO staging.atc (description, atc_code) VALUES ('troxipide', 'A02BX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('trypan blue', 'S01KX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('trypsin', 'B06AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('trypsin', 'D03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('trypsin, combinations', 'M09AB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('tryptophan', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('tryptophan', 'N06AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tuaminoheptane', 'R01AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('tuaminoheptane', 'R01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tuberculin', 'V04CF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tuberculosis diagnostics', 'V04CF');
INSERT INTO staging.atc (description, atc_code) VALUES ('tuberculosis vaccines', 'J07AN');
INSERT INTO staging.atc (description, atc_code) VALUES ('tuberculosis, live attenuated', 'J07AN01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tubocurarine', 'M03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tulobuterol', 'R03AC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tulobuterol', 'R03CC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tumor necrosis factor alpha (tnf-α) inhibitors', 'L04AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('tumour detection', 'V09I');
INSERT INTO staging.atc (description, atc_code) VALUES ('tyloxapol', 'R05CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tymazoline', 'R01AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('type 5 phosphodiesterase inhibitors (except vardanefil)', 'ZXX0096');
INSERT INTO staging.atc (description, atc_code) VALUES ('typhoid vaccine (salmonella typhi ty21a)', 'J07AP01');
INSERT INTO staging.atc (description, atc_code) VALUES ('typhoid vaccines', 'J07AP');
INSERT INTO staging.atc (description, atc_code) VALUES ('typhoid, combinations with paratyphi types', 'J07AP10');
INSERT INTO staging.atc (description, atc_code) VALUES ('typhoid, inactivated, whole cell', 'J07AP02');
INSERT INTO staging.atc (description, atc_code) VALUES ('typhoid, oral, live attenuated', 'J07AP01');
INSERT INTO staging.atc (description, atc_code) VALUES ('typhoid, purified polysaccharide antigen', 'J07AP03');
INSERT INTO staging.atc (description, atc_code) VALUES ('typhus (exanthematicus) vaccines', 'J07AR');
INSERT INTO staging.atc (description, atc_code) VALUES ('typhus exanthematicus, inactivated, whole cell', 'J07AR01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tyropanoic acid', 'V08AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('tyrosine', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('tyrosine hydroxylase inhibitors', 'C02KB');
INSERT INTO staging.atc (description, atc_code) VALUES ('tyrosine kinase inhibitors', 'ZXX0099');
INSERT INTO staging.atc (description, atc_code) VALUES ('tyrothricin', 'S01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tyrothricin', 'D06AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('tyrothricin', 'R02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ubidecarenone', 'C01EB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('ulipristal', 'G03AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ulobetasol', 'D07AC21');
INSERT INTO staging.atc (description, atc_code) VALUES ('ultrasound contrast media', 'V08DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('ultrasound contrast media', 'V08D');
INSERT INTO staging.atc (description, atc_code) VALUES ('undecylenic acid', 'D01AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('undecylenic acid, combinations', 'D01AE54');
INSERT INTO staging.atc (description, atc_code) VALUES ('unfractionated heparins (prophylactic doses)', 'ZXX0092');
INSERT INTO staging.atc (description, atc_code) VALUES ('unfractionated heparins (therapeutic and in the elderly)', 'ZXX0091');
INSERT INTO staging.atc (description, atc_code) VALUES ('unoprostone', 'S01EE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('urapidil', 'C02CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('urate oxidase', 'M04AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('urea', 'D04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('uricosurics', 'ZXX0152');
INSERT INTO staging.atc (description, atc_code) VALUES ('urinary alkalinization', 'ZXX0006');
INSERT INTO staging.atc (description, atc_code) VALUES ('urinary antispasmodics', 'G04BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('urinary concrement solvents', 'G04BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('urine tests', 'V04B');
INSERT INTO staging.atc (description, atc_code) VALUES ('urofollitropin', 'G03GA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('urokinase', 'B01AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('urologicals', 'G04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ursodeoxycholic acid', 'A05AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ursodiol', 'A05AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ustekinumab', 'L04AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('vaccines', 'J07');
INSERT INTO staging.atc (description, atc_code) VALUES ('vaccinia immunoglobulin', 'J06BB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('vaginal ring with progestogen and estrogen', 'G02BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('valaciclovir', 'J05AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('valacyclovir (valacyclovir hydrochloride)', 'J05AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('valdecoxib', 'M01AH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('valerian', 'N05CM09');
INSERT INTO staging.atc (description, atc_code) VALUES ('valganciclovir', 'J05AB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('valganciclovir (valganciclovir hydrochloride)', 'J05AB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('valine', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('valnoctamide', 'N05CM13');
INSERT INTO staging.atc (description, atc_code) VALUES ('valproic acid', 'N03AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('valproic acid (sodium valproate)', 'N03AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('valproic acid and, by extrapolation, valpromide', 'ZXX0156');
INSERT INTO staging.atc (description, atc_code) VALUES ('valpromide', 'N03AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('valrubicin', 'L01DB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('valsartan', 'C09CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('valsartan and aliskiren', 'C09DX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('valsartan and amlodipine', 'C09DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('valsartan and diuretics', 'C09DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('valsartan, amlodipine and hydrochlorothiazide', 'C09DX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vancomycin', 'J01XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vancomycin', 'A07AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vancomycin (vancomycin hydrochloride)', 'A07AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('vardenafil', 'G04BE09');
INSERT INTO staging.atc (description, atc_code) VALUES ('vardenafil (vardenafil hydrochloride)', 'G04BE09');
INSERT INTO staging.atc (description, atc_code) VALUES ('varenicline', 'N07BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('varenicline (varenicline tartrate)', 'N07BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('varicella vaccines', 'J07BK');
INSERT INTO staging.atc (description, atc_code) VALUES ('varicella zoster immune globulin human', 'J06BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('varicella, live attenuated', 'J07BK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('varicella-zoster virus vaccine live attenuated (oka/merck strain)', 'J07BK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('varicella-zoster virus vaccine live attenuated (oka/merck strain)', 'J07BK02');
INSERT INTO staging.atc (description, atc_code) VALUES ('varicella/zoster immunoglobulin', 'J06BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('various', 'R01AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('various', 'V');
INSERT INTO staging.atc (description, atc_code) VALUES ('various', 'A01AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('various', 'M02AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('various', 'V01AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('various', 'R02AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('various', 'A01AD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('various alimentary tract and metabolism products', 'A16AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('various combinations', 'B03AE10');
INSERT INTO staging.atc (description, atc_code) VALUES ('various combinations', 'D10AX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('various diagnostic radiopharmaceuticals', 'V09XX');
INSERT INTO staging.atc (description, atc_code) VALUES ('various pain palliation radiopharmaceuticals', 'V10BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('various therapeutic radiopharmaceuticals', 'V10XX');
INSERT INTO staging.atc (description, atc_code) VALUES ('various thyroid diagnostic radiopharmaceuticals', 'V09FX');
INSERT INTO staging.atc (description, atc_code) VALUES ('vasoconstrictor ergot alkaloids', 'ZXX0008');
INSERT INTO staging.atc (description, atc_code) VALUES ('vasodilators used in cardiac diseases', 'C01D');
INSERT INTO staging.atc (description, atc_code) VALUES ('vasopeptidases inhibitor, plain', 'C09EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vasopeptidases inhibitors, plain', 'C09E');
INSERT INTO staging.atc (description, atc_code) VALUES ('vasopressin', 'H01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vasopressin (arginine vasopressin)', 'H01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vasopressin and analogues', 'H01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vasoprotectives', 'C05');
INSERT INTO staging.atc (description, atc_code) VALUES ('vecuronium', 'M03AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('vecuronium bromide', 'M03AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('velaglucerase alfa', 'A16AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('venlafaxine', 'N06AX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('veraliprid', 'N05AL06');
INSERT INTO staging.atc (description, atc_code) VALUES ('verapamil', 'C08DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('verapamil hydrochloride', 'C08DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('verapamil, combinations', 'C08DA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('veratrum', 'C02KA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('veratrum and diuretics', 'C02LK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('verteporfin', 'S01LA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vespula spp venom protein extract', 'V01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('vidarabine', 'S01AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('vidarabine', 'J05AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('vigabatrin', 'N03AG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('vildagliptin', 'A10BH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('viloxazine', 'N06AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('viminol', 'N02BG05');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinbarbital', 'N05CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinblastine', 'L01CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinblastine sulfate', 'L01CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinburnine', 'C04AX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinca alkaloid cytotoxics', 'ZXX0157');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinca alkaloids and analogues', 'L01CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vincamine', 'C04AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('vincristine', 'L01CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('vincristine sulfate', 'L01CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('vindesine', 'L01CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinflunine', 'L01CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinorelbine', 'L01CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinorelbine (vinorelbine tartrate)', 'L01CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinpocetine', 'N06BX18');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinyl ether', 'N01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinylbital', 'N05CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('viral vaccines', 'J07B');
INSERT INTO staging.atc (description, atc_code) VALUES ('virginiamycin', 'D06AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('viscoelastic substances', 'S01KA');
INSERT INTO staging.atc (description, atc_code) VALUES ('visnadine', 'C04AX24');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin a', 'A11CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin a and d in combination', 'A11CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin a and d, incl. combinations of the two', 'A11C');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin a concentrates', 'V04CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin a, plain', 'A11CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b-complex with anabolic steroids', 'A11ED');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b-complex with minerals', 'A11EC');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b-complex with vitamin c', 'A11EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b-complex, incl. combinations', 'A11E');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b-complex, other combinations', 'A11EX');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b-complex, plain', 'A11EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b1 in combination with vitamin b6 and/or vitamin b12', 'A11DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b1, plain', 'A11DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b1, plain and in combination with vitamin b6 and b12', 'A11D');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b12', 'B03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b12 (cyanocobalamin and analogues)', 'B03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b12 (cyanocobalamin)', 'B03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b12 and folic acid', 'B03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b2 (riboflavin 5''-phosphate sodium)', 'A11HA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin c', 'A11GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin c (ascorbic acid)', 'A11GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin c (sodium ascorbate)', 'A11GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin d', 'ZXX0158');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin d (vitamin d3)', 'A11CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin d and analogues', 'A11CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin d2', 'A11CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin d3', 'A11CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin d3 (cholecalciferol)', 'A11CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin e (dl-alpha tocopheryl acetate)', 'A11HA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin k', 'B02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin k and other hemostatics', 'B02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin k antagonists', 'B01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin k1', 'B02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamins', 'B05XC');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamins', 'A11');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamins with minerals', 'A11JB');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamins, other combinations', 'A11JC');
INSERT INTO staging.atc (description, atc_code) VALUES ('voglibose', 'A10BF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('volatile halogenated anesthetics', 'ZXX0017');
INSERT INTO staging.atc (description, atc_code) VALUES ('von willebrand factor and coagula-tion factor viii in combination', 'B02BD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('voriconazole', 'J02AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('vorinostat', 'L01XX38');
INSERT INTO staging.atc (description, atc_code) VALUES ('vorozole', 'L02BG05');
INSERT INTO staging.atc (description, atc_code) VALUES ('warfarin', 'B01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('warfarin sodium', 'B01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('wart and anti-corn preparations', 'D11AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('washing agents etc.', 'V07AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('wasp venom protein', 'V01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('water', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('water', 'B01AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('water', 'L03AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('water', 'B01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('water', 'H01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('water', 'G04BE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('watersoluble, hepatotropic x-ray contrast media', 'V08AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('watersoluble, nephrotropic, high osmolar x-ray contrast media', 'V08AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('watersoluble, nephrotropic, low osmolar x-ray contrast media', 'V08AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('weak cytochrome p450 1a2 inhibitors', 'ZXX0167');
INSERT INTO staging.atc (description, atc_code) VALUES ('weak cytochrome p450 2b6 inhibitors', 'ZXX0173');
INSERT INTO staging.atc (description, atc_code) VALUES ('weak cytochrome p450 2c19 inhibitors', 'ZXX0191');
INSERT INTO staging.atc (description, atc_code) VALUES ('weak cytochrome p450 2c8 inhibitors', 'ZXX0179');
INSERT INTO staging.atc (description, atc_code) VALUES ('weak cytochrome p450 2c9 inhibitors', 'ZXX0185');
INSERT INTO staging.atc (description, atc_code) VALUES ('weak cytochrome p450 2d6 inhibitors', 'ZXX0197');
INSERT INTO staging.atc (description, atc_code) VALUES ('weak cytochrome p450 2e1 inhibitors', 'ZXX0203');
INSERT INTO staging.atc (description, atc_code) VALUES ('weak cytochrome p450 3a4,5,7 inhibitors', 'ZXX0209');
INSERT INTO staging.atc (description, atc_code) VALUES ('white faced hornet venom protein', 'V01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('white petrolatum', 'D02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('white petrolatum', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('wool alcohols', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('x-ray contrast media, iodinated', 'V08A');
INSERT INTO staging.atc (description, atc_code) VALUES ('x-ray contrast media, non-iodinated', 'V08B');
INSERT INTO staging.atc (description, atc_code) VALUES ('xaliproden', 'N07XX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('xamoterol', 'C01CX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('xanthine derivatives', 'C03BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('xanthine derivatives', 'N06BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('xanthines', 'R03DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('xanthines and adrenergics', 'R03DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('xantinol nicotinate', 'C04AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('xenon (127xe) gas', 'V09EX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('xenon (133xe) gas', 'V09EX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('xenysalate', 'D11AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('xibornol', 'J01XX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ximelagatran', 'B01AE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('xipamide', 'C03BA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('xylometazoline', 'S01GA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('xylometazoline', 'R01AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('xylometazoline', 'R01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('xylometazoline hydrochloride', 'R01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('xylometazoline, combinations', 'S01GA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('yellow fever vaccine', 'J07BL01');
INSERT INTO staging.atc (description, atc_code) VALUES ('yellow fever vaccine', 'ZXX0153');
INSERT INTO staging.atc (description, atc_code) VALUES ('yellow fever vaccines', 'J07BL');
INSERT INTO staging.atc (description, atc_code) VALUES ('yellow fever, live attenuated', 'J07BL01');
INSERT INTO staging.atc (description, atc_code) VALUES ('yellow hornet venom protein', 'V01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('yellow jacket venom protein', 'V01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('yohimbin', 'G04BE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('yohimbin', 'V03AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('yohimbine hydrochloride', 'G04BE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('yttrium (90y) citrate colloid', 'V10AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('yttrium (90y) compounds', 'V10AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('yttrium (90y) ferrihydroxide colloid', 'V10AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('yttrium (90y) silicate colloid', 'V10AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('zafirlukast', 'R03DC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('zalcitabine', 'J05AF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('zaleplon', 'N05CF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('zanamivir', 'J05AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ziconotide', 'N02BG08');
INSERT INTO staging.atc (description, atc_code) VALUES ('zidovudine', 'J05AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('zimeldine', 'N06AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc', 'A12CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc (zinc sulfate)', 'A12CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc acetate', 'D04AA32');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc acetate', 'D04AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc acetate', 'A16AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc bandage with supplements', 'D09AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc bandage without supplements', 'D09AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc bandages', 'D09AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc chloride', 'B05XA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc compounds', 'S01AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc dibutyldithiocarbamate', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc diethyldithiocarbamate', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc gluconate', 'A12CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc oxide', 'D11AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc preparations', 'C05AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc products', 'D02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc protein complex', 'A12CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinc sulfate', 'A12CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('zipeprol', 'R05DB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('ziprasidone', 'N05AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ziprasidone (ziprasidone hydrochloride monohydrate)', 'N05AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('zofenopril', 'C09AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('zoledronic acid', 'M05BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('zolimidine', 'A02BX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('zolmitriptan', 'N02CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('zolpidem', 'N05CF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('zomepirac', 'M01AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('zonisamide', 'N03AX15');
INSERT INTO staging.atc (description, atc_code) VALUES ('zopiclone', 'N05CF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('zorubicin', 'L01DB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('zotepine', 'N05AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('zucapsaicin', 'M02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('zuclopenthixol', 'N05AF05');
INSERT INTO staging.atc (description, atc_code) VALUES ('zuclopenthixol (zuclopenthixol hydrochloride)', 'N05AF05');
INSERT INTO staging.atc (description, atc_code) VALUES ('zuclopenthixol acetate', 'N05AF05');
INSERT INTO staging.atc (description, atc_code) VALUES ('zuclopenthixol decanoate', 'N05AF05');


--
-- PostgreSQL database dump complete
--



-- ===========================================================
-- fill in ATC codes where missing among identifiable consumable substances (en)
-- ===========================================================

UPDATE ref.consumable_substance
SET atc_code = staging.atc.atc_code
FROM staging.atc
WHERE UPPER(ref.consumable_substance.description) = UPPER(staging.atc.description)
AND ref.consumable_substance.atc_code IS NULL
;

commit;

-- =================
-- cleanup and exit
-- =================

\unset ON_ERROR_STOP
DROP TABLE staging.atc CASCADE;
\set ON_ERROR_STOP 1

-- end